OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Teagmhálaithe a allmhairiú",
    "Details" : "Sonraí",
    "All contacts" : "Gach teagmhálaí",
    "_Imported %n contact_::_Imported %n contacts_" : ["Iompórtáladh %n teagmhálaí","Iompórtáladh %n teagmhálacha","Iompórtáladh %n teagmhálacha","Iompórtáladh %n teagmhálacha","Iompórtáladh %n teagmhálacha"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n teagmhálaí scipeáilte)","(%n teagmhálaithe scipeáilte)","(%n teagmhálaithe scipeáilte)","(%n teagmhálaithe scipeáilte)","(%n teagmhálaithe scipeáilte)"],
    "Contacts" : "Teagmhálaithe",
    "A contacts app for Nextcloud" : "Aip teagmhálaithe do Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Is comhéadan úsáideora é an aip teagmhálacha Nextcloud do fhreastalaí CardDAV Nextcloud. Sioncronaigh go héasca teagmhálacha ó ghléasanna éagsúla le do Nextcloud agus cuir in eagar iad ar líne.\n\n* 🚀 **Comhtháthú le haipeanna eile Nextcloud!** Ríomhphost agus Féilire faoi láthair – tuilleadh le teacht.\n* 🎉 **Ná déan dearmad ar bhreithlá!** Is féidir leat breithlaethanta agus imeachtaí athfhillteacha eile a shioncronú le d’Fhéilire Nextcloud.\n* 👥 **Leabhar Seoltaí á Roinnt!** Ar mhaith leat do theagmhálacha a roinnt le do chairde nó le do chomhoibrithe? Fadhb ar bith!\n* 🙈 **Níl an roth á athchruthú againn!** Bunaithe ar leabharlann iontach oscailte SabreDAV.",
    "Copy to full name" : "Cóipeáil chuig an ainm iomlán",
    "Omit year" : "Fág an bhliain ar lár",
    "Allow updating avatars from social media" : "Ceadaigh avatars ó na meáin shóisialta a nuashonrú",
    "There was an error fetching the member list" : "Tharla earráid agus liosta na mball á fháil",
    "Please select a team" : "Roghnaigh foireann le do thoil",
    "Loading team…" : "Foireann á lódáil…",
    "Loading contacts …" : "Teagmhálacha á lódáil …",
    "There are no contacts yet" : "Níl aon teagmhálaithe ann fós",
    "Create contact" : "Cruthaigh teagmhálaí",
    "There are no contacts in this group" : "Níl aon teagmhálaithe sa ghrúpa seo",
    "Create contacts" : "Cruthaigh teagmhálaithe",
    "Add contacts" : "Cuir teagmhálaithe leis",
    "Loading …" : "Ag lódáil …",
    "Manage team" : "Foireann bhainistíochta",
    "Leave team" : "Fág an fhoireann",
    "Delete team" : "Scrios an fhoireann",
    "Setting saved" : "Socrú sábháilte",
    "Failed to save setting" : "Theip ar an socrú a shábháil",
    "Contacts settings" : "Socruithe teagmhálaithe",
    "General" : "Ginearálta",
    "Update avatars from social media" : "Íosluchtaigh avatars ó líonraí sóisialta",
    "Refreshed once per week" : "Athnuachan uair sa tseachtain",
    "Address books" : "Leabhair seoltaí",
    "Tried to drop an invalid contact!" : "Rinneadh iarracht teagmhálaí neamhbhailí a chailleadh!",
    "Rename" : "Athainmnigh",
    "Export" : "Easpórtáil",
    "Send email" : "Seol ríomhphost",
    "Send email as BCC" : "Seol ríomhphost mar BCC",
    "Delete" : "Scrios",
    "Show all groups" : "Taispeáin gach grúpaí",
    "Collapse groups" : "Laghdaigh grúpaí",
    "Show all teams" : "Taispeáin gach foireann",
    "Collapse teams" : "Laghdaigh foirne",
    "Group name cannot be empty" : "Ní féidir ainm an ghrúpa a bheith folamh",
    "This group already exists" : "Tá an grúpa seo ann cheana féin",
    "An error occurred while creating the group" : "Tharla earráid agus an grúpa á chruthú",
    "This team already exists" : "Tá an fhoireann seo ann cheana féin",
    "An error happened during the creation of the team" : "Tharla earráid le linn cruthú na foirne",
    "Recently contacted" : "Rinneadh teagmháil le déanaí",
    "Contact groups" : "Déan teagmháil le grúpaí",
    "Create a new contact group" : "Cruthaigh grúpa teagmhála nua",
    "Contact group name" : "Ainm an ghrúpa teagmhála",
    "Teams" : "Foirne",
    "Create a new team" : "Cruthaigh foireann nua",
    "Open the contacts app settings" : "Oscail na socruithe aip teagmhálacha",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Roinnte le {num} eintiteas","Roinnte le {num} eintiteas","Roinnte le {num} eintiteas","Roinnte le {num} eintiteas","Roinnte le {num} eintiteas"],
    "Copied" : "Cóipeáladh",
    "Cannot copy" : "Ní féidir cóip a dhéanamh",
    "Copy link" : "Cóipeáil nasc",
    "Toggling of address book was not successful" : "Níor éirigh le scoránú an leabhair sheoltaí",
    "This will delete the address book and every contacts within it" : "Scriosfaidh sé seo an leabhar seoltaí agus gach teagmhálaí laistigh de",
    "Delete {addressbook}?" : "Scrios {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Déanfaidh sé seo an leabhar seoltaí agus gach teagmhálaí laistigh de a dhíroinnt",
    "Unshare {addressbook}?" : "An dteastaíonn uait an {addressbook} a dhíchomhroinnt?",
    "Deletion of address book was not successful." : "Níor éirigh le scriosadh an leabhair sheoltaí.",
    "Renaming of address book was not successful." : "Níor éirigh le hathainmniú an leabhair sheoltaí.",
    "{addressbookname} (Hidden)" : "{addressbookname} (I bhfolach)",
    "Download" : "Íosluchtaigh",
    "Show" : "Taispeáin",
    "Unshare from me" : "Dí-roinn uaim",
    "_%n contact_::_%n contacts_" : ["%n teagmháil","%n teagmhálaithe","%n teagmhálaithe","%n teagmhálaithe","%n teagmhálaithe"],
    "_%n group_::_%n groups_" : ["%n grúpa","%n grúpaí","%n grúpaí","%n grúpaí","%n grúpaí"],
    "Share with users or groups" : "Roinn le húsáideoirí nó le grúpaí",
    "Share with users" : "Comhroinn le húsáideoirí",
    "No users or groups" : "Gan úsáideoirí nó grúpaí",
    "Unable to delete the share" : "Ní féidir an sciar a scriosadh",
    "Unable to change permissions" : "Ní féidir ceadanna a athrú",
    "can create and edit" : "is féidir a chruthú agus a chur in eagar",
    "Choose a vCard file to import" : "Roghnaigh comhad vCard le hiompórtáil",
    "Import into the {addressbookName} address book" : "Iompórtáil isteach sa leabhar seoltaí {addressbookName}",
    "Select local file" : "Roghnaigh comhad áitiúil",
    "Import from files" : "Iompórtáil ó chomhaid",
    "Importing is disabled because there are no address books available" : "Tá an iompórtáil díchumasaithe toisc nach bhfuil leabhair seoltaí ar fáil",
    "An error occurred, unable to create the address book" : "Tharla earráid, níorbh fhéidir an leabhar seoltaí a chruthú",
    "New address book" : "Leabhar seoltaí nua",
    "Add new address book" : "Cuir leabhar seoltaí nua leis",
    "Cancel" : "Cealaigh",
    "Add" : "Cuir",
    "First name" : "Ainm",
    "Last name" : "Sloinne",
    "Phonetic first name" : "Céadainm foghraíochta",
    "Phonetic last name" : "Sloinne foghraíochta",
    "Display name" : "Ainm taispeána",
    "Last modified" : "Athraithe go deireanach",
    "Sort contacts by" : "Sórtáil teagmhálacha de réir",
    "Manages" : "Bainistíonn",
    "Oversees" : "Maoirseacht",
    "An error happened during the config change" : "Tharla earráid le linn an athraithe cumraíochta",
    "Enforce password protection on files shared to this team" : "Cuir cosaint pasfhocail i bhfeidhm ar chomhaid a roinntear leis an bhfoireann seo",
    "Use a unique password for all shares to this team" : "Bain úsáid as pasfhocal uathúil le haghaidh na scaireanna go léir leis an bhfoireann seo",
    "Unique password …" : "Pasfhocal uathúil …",
    "Save" : "Sábháil",
    "Change unique password" : "Athraigh pasfhocal uathúil",
    "Failed to save password. Please try again later." : "Theip ar shábháil pasfhocal. Bain triail eile as ar ball le do thoil.",
    "Close" : "Dún",
    "There is no description for this team" : "Níl aon tuairisc ar an bhfoireann seo",
    "Enter a description for the team" : "Iontráil cur síos don fhoireann",
    "Folder" : "Fillteán",
    "New folder" : "Fillteán nua",
    "Folder name" : "Ainm fillteáin",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Cruthóidh sé seo fillteán rialta a roinntear leis an bhfoireann. Chun Fillteán Foirne a chruthú, déan teagmháil le riarthóir do {productName}.",
    "Talk conversation" : "Comhrá cainte",
    "New Talk conversation" : "Comhrá Cainte Nua",
    "Conversation name" : "Ainm an chomhrá",
    "Collective" : "Comhchoiteann",
    "Calendar" : "Féilire",
    "New calendar" : "Féilire nua",
    "Calendar name" : "Ainm an fhéilire",
    "Deck board" : "Clár deic",
    "New Deck board" : "Clár Deic Nua",
    "Board name" : "Ainm an bhoird",
    "Deck app is not installed. Please install it to create team boards." : "Níl an aip deic suiteáilte. Suiteáil í le do thoil chun boird foirne a chruthú.",
    "Unknown resource type" : "Cineál acmhainne anaithnid",
    "Team calendar \"{resourceName}\" created and shared with team" : "Cruthaíodh agus roinneadh féilire foirne \"{resourceName}\" leis an bhfoireann",
    "{resourceType} \"{resourceName}\" created and shared with team" : "Cruthaíodh agus roinneadh \"{resourceName}\" leis an bhfoireann {resourceType}",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Tá féilire darb ainm \"{name}\" ann cheana féin. Roghnaigh ainm eile le do thoil.",
    "Failed to create {resourceType}: {error}" : "Theip ar {resourceType} a chruthú: {error}",
    "An error happened while saving {fields}" : "Tharla earráid agus {fields} á shábháil",
    "Team name" : "Ainm foirne",
    "Team owner" : "Úinéir na foirne",
    "Edit" : "Cuir in eagar",
    "Request to join" : "Iarratas chun páirt a ghlacadh",
    "Create" : "Cruthaigh",
    "Show in Calendar" : "Taispeáin sa Fhéilire",
    "Your request to join this team is pending approval" : "Tá d'iarratas chun dul isteach san fhoireann seo ar feitheamh cheadú",
    "You are not a member of {circle}" : "Níl tú i do bhall de {circle}",
    "Members" : "Baill",
    "Confirm" : "Deimhnigh",
    "Add more info" : "Cuir tuilleadh eolais leis",
    "More fields" : "Níos mó réimsí",
    "Please select a valid format" : "Roghnaigh formáid bhailí le do thoil",
    "Invalid image" : "Íomhá neamhbhailí",
    "Error cropping picture" : "Earráid agus pictiúr á bhearradh",
    "Pick an avatar" : "Roghnaigh avatar",
    "Pick" : "Pioc",
    "Error while processing the picture." : "Earráid agus an pictiúr á phróiseáil.",
    "Avatar downloaded from social network" : "Íosluchtaigh avatar ó líonra sóisialta",
    "Avatar already up to date" : "Avatar cothrom le dáta cheana féin",
    "Avatar download failed" : "Theip ar an avatar íoslódáil",
    "Crop contact photo" : "Íosluchtaigh grianghraf teagmhála",
    "Upload a new picture" : "Íoslódáil an pictiúr nua",
    "Choose from Files" : "Roghnaigh ó Chomhaid",
    "Download picture" : "Íoslódáil an pictiúr",
    "Delete picture" : "Scrios pictiúr",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tá an teagmhálaí seo i mód inléite amháin. Níl cead agat an teagmhálaí seo a chur in eagar.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Tá an teagmhálaí a bhí tú ag iarraidh a chur in eagar athraithe. Athnuaigh an teagmhálaí de láimh le do thoil. Cuirfear deireadh le haon athruithe breise.",
    "Address book" : "Leabhar seoltaí",
    "Add contact to Birthday Calendar" : "Cuir teagmhálaí leis an bhFéilire Breithlá",
    "Exclude contact from Birthday Calendar" : "Fág teagmháil as an bhFéilire Breithlá",
    "{title} at {organization}" : "{title} ag {organization}",
    "Name" : "Ainm",
    "Syntax error. Cannot open the contact." : "Earráid chomhréire. Ní féidir an teagmhálaí a oscailt.",
    "The contact does not exist on the server anymore." : "Níl an teagmhálaí ar an bhfreastalaí a thuilleadh.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Ní féidir an teagmhálaí a fháil ón bhfreastalaí, seiceáil do cheangal líonra le do thoil.",
    "An error occurred while trying to move the contact" : "Tharla earráid agus iarracht á déanamh an teagmhálaí a bhogadh",
    "An error occurred while trying to copy the contact" : "Tharla earráid agus iarracht á déanamh an teagmhálaí a chóipeáil",
    "Unable to update contact" : "Ní féidir an teagmhálaí a nuashonrú",
    "No contact selected" : "Níl aon teagmhálaí roghnaithe",
    "Select a contact on the list to begin" : "Roghnaigh teagmhálaí ar an liosta le tosú",
    "Title" : "Teideal",
    "Company" : "Cuideachta",
    "Go to talk conversation" : "Téigh chuig comhrá cainte",
    "View profile" : "Féach ar phróifíl",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Briseadh an teagmhálaí seo agus fuarthas réiteach. Déan athbhreithniú ar an ábhar agus cliceáil anseo chun é a shábháil le do thoil.",
    "Edit profile" : "Cuir próifíl in eagar",
    "Clone contact" : "Teagmháil clón",
    "Generate QR Code" : "Gin Cód QR",
    "Contact vCard as QR code" : "Déan teagmháil le vCard mar chód QR",
    "Pick an address book" : "Roghnaigh leabhar seoltaí",
    "Select address book" : "Roghnaigh leabhar seoltaí",
    "Media shares with you" : "Roinnt meáin leat",
    "Talk conversations with you" : "Labhair comhráite leat",
    "Calendar events with you" : "Imeachtaí féilire leat",
    "Deck cards with you" : "Cártaí amadán leat",
    "No shared items with this contact" : "Níl aon mhír roinnte leis an teagmhálaí seo",
    "This contact cannot be moved" : "Ní féidir an teagmhálaí seo a bhogadh",
    "This contact cannot be grouped" : "Ní féidir an teagmhálaí seo a ghrúpáil",
    "Add contacts to groups" : "Cuir teagmhálaithe le grúpaí",
    "Move contacts to addressbook" : "Bog teagmhálaithe chuig an leabhar seoltaí",
    "Select groups" : "Roghnaigh grúpaí",
    "Select addressbook" : "Roghnaigh leabhar seoltaí",
    "Selected contacts" : "Teagmhálaithe roghnaithe",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Tabhair faoi deara nach féidir ach {count} de na {total} teagmhálaithe a chur le grúpa",
    "Please note that only {count} of the {total} contacts can be moved" : "Tabhair faoi deara nach féidir ach {count} de na {total} teagmhálaithe a bhogadh",
    "Move" : "Bog",
    "Could not update favorite status" : "Níorbh fhéidir stádas is fearr leat a nuashonrú",
    "from {addressbook}" : "ó {addressbook}",
    "Remove from favorites" : "Bain ó cheanáin",
    "Add to favorites" : "Cuir le ceanáin",
    "Confirm merging contacts" : "Deimhnigh teagmhálacha a chumasc",
    "The selected contacts have conflicting information. Choose which information to keep" : "Tá faisnéis choimhlinteach sna teagmhálaithe roghnaithe. Roghnaigh cén fhaisnéis atá le coinneáil.",
    "Contacts can be merged" : "Is féidir teagmhálacha a chumasc",
    "Groups" : "Grúpaí",
    "Select groups to add the merged contact to" : "Roghnaigh grúpaí chun an teagmhálaí cumasctha a chur leo",
    "Merge contacts" : "Cumaisc teagmhálacha",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Scrios {number} teagmhálaí","Scrios {number} teagmhálaithe","Scrios {number} teagmhálaithe","Scrios {number} teagmhálaithe","Scrios {number} teagmhálaithe"],
    "Please select at least one editable contact to delete" : "Roghnaigh teagmhálaí amháin ar a laghad is féidir a chur in eagar le scriosadh",
    "Please select two editable contacts to merge" : "Roghnaigh dhá theagmhálaí in-eagarthóireachta le cumasc",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Cuir {number} teagmhálaí leis an ngrúpa","Cuir {number} teagmhálaithe leis an ngrúpa","Cuir {number} teagmhálaithe leis an ngrúpa","Cuir {number} teagmhálaithe leis an ngrúpa","Cuir {number} teagmhálaithe leis an ngrúpa"],
    "Please select at least one editable contact to add to a group" : "Roghnaigh teagmhálaí amháin ar a laghad is féidir a chur in eagar le cur leis an ngrúpa",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Bog {number} teagmhálaí chuig an leabhar seoltaí","Bog {number} teagmhálaithe chuig an leabhar seoltaí","Bog {number} teagmhálaithe chuig an leabhar seoltaí","Bog {number} teagmhálaithe chuig an leabhar seoltaí","Bog {number} teagmhálaithe chuig an leabhar seoltaí"],
    "Please select at least one editable contact to move to an addressbook" : "Roghnaigh teagmhálaí amháin ar a laghad is féidir a chur in eagar le bogadh chuig an leabhar seoltaí",
    "Are you sure you want to proceed?" : "An bhfuil tú cinnte gur mian leat dul ar aghaidh?",
    "Add contacts to group" : "Cuir teagmhálaithe leis an ngrúpa",
    "Search contacts …" : "Cuardaigh teagmhálaithe …",
    "Unselect {number}" : "Díroghnaigh {number}",
    "Add to {group}" : "Cuir le {group}",
    "Add members to {group}" : "Cuir baill le {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Tabhair faoi deara nach féidir leat ach teagmhálaithe ó leabhair sheoltaí inscríofa a chur le grúpaí teagmhálaithe. Ní féidir teagmhálaithe ó leabhair sheoltaí inléite amháin, amhail leabhar seoltaí an chórais, a chur leis.",
    "Remove {type}" : "Bain {type}",
    "Add to group" : "Cuir leis an ngrúpa",
    "Add members to group" : "Cuir baill leis an ngrúpa",
    "Search {types}" : "Cuardaigh {types}",
    "Add guest" : "Cuir aoi leis",
    "Search for people to add" : "Cuardaigh daoine le cur leis",
    "No results" : "Gan torthaí",
    "Add {type}" : "Cuir {type} leis",
    "New team name" : "Ainm foirne nua",
    "Personal team" : "Foireann phearsanta",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Ní bheidh an fhoireann seo le feiceáil ach duit. Ní bheidh baill eile in ann é a fheiceáil ná a úsáid.",
    "Local team" : "Foireann áitiúil",
    "This team will not be shared with the other instances of the global scale" : "Ní roinnfear an fhoireann seo leis na cásanna eile den scála domhanda",
    "Create team" : "Cruthaigh foireann",
    "Promote as sole owner" : "A chur chun cinn mar úinéir aonair",
    "Promote to {level}" : "Cuir chun cinn go {level}",
    "Demote to {level}" : "Léim go {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "An bhfuil tú cinnte gur mian leat an fhoireann seo a fhágáil? Ní féidir an gníomh seo a chealú.",
    "Leave team failed." : "Theip ar an bhfoireann a fhágáil.",
    "Could not delete the member {displayName}" : "Níorbh fhéidir an ball {displayName} a scriosadh",
    "Could not change the member level to {level}" : "Níorbh fhéidir an leibhéal ball a athrú go {level}",
    "Could not accept membership request" : "Níorbh fhéidir glacadh leis an iarratas ballraíochta",
    "Accept membership request" : "Glac le hiarratas ballraíochta",
    "Reject membership request" : "Diúltú don iarratas ballraíochta",
    "Manage level" : "Bainistigh leibhéal",
    "Remove member" : "Bain ball",
    "Unable to get the results" : "Ní féidir na torthaí a fháil",
    "Some members could not be added" : "Níorbh fhéidir roinnt ball a chur leis",
    "There was an issue adding members to the team" : "Bhí deacracht ag cur baill ar an bhfoireann",
    "Loading members list …" : "Ag lódáil liosta na mball …",
    "The list of members is only visible to members of this team" : "Níl liosta na mball le feiceáil ach ag baill na foirne seo",
    "You currently have no access to the member list" : "Níl rochtain agat ar liosta na mball faoi láthair",
    "Add to {team}" : "Cuir le {team}",
    "Invite members to {team}" : "Tabhair cuireadh do bhaill chuig {team}",
    "Pending" : "Ar feitheamh",
    "Select chart …" : "Roghnaigh cairt …",
    "Chart" : "Cairt",
    "Select Date" : "Roghnaigh Dáta",
    "Select type" : "Roghnaigh cineál",
    "Add contact in group" : "Cuir teagmhálaí leis sa ghrúpa",
    "None" : "Dada",
    "copy" : "cóip",
    "Select option" : "Roghnaigh rogha",
    "JavaScript URIs are not allowed" : "Ní cheadaítear URIanna JavaScript",
    "Notes" : "Nótaí",
    "send an email" : "seol ríomhphost",
    "Personal dates" : "Dátaí pearsanta",
    "Add property of this type" : "Cuir airí den chineál seo leis",
    "Member" : "Ball",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Is grúpa inléite amháin é seo atá á bhainistiú ag riarthóirí. Ní féidir ach le baill an ghrúpa an grúpa seo a fheiceáil.",
    "Unable to create the contact." : "Ní féidir an teagmhálaí a chruthú.",
    "Contact not found" : "Teagmháil gan aimsiú",
    "Group {group} not found" : "Grúpa {group} gan aimsiú",
    "Add member" : "Cuir ball leis",
    "New contact" : "Teagmháil nua",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} teagmhálaí curtha le {name}","{success} teagmhálaithe curtha le {name}","{success} teagmhálaithe curtha le {name}","{success} teagmhálaithe curtha le {name}","{success} teagmhálaithe curtha le {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Ag cur {success} teagmhálaí le {name}","Ag cur {success} teagmhálaithe le {name}","Ag cur {success} teagmhálaithe le {name}","Ag cur {success} teagmhálaithe le {name}","Ag cur {success} teagmhálaithe le {name}"],
    "_{count} error_::_{count} errors_" : ["{count} earráid","{count} earráidí","{count} earráidí","{count} earráidí","{count} earráidí"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : [" %n agus teagmhálaí á iompórtáil isteach i {addressbook}"," %n agus teagmhálaithe á iompórtáil isteach i {addressbook}"," %n agus teagmhálaithe á iompórtáil isteach i {addressbook}"," %n agus teagmhálaithe á iompórtáil isteach i {addressbook}"," %n agus teagmhálaithe á iompórtáil isteach i {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Déanta ag iompórtáil %n agus teagmhálaí go {addressbook}","Déanta ag iompórtáil %n agus teagmhálaithe go {addressbook}","Déanta ag iompórtáil %n agus teagmhálaithe go {addressbook}","Déanta ag iompórtáil %n agus teagmhálaithe go {addressbook}","Déanta ag iompórtáil %n agus teagmhálaithe go {addressbook}"],
    "No data for this contact" : "Níl aon sonraí don teagmhálaí seo",
    "No data for this contact on their profile" : "Níl aon sonraí don teagmhálaí seo ar a bpróifíl",
    "Import" : "Iompórtáil",
    "Are you sure you want to import this contact file?" : "An bhfuil tú cinnte gur mhaith leat an comhad teagmhála seo a iompórtáil?",
    "Could not copy" : "Níorbh fhéidir a chóipeáil",
    "Join team" : "Bí ar fhoireann",
    "You are about to leave {circle}.\nAre you sure?" : "Tá tú ar tí {circle} a fhágáil.\nAn bhfuil tú cinnte?",
    "Please confirm team leave" : "Deimhnigh saoire foirne le do thoil",
    "Could not leave the team {displayName}" : "Níorbh fhéidir an fhoireann {displayName} a fhágáil",
    "Unable to join the team" : "Ní féidir a bheith ar an bhfoireann",
    "You are about to delete {circle}.\nAre you sure?" : "Tá tú ar tí {circle} a scriosadh.\nAn bhfuil tú cinnte?",
    "Please confirm team deletion" : "Deimhnigh scriosadh na foirne le do thoil",
    "Unable to delete the team" : "Ní féidir an fhoireann a scriosadh",
    "Confirm enabling federation" : "Deimhnigh go gcuirfí cónaidhm ar bun",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Má chumasaítear é seo, cuirfear cosc ​​ar {circle} a bheith ina bhall de fhoirne eile.\nAn bhfuil tú cinnte?",
    "Enable federation" : "Cumasaigh cónaidhm",
    "Link copied to the clipboard" : "Cóipeáladh an nasc chuig an ngearrthaisce",
    "Could not copy link to the clipboard." : "Níorbh fhéidir nasc chuig an ngearrthaisce a chóipeáil.",
    "Not grouped" : "Gan grúpáil",
    "Organization chart" : "Cairt Eagrúcháin",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Cruthaigh do ghrúpaí féin le haghaidh comhroinnte. Cuir úsáideoirí Nextcloud, teagmhálaithe, nó aon duine leis trí ríomhphost.",
    "Team" : "Foireann",
    "User" : "Úsáideoir",
    "Group" : "Grúpa",
    "Email" : "Ríomhphost",
    "Contact" : "Teagmháil",
    "Moderator" : "Modhnóir",
    "Admin" : "Riarachán",
    "Owner" : "Úinéir",
    "Invites" : "Cuireadh",
    "Anyone can request membership" : "Is féidir le haon duine ballraíocht a iarraidh",
    "Members need to accept invitation" : "Ní mór do chomhaltaí glacadh le cuireadh",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Ní mór do Mhodhnóir ballraíocht a dheimhniú/glacadh léi (éilíonn \"Is féidir le duine ar bith ballraíocht a iarraidh\")",
    "Members can also invite" : "Is féidir le baill cuireadh a thabhairt freisin",
    "Membership" : "Ballraíocht",
    "Prevent teams from being a member of another team" : "Cosc a chur ar fhoirne ó bheith mar bhall d’fhoireann eile",
    "Federation" : "Cónaidhm",
    "Allow federated members" : "Ceadaigh baill chónaidhme",
    "Privacy" : "Príobháideacht",
    "Visible to everyone" : "Infheicthe ag gach duine",
    "users" : "úsáideoirí",
    "Users" : "Úsáideoirí",
    "groups" : "grúpaí",
    "federated users" : "úsáideoirí cónaidhme",
    "Federated users" : "Úsáideoirí cónaidhme",
    "teams" : "foirne",
    "email addresses" : "seoltaí ríomhphoist",
    "Email addresses" : "Seoltaí ríomhphoist",
    "contacts" : "teagmhálaithe",
    "Detailed name" : "Ainm mionsonraithe",
    "Additional names" : "Ainmneacha breise",
    "Prefix" : "Réimír",
    "Suffix" : "Iarmhír",
    "Nickname" : "Leasainm",
    "Website" : "Suíomh Gréasáin",
    "Location" : "Suíomh",
    "Federated Cloud ID" : "ID Cloud Cónaidhme",
    "Home" : "Baile",
    "Work" : "Obair",
    "Other" : "Eile",
    "Address" : "Seoladh",
    "Post office box" : "Bosca oifig an phoist",
    "Extended address" : "Seoladh leathnaithe",
    "City" : "Cathair",
    "State or province" : "Stát nó cúige",
    "Postal code" : "Cód Poist",
    "Country" : "Tír",
    "Birthday" : "Breithlá",
    "Place of birth" : "Áit bhreithe",
    "Anniversary" : "Comóradh",
    "Date of death" : "Dáta báis",
    "Place of death" : "Áit an bháis",
    "Instant messaging" : "Teachtaireachtaí meandaracha",
    "Phone" : "Fón",
    "Mobile" : "Soghluaiste",
    "Work mobile" : "Oibrigh soghluaiste",
    "Home mobile" : "Fón póca baile",
    "Fax" : "Facs",
    "Fax home" : "Facs baile",
    "Fax work" : "Obair facs",
    "Pager" : "Glaoire",
    "Voice" : "Guth",
    "Car" : "Carr",
    "Work pager" : "Próiseálaí oibre",
    "Line manager" : "Bainisteoir líne",
    "Social network" : "Líonra sóisialta",
    "Relationship to you" : "Gaol leat",
    "Spouse" : "Céile",
    "Child" : "Páiste",
    "Mother" : "Máthair",
    "Father" : "Athair",
    "Parent" : "Tuismitheoir",
    "Brother" : "Deartháir",
    "Sister" : "Deirfiúr",
    "Relative" : "Coibhneasta",
    "Friend" : "Cara",
    "Colleague" : "Comhghleacaí",
    "Assistant" : "Cúntóir",
    "Related contacts" : "Teagmhálaithe gaolmhara",
    "Agent" : "Gníomhaire",
    "Emergency" : "Éigeandála",
    "Co-worker" : "Comhoibrí",
    "Gender" : "Inscne",
    "Female" : "Mná",
    "Male" : "Fireann",
    "Unknown" : "Anaithnid",
    "Time zone" : "Crios ama",
    "Spoken languages" : "Teangacha labhartha",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Theip ar {failed} teagmhálaí a léamh","Theip ar {failed} teagmhálaithe a léamh","Theip ar {failed} teagmhálaithe a léamh","Theip ar {failed} teagmhálaithe a léamh","Theip ar {failed} teagmhálaithe a léamh"],
    "An error has occurred in team(s). Check the console for more details." : "Tharla earráid san fhoireann(í). Seiceáil an consól le haghaidh tuilleadh sonraí.",
    "Unable to create team {circleName}" : "Ní féidir foireann {circleName} a chruthú",
    "Unable to delete team {circleId}" : "Ní féidir foireann {circleId} a scriosadh",
    "Could not update favorite state" : "Níorbh fhéidir an stát is fearr leat a nuashonrú",
    "Unable to delete contact" : "Ní féidir teagmhálaí a scriosadh",
    "Value copied to the clipboard" : "Luach cóipeáilte chuig an ghearrthaisce",
    "Could not copy value to the clipboard." : "Níorbh fhéidir luach a chóipeáil chuig an ghearrthaisce.",
    "note" : "nóta",
    "email" : "ríomhphost"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
