OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacts",
    "General" : "Umumiy",
    "Rename" : "Nomini o'zgartirish",
    "Delete" : "O'chirish",
    "Download" : "Yuklab olish",
    "Cancel" : "Bekor qilish",
    "Add" : "Qo'shish",
    "Save" : "Saqlash",
    "Close" : "Yopish",
    "Invalid image" : "Invalid image",
    "Name" : "Name",
    "Title" : "Sarlavha",
    "Pending" : "Pending",
    "None" : "Yo'q",
    "Notes" : "Notes",
    "Member" : "Member",
    "Admin" : "Admin",
    "Federation" : "Jamg'arma",
    "Users" : "Users",
    "Unknown" : "Unknown"
},
"nplurals=1; plural=0;");
