<?php

/**
 * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

// TODO: uncomment once there are custom styles in the admin settings entrypoint
// style('contacts', 'contacts-index');
// style('contacts', 'contacts-admin-settings');
script('contacts', 'contacts-admin-settings');
?>

<div id="contacts-settings"></div>
