OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importar contactos",
    "Details" : "Detalles",
    "All contacts" : "Todos los contactos",
    "Contacts" : "Contactos",
    "A contacts app for Nextcloud" : "Una aplicación de contactos para Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "La app de Contactos de Nextcloud es una interfaz de usuario para el servidor CardDAV de Nextcloud. Sincroniza fácilmente los contactos de varios dispositivos con tu Nextcloud y edítalos en línea\n\n* 🚀 **Integración con otras apps de Nextcloud.** Actualmente Correo y Calendario; más por llegar.\n* 🎉 **No olvides nunca un calendario.** Puedes sincronizar los calendarios y otros eventos recurrentes con tu calendario de Nextcloud.\n* 👥 **Compartir libretas de dirección.** ¿Quieres compartir tus contactos con tus amigos y colegas? ¡No hay problema!\n* 🙈 **No reinventamos la rueda.l** Basada en la gran biblioteca de código abierto SabreDAV.",
    "Copy to full name" : "Copiar a nombre completo",
    "Omit year" : "Omitir año",
    "Allow updating avatars from social media" : "Permitir la actualización de avatares desde medios sociales",
    "There was an error fetching the member list" : "Ha habido un error al recuperar la lista de miembros",
    "There are no contacts yet" : "Aún no hay contactos",
    "Create contact" : "Crear contacto",
    "There are no contacts in this group" : "No hay contactos en este grupo",
    "Create contacts" : "Crear contactos",
    "Add contacts" : "Añadir contactos",
    "Contacts settings" : "Ajustes del Contacto",
    "Update avatars from social media" : "Actualizar avatares desde redes sociales",
    "Address books" : "Libretas de direcciones",
    "Rename" : "Renombrar",
    "Send email" : "Enviar correo electrónico",
    "Delete" : "Borrar",
    "Show all groups" : "Mostrar todos los grupos",
    "Collapse groups" : "Colapsar grupos",
    "This group already exists" : "Este grupo ya existe",
    "Recently contacted" : "Contactados recientemente",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidad","Compartido con {num} entidades","Compartido con {num} entidades"],
    "Copied" : "Copiado",
    "Cannot copy" : "No se pudo copiar",
    "Copy link" : "Copiar enlace",
    "Toggling of address book was not successful" : "El cambio de la libreta de direcciones falló",
    "This will delete the address book and every contacts within it" : "Esto eliminará la libreta de direcciones y todos los contactos que hay en ella",
    "Delete {addressbook}?" : "¿Eliminar {addressbook}?",
    "Deletion of address book was not successful." : "El borrado de la libreta de direcciones falló.",
    "Renaming of address book was not successful." : "El renombrado de la libreta de direcciones falló.",
    "Download" : "Descargar",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "Unable to delete the share" : "No se ha podido eliminar el recurso compartido",
    "Unable to change permissions" : "No se han podido cambiar los permisos",
    "Choose a vCard file to import" : "Elige un archivo vCard para importar",
    "Import into the {addressbookName} address book" : "Importar en la libreta de direcciones {addressbookName}",
    "Select local file" : "Selecciona archivo local",
    "Importing is disabled because there are no address books available" : "La importación está deshabilitada porque no hay libretas de direcciones disponibles",
    "An error occurred, unable to create the address book" : "Ha ocurrido un error, no se ha podido crear la libreta de direcciones",
    "Add new address book" : "Agregar nueva libreta de direcciones",
    "Cancel" : "Cancelar",
    "Add" : "Añadir",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Phonetic first name" : "Nombre fonético",
    "Phonetic last name" : "Apellido fonético",
    "Display name" : "Nombre para mostrar",
    "Last modified" : "Última modificación",
    "An error happened during the config change" : "Ha ocurrido un error durante el cambio de la configuración",
    "Save" : "Guardar",
    "Change unique password" : "Cambiar la contraseña única",
    "Failed to save password. Please try again later." : "No se ha podido guardar la contraseña. Por favor, inténtelo de nuevo más tarde.",
    "Close" : "Cerrar",
    "Folder" : "Folder",
    "Request to join" : "Solicitud de unión",
    "Create" : "Crear",
    "You are not a member of {circle}" : "No eres miembro de {circle}",
    "Invalid image" : "Imagen inválida",
    "Pick an avatar" : "Escoger un avatar",
    "Error while processing the picture." : "Error al procesar la imagen",
    "Avatar downloaded from social network" : "Avatar descargado desde red social",
    "Avatar already up to date" : "Avatar ya actualizado",
    "Avatar download failed" : "Descarga del avatar fallido",
    "Upload a new picture" : "Subir una nueva imagen",
    "Choose from Files" : "Escoger desde Archivos",
    "Download picture" : "Descargar imágen",
    "Delete picture" : "Eliminar imagen",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de sólo lectura. No tienes permiso para editar este contacto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que intentabas editar ha cambiado. Por favor actualice manualmente el contacto. Cualquier otra edición será descartada.",
    "Address book" : "libreta de direcciones",
    "Name" : "Nombre",
    "Syntax error. Cannot open the contact." : "Error de sintaxis. No se puede abrir el contacto",
    "Unable to retrieve the contact from the server, please check your network connection." : "Imposible recibir el contacto del servidor, por favor comprueba tu conexión de red.",
    "An error occurred while trying to move the contact" : "Ocurrió un error intentando mover el contacto",
    "An error occurred while trying to copy the contact" : "Ocurrió un error intentando copiar el contacto",
    "No contact selected" : "Contacto no seleccionado",
    "Select a contact on the list to begin" : "Seleccione un contacto en la lista para comenzar",
    "Title" : "Título",
    "Company" : "Empresa",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contacto estaba dañado y se ha reparado. Por favor, revise el contenido y haga clic aquí para guardarlo.",
    "Clone contact" : "Clonar contacto",
    "Generate QR Code" : "Generar código QR",
    "Contact vCard as QR code" : "Contacto vCard como código QR",
    "Pick an address book" : "Escoge una libreta de direcciones",
    "Select address book" : "Selecciona una libreta de direcciones",
    "Move" : "Move",
    "Remove from favorites" : "Eliminado de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Add to {group}" : "Añadir a {group}",
    "Remove {type}" : "Eliminar {type}",
    "Add to group" : "Añadir a grupo",
    "Search {types}" : "Buscar {types}",
    "Search for people to add" : "Buscar personas a añadir",
    "No results" : "Sin resultados",
    "Add {type}" : "Añadir {type}",
    "Promote as sole owner" : "Promover como único propietario",
    "Promote to {level}" : "Promover a {level}",
    "Demote to {level}" : "Descender a {level}",
    "Could not delete the member {displayName}" : "No se ha podido eliminar el miembro {displayName}",
    "Could not change the member level to {level}" : "No se ha podido modificar el nivel del miembro a {level}",
    "Could not accept membership request" : "No se ha podido aceptar la petición de adhesión",
    "Accept membership request" : "Aceptar solicitud de adhesión",
    "Reject membership request" : "Rechazar solicitud de adhesión",
    "Manage level" : "Administrar el nivel",
    "Remove member" : "Eliminar miembro",
    "Unable to get the results" : "No se puede obtener los resultados",
    "Some members could not be added" : "Algunos miembros no se han podido añadir",
    "Pending" : "Pendiente",
    "Select Date" : "Seleccionar fecha",
    "Select type" : "Seleccionar tipo",
    "Add contact in group" : "Añadir contacto en grupo",
    "None" : "Ninguno",
    "Select option" : "Seleccionar opción",
    "Notes" : "Notas",
    "Member" : "Miembro",
    "Unable to create the contact." : "No se puede crear el contacto.",
    "Contact not found" : "Contacto no encontrado",
    "Group {group} not found" : "Grupo {group} no encontrado",
    "Add member" : "Añadir miembro",
    "New contact" : "Nuevo contacto",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contacto añadido a {name}","{success} contactos añadidos a {name}","{success} contactos añadidos a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Añadiendo {success} contacto a {name}","Añadiendo {success} contactos a {name}","Añadiendo {success} contactos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errores","{count} errores"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contacto en {addressbook}","Importandos %n contactos en {addressbook}","Importando %n contactos en {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Completado importando %n contacto en {addressbook}","Completado importando %n contactos en {addressbook}","Completado importando %n contactos en {addressbook}"],
    "Import" : "Importar",
    "Could not copy" : "No se ha podido copiar",
    "You are about to leave {circle}.\nAre you sure?" : "Está a punto de salir de {circle}.\n¿Está seguro?",
    "You are about to delete {circle}.\nAre you sure?" : "Estás a punto de eliminar {circle}.\n¿Desea continuar?",
    "Link copied to the clipboard" : "Enlace copiado al portapapeles",
    "Could not copy link to the clipboard." : "No se pudo copiar el enlace al portapapeles.",
    "Not grouped" : "No agrupado",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Contact" : "Contacto",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "Invites" : "Invitaciones",
    "Anyone can request membership" : "Cualquiera puede solicitar membresía",
    "Members need to accept invitation" : "Los miembros deben aceptar la invitación",
    "Members can also invite" : "Los miembros también pueden invitar",
    "Privacy" : "Privacidad",
    "Visible to everyone" : "Visible para todos",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Nickname" : "Apodo",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "Extended address" : "Dirección extendida",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Trabajo movil",
    "Home mobile" : "Casa móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Coche",
    "Work pager" : "Buscapersonas de trabajo",
    "Social network" : "Red social",
    "Relationship to you" : "Relación contigo",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Relativo",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Related contacts" : "Contactos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Co-trabajador",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "Unknown" : "Desconocido",
    "Time zone" : "Zona horaria",
    "Spoken languages" : "Idiomas hablados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contacto no se ha podido leer","{failed} contactos no se han podido leer","{failed} contactos no se han podido leer"],
    "Unable to delete contact" : "No se ha podido eliminar el contacto"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
