OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Import contacts",
    "Details" : "Details",
    "All contacts" : "Svi kontakti",
    "Contacts" : "Kontakti",
    "A contacts app for Nextcloud" : "A contacts app for Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library.",
    "Copy to full name" : "Copy to full name",
    "Omit year" : "Izostavi godinu",
    "Allow updating avatars from social media" : "Allow updating avatars from social media",
    "There was an error fetching the member list" : "There was an error fetching the member list",
    "Please select a team" : "Please select a team",
    "Loading team…" : "Loading team…",
    "There are no contacts yet" : "There are no contacts yet",
    "Create contact" : "Create contact",
    "There are no contacts in this group" : "There are no contacts in this group",
    "Create contacts" : "Create contacts",
    "Add contacts" : "Add contacts",
    "Manage team" : "Manage team",
    "Leave team" : "Leave team",
    "Delete team" : "Delete team",
    "Contacts settings" : "Contacts settings",
    "Update avatars from social media" : "Update avatars from social media",
    "Address books" : "Address books",
    "Rename" : "Preimenuj",
    "Export" : "Export",
    "Send email" : "Pošalji e-poštu",
    "Send email as BCC" : "Send email as BCC",
    "Delete" : "Obriši",
    "Show all groups" : "Show all groups",
    "Collapse groups" : "Collapse groups",
    "Show all teams" : "Show all teams",
    "Collapse teams" : "Collapse teams",
    "Group name cannot be empty" : "Group name cannot be empty",
    "This group already exists" : "This group already exists",
    "An error occurred while creating the group" : "An error occurred while creating the group",
    "This team already exists" : "This team already exists",
    "An error happened during the creation of the team" : "An error happened during the creation of the team",
    "Recently contacted" : "Recently contacted",
    "Contact groups" : "Contact groups",
    "Create a new contact group" : "Create a new contact group",
    "Contact group name" : "Contact group name",
    "Teams" : "Teams",
    "Create a new team" : "Create a new team",
    "Open the contacts app settings" : "Open the contacts app settings",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Shared with {num} entity","Shared with {num} entities","Shared with {num} entities"],
    "Copied" : "Copied",
    "Cannot copy" : "Cannot copy",
    "Copy link" : "Copy link",
    "Toggling of address book was not successful" : "Toggling of address book was not successful",
    "This will delete the address book and every contacts within it" : "This will delete the address book and every contacts within it",
    "Delete {addressbook}?" : "Delete {addressbook}?",
    "This will unshare the address book and every contacts within it" : "This will unshare the address book and every contacts within it",
    "Unshare {addressbook}?" : "Unshare {addressbook}?",
    "Deletion of address book was not successful." : "Deletion of address book was not successful.",
    "Renaming of address book was not successful." : "Renaming of address book was not successful.",
    "Download" : "Preuzmi",
    "Show" : "Show",
    "Unshare from me" : "Unshare from me",
    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts","%n contacts"],
    "_%n group_::_%n groups_" : ["%n group","%n groups","%n groups"],
    "Share with users or groups" : "Share with users or groups",
    "Share with users" : "Share with users",
    "No users or groups" : "No users or groups",
    "Unable to delete the share" : "Unable to delete the share",
    "Unable to change permissions" : "Unable to change permissions",
    "Choose a vCard file to import" : "Choose a vCard file to import",
    "Import into the {addressbookName} address book" : "Import into the {addressbookName} address book",
    "Select local file" : "Select local file",
    "Import from files" : "Import from files",
    "Importing is disabled because there are no address books available" : "Importing is disabled because there are no address books available",
    "An error occurred, unable to create the address book" : "An error occurred, unable to create the address book",
    "Add new address book" : "Add new address book",
    "Cancel" : "Otkaži",
    "Add" : "Dodaj",
    "First name" : "Ime",
    "Last name" : "Prezime",
    "Phonetic first name" : "Phonetic first name",
    "Phonetic last name" : "Phonetic last name",
    "Display name" : "Display name",
    "Last modified" : "Last modified",
    "Manages" : "Manages",
    "Oversees" : "Oversees",
    "An error happened during the config change" : "An error happened during the config change",
    "Enforce password protection on files shared to this team" : "Enforce password protection on files shared to this team",
    "Use a unique password for all shares to this team" : "Use a unique password for all shares to this team",
    "Save" : "Spremi",
    "Change unique password" : "Change unique password",
    "Failed to save password. Please try again later." : "Failed to save password. Please try again later.",
    "Close" : "Zatvori",
    "There is no description for this team" : "There is no description for this team",
    "Enter a description for the team" : "Enter a description for the team",
    "Folder" : "Folder",
    "Team name" : "Team name",
    "Edit" : "Edit",
    "Request to join" : "Request to join",
    "Create" : "Ustvari",
    "Your request to join this team is pending approval" : "Your request to join this team is pending approval",
    "You are not a member of {circle}" : "You are not a member of {circle}",
    "Confirm" : "Confirm",
    "Add more info" : "Add more info",
    "More fields" : "More fields",
    "Please select a valid format" : "Please select a valid format",
    "Invalid image" : "Nevažeća datoteka",
    "Error cropping picture" : "Error cropping picture",
    "Pick an avatar" : "Pick an avatar",
    "Pick" : "Pick",
    "Error while processing the picture." : "Error while processing the picture.",
    "Avatar downloaded from social network" : "Avatar downloaded from social network",
    "Avatar already up to date" : "Avatar already up to date",
    "Avatar download failed" : "Avatar download failed",
    "Crop contact photo" : "Crop contact photo",
    "Upload a new picture" : "Upload a new picture",
    "Choose from Files" : "Choose from Files",
    "Download picture" : "Download picture",
    "Delete picture" : "Delete picture",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "This contact is in read-only mode. You do not have permission to edit this contact.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded.",
    "Address book" : "Address book",
    "Add contact to Birthday Calendar" : "Add contact to Birthday Calendar",
    "Exclude contact from Birthday Calendar" : "Exclude contact from Birthday Calendar",
    "{title} at {organization}" : "{title} at {organization}",
    "Name" : "Ime",
    "Syntax error. Cannot open the contact." : "Syntax error. Cannot open the contact.",
    "The contact does not exist on the server anymore." : "The contact does not exist on the server anymore.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Unable to retrieve the contact from the server, please check your network connection.",
    "An error occurred while trying to move the contact" : "An error occurred while trying to move the contact",
    "An error occurred while trying to copy the contact" : "An error occurred while trying to copy the contact",
    "Unable to update contact" : "Unable to update contact",
    "No contact selected" : "No contact selected",
    "Select a contact on the list to begin" : "Select a contact on the list to begin",
    "Title" : "Naslov",
    "Company" : "Company",
    "Go to talk conversation" : "Go to talk conversation",
    "View profile" : "View profile",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "This contact was broken and received a fix. Please review the content and click here to save it.",
    "Clone contact" : "Clone contact",
    "Generate QR Code" : "Generate QR Code",
    "Contact vCard as QR code" : "Contact vCard as QR code",
    "Pick an address book" : "Pick an address book",
    "Select address book" : "Select address book",
    "Media shares with you" : "Media shares with you",
    "Talk conversations with you" : "Talk conversations with you",
    "Calendar events with you" : "Calendar events with you",
    "Deck cards with you" : "Deck cards with you",
    "No shared items with this contact" : "No shared items with this contact",
    "Add to favorites" : "Add to favorites",
    "Groups" : "Groups",
    "Add to {group}" : "Add to {group}",
    "Remove {type}" : "Remove {type}",
    "Add to group" : "Add to group",
    "Search {types}" : "Search {types}",
    "Search for people to add" : "Search for people to add",
    "No results" : "No results",
    "Add {type}" : "Add {type}",
    "New team name" : "New team name",
    "Personal team" : "Personal team",
    "This team will only be visible to you. Other members will not be able to see or use it." : "This team will only be visible to you. Other members will not be able to see or use it.",
    "Local team" : "Local team",
    "This team will not be shared with the other instances of the global scale" : "This team will not be shared with the other instances of the global scale",
    "Create team" : "Create team",
    "Promote as sole owner" : "Promote as sole owner",
    "Promote to {level}" : "Promote to {level}",
    "Demote to {level}" : "Demote to {level}",
    "Could not delete the member {displayName}" : "Could not delete the member {displayName}",
    "Could not change the member level to {level}" : "Could not change the member level to {level}",
    "Could not accept membership request" : "Could not accept membership request",
    "Accept membership request" : "Accept membership request",
    "Reject membership request" : "Reject membership request",
    "Manage level" : "Manage level",
    "Remove member" : "Remove member",
    "Unable to get the results" : "Unable to get the results",
    "Some members could not be added" : "Some members could not be added",
    "There was an issue adding members to the team" : "There was an issue adding members to the team",
    "The list of members is only visible to members of this team" : "The list of members is only visible to members of this team",
    "You currently have no access to the member list" : "You currently have no access to the member list",
    "Pending" : "Na čekanju",
    "Chart" : "Chart",
    "Select Date" : "Select Date",
    "Select type" : "Select type",
    "Add contact in group" : "Add contact in group",
    "None" : "Ništa",
    "Select option" : "Select option",
    "Notes" : "Notes",
    "Personal dates" : "Personal dates",
    "Add property of this type" : "Add property of this type",
    "Member" : "Član",
    "Unable to create the contact." : "Unable to create the contact.",
    "Contact not found" : "Contact not found",
    "Group {group} not found" : "Group {group} not found",
    "Add member" : "Add member",
    "New contact" : "Novi kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contact added to {name}","{success} contacts added to {name}","{success} contacts added to {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adding {success} contact to {name}","Adding {success} contacts to {name}","Adding {success} contacts to {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errors","{count} errors"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importing %n contact into {addressbook}","Importing %n contacts into {addressbook}","Importing %n contacts into {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Done importing %n contact into {addressbook}","Done importing %n contacts into {addressbook}","Done importing %n contacts into {addressbook}"],
    "No data for this contact" : "No data for this contact",
    "No data for this contact on their profile" : "No data for this contact on their profile",
    "Import" : "Uvoz",
    "Are you sure you want to import this contact file?" : "Are you sure you want to import this contact file?",
    "Could not copy" : "Could not copy",
    "Join team" : "Join team",
    "You are about to leave {circle}.\nAre you sure?" : "You are about to leave {circle}.\nAre you sure?",
    "Please confirm team leave" : "Please confirm team leave",
    "Could not leave the team {displayName}" : "Could not leave the team {displayName}",
    "Unable to join the team" : "Unable to join the team",
    "You are about to delete {circle}.\nAre you sure?" : "You are about to delete {circle}.\nAre you sure?",
    "Please confirm team deletion" : "Please confirm team deletion",
    "Unable to delete the team" : "Unable to delete the team",
    "Link copied to the clipboard" : "Link copied to the clipboard",
    "Could not copy link to the clipboard." : "Could not copy link to the clipboard.",
    "Not grouped" : "Nije grupirano",
    "Organization chart" : "Organization chart",
    "Team" : "Team",
    "User" : "User",
    "Group" : "Grupa",
    "Email" : "E-pošta",
    "Contact" : "Contact",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "Invites" : "Invites",
    "Anyone can request membership" : "Anyone can request membership",
    "Members need to accept invitation" : "Members need to accept invitation",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")",
    "Members can also invite" : "Members can also invite",
    "Prevent teams from being a member of another team" : "Prevent teams from being a member of another team",
    "Visible to everyone" : "Visible to everyone",
    "users" : "users",
    "Users" : "Users",
    "groups" : "groups",
    "teams" : "teams",
    "email addresses" : "email addresses",
    "Email addresses" : "Email addresses",
    "contacts" : "contacts",
    "Detailed name" : "Detailed name",
    "Additional names" : "Dodatna imena",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Nadimak",
    "Website" : "Web-prezentacija",
    "Location" : "Lokacija",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Kuća",
    "Work" : "Posao",
    "Other" : "Ostali",
    "Address" : "Adresa",
    "Post office box" : "Post office box",
    "Extended address" : "Extended address",
    "City" : "Grad",
    "State or province" : "Savezna država ili pokrajina",
    "Postal code" : "Poštanski broj",
    "Country" : "Država",
    "Birthday" : "Rođendan",
    "Place of birth" : "Place of birth",
    "Anniversary" : "Anniversary",
    "Date of death" : "Date of death",
    "Place of death" : "Place of death",
    "Instant messaging" : "Razmjena izravnih poruka",
    "Phone" : "Telefon",
    "Mobile" : "Mobitel",
    "Work mobile" : "Work mobile",
    "Home mobile" : "Home mobile",
    "Fax" : "Faks",
    "Fax home" : "Fax home",
    "Fax work" : "Fax work",
    "Pager" : "Dojavljivač",
    "Voice" : "Glas",
    "Car" : "Car",
    "Work pager" : "Work pager",
    "Line manager" : "Line manager",
    "Social network" : "Social network",
    "Relationship to you" : "Relationship to you",
    "Spouse" : "Spouse",
    "Child" : "Child",
    "Mother" : "Mother",
    "Father" : "Father",
    "Parent" : "Parent",
    "Brother" : "Brother",
    "Sister" : "Sister",
    "Relative" : "Relative",
    "Friend" : "Friend",
    "Colleague" : "Colleague",
    "Assistant" : "Assistant",
    "Related contacts" : "Related contacts",
    "Agent" : "Agent",
    "Emergency" : "Emergency",
    "Co-worker" : "Co-worker",
    "Gender" : "Gender",
    "Female" : "Female",
    "Male" : "Male",
    "Unknown" : "Nepoznato",
    "Time zone" : "Time zone",
    "Spoken languages" : "Spoken languages",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contact failed to be read","{failed} contacts failed to be read","{failed} contacts failed to be read"],
    "An error has occurred in team(s). Check the console for more details." : "An error has occurred in team(s). Check the console for more details.",
    "Unable to create team {circleName}" : "Unable to create team {circleName}",
    "Unable to delete team {circleId}" : "Unable to delete team {circleId}",
    "Unable to delete contact" : "Unable to delete contact"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
