OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Імпарт кантактаў",
    "Details" : "Падрабязнасці",
    "All contacts" : "Усе кантакты",
    "_Imported %n contact_::_Imported %n contacts_" : ["Імпартаваны %n кантакт","Імпартаваны %n кантакты","Імпартавана %n кантактаў","Імпартавана %n кантактаў"],
    "Contacts" : "Кантакты",
    "A contacts app for Nextcloud" : "Праграма Кантакты для Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Праграма Кантакты Nextcloud — гэта карыстальніцкі інтэрфейс для сервера CardDAV ад Nextcloud. Лёгка сінхранізуйце кантакты з розных прылад з вашым Nextcloud і рэдагуйце іх у сетцы.\n\n* 🚀 **Інтэграцыя з іншымі праграмамі Nextcloud!** У цяперашні час гэта «Пошта» і «Каляндар» — далей будуць яшчэ.\n\n* 🎉 **Ніколі не забывайце пра дзень нараджэння!** Вы можаце сінхранізаваць дні нараджэння і іншыя перыядычныя падзеі з календаром Nextcloud.\n* 👥 **Агульны доступ да адрасных кніг!** Хочаце абагуліць свае кантакты з сябрамі або калегамі? Без праблем!\n* 🙈 **Мы не вынаходзім ровар!** Заснавана на выдатнай і адкрытай бібліятэцы SabreDAV.",
    "Copy to full name" : "Скапіяваць у поўнае імя",
    "Omit year" : "Прапусціць год",
    "Allow updating avatars from social media" : "Дазволіць абнаўленне аватараў з сацыяльных медыя",
    "Please select a team" : "Выберыце каманду",
    "Loading team…" : "Загрузка каманды…",
    "Loading contacts …" : "Загрузка кантактаў …",
    "There are no contacts yet" : "Пакуль няма кантактаў.",
    "Create contact" : "Стварыць кантакт",
    "There are no contacts in this group" : "У гэтай групе няма кантактаў",
    "Create contacts" : "Стварыць кантакты",
    "Add contacts" : "Дадаць кантакты",
    "Loading …" : "Загрузка …",
    "Manage team" : "Кіраванне камандай",
    "Leave team" : "Выйсці з каманды",
    "Delete team" : "Выдаліць каманду",
    "Contacts settings" : "Налады Кантактаў",
    "General" : "Агульныя",
    "Update avatars from social media" : "Абнаўляць аватары з сацыяльных медыя",
    "Refreshed once per week" : "Абнаўляецца раз на тыдзень",
    "Address books" : "Адрасныя кнігі",
    "Rename" : "Перайменаваць",
    "Export" : "Экспарт",
    "Send email" : "Адправіць электронны ліст",
    "Send email as BCC" : "Адправіць ліст як схаваную копію",
    "Delete" : "Выдаліць",
    "Show all groups" : "Паказаць усе групы",
    "Collapse groups" : "Згарнуць групы",
    "Show all teams" : "Паказаць усе каманды",
    "Collapse teams" : "Згарнуць каманды",
    "Group name cannot be empty" : "Назва групы не можа быць пустой",
    "This group already exists" : "Гэта група ўжо існуе",
    "An error occurred while creating the group" : "Пры стварэнні групы адбылася памылка",
    "This team already exists" : "Каманда ўжо існуе",
    "An error happened during the creation of the team" : "Пры стварэнні каманды адбылася памылка",
    "Recently contacted" : "Нядаўнія кантакты",
    "Contact groups" : "Групы кантактаў",
    "Create a new contact group" : "Стварыць новую групу кантактаў",
    "Contact group name" : "Назва групы кантактаў",
    "Teams" : "Каманды",
    "Create a new team" : "Стварыць новую каманду",
    "Open the contacts app settings" : "Адкрыць налады праграмы Кантакты",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Агулена з {num} аб'ектам","Агулена з {num} аб'ектамі","Агулена з {num} аб'ектамі","Агулена з {num} аб'ектамі"],
    "Copied" : "Скапіявана",
    "Cannot copy" : "Не ўдалося скапіяваць",
    "Copy link" : "Скапіяваць спасылку",
    "Toggling of address book was not successful" : "Не ўдалося пераключыць адрасную кнігу",
    "This will delete the address book and every contacts within it" : "Будзе выдалена адрасная кніга і ўсе кантакты ў ёй",
    "Delete {addressbook}?" : "Выдаліць {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Будзе скасавана абагульванне адраснай кнігі і ўсіх кантактаў у ёй",
    "Unshare {addressbook}?" : "Скасаваць абагульванне {addressbook}?",
    "Deletion of address book was not successful." : "Не ўдалося выдаліць адрасную кнігу",
    "Renaming of address book was not successful." : "Не ўдалося перайменаваць адрасную кнігу",
    "{addressbookname} (Hidden)" : "{addressbookname} (Схаваная)",
    "Download" : "Спампаваць",
    "Show" : "Паказаць",
    "Unshare from me" : "Скасаваць абагульванне са мной",
    "_%n contact_::_%n contacts_" : ["%n кантакт","%n кантакты","%n кантактаў","%n кантактаў"],
    "_%n group_::_%n groups_" : ["%n група","%n групы","%n груп","%n груп"],
    "Share with users or groups" : "Абагуліць з карыстальнікамі або групамі",
    "Share with users" : "Абагуліць з карыстальнікамі",
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Unable to delete the share" : "Немагчыма выдаліць абагульванне",
    "Unable to change permissions" : "Немагчыма змяніць дазволы",
    "Choose a vCard file to import" : "Выберыце файл vCard для імпарту",
    "Import into the {addressbookName} address book" : "Імпарт у адрасную кнігу {addressbookName}",
    "Select local file" : "Выбраць лакальны файл",
    "Import from files" : "Імпарт з фалаў",
    "Importing is disabled because there are no address books available" : "Імпарт адключаны, бо няма даступных адрасных кніг",
    "An error occurred, unable to create the address book" : "Узнікла памылка, немагчыма стварыць адрасную кнігу",
    "New address book" : "Новая адрасная кніга",
    "Add new address book" : "Дадаць новую адрасную кнігу",
    "Cancel" : "Скасаваць",
    "Add" : "Дадаць",
    "First name" : "Імені",
    "Last name" : "Прозвішчы",
    "Phonetic first name" : "Фанетычным імені",
    "Phonetic last name" : "Фанетычным прозвішчы",
    "Display name" : "Імені для паказу",
    "Last modified" : "Апошнім змяненні",
    "Sort contacts by" : "Сартаваць кантыкты па",
    "Manages" : "Кіруе",
    "Oversees" : "Наглядае",
    "An error happened during the config change" : "Падчас змены канфігурацыі адбылася памылка",
    "Enforce password protection on files shared to this team" : "Прымусова ўключыць абарону паролем для файлаў, абагуленых з гэтай камандай",
    "Use a unique password for all shares to this team" : "Выкарыстоўваць ўнікальны пароль для ўсіх абагуленых з гэтай камандай файлаў",
    "Unique password …" : "Унікальны пароль …",
    "Save" : "Захаваць",
    "Change unique password" : "Змяніць унікальны пароль",
    "Failed to save password. Please try again later." : "Не ўдалося захаваць пароль. Паспрабуйце яшчэ раз пазней.",
    "Close" : "Закрыць",
    "There is no description for this team" : "У гэтай каманды няма апісання",
    "Enter a description for the team" : "Увядзіце апісанне каманды",
    "Folder" : "Folder",
    "Talk conversation" : "Размова ў Talk",
    "New Talk conversation" : "Новая размова ў Talk",
    "Conversation name" : "Назва размовы",
    "Calendar" : "Каляндар",
    "New calendar" : "Новы каляндар",
    "Calendar name" : "Назва календара",
    "An error happened while saving {fields}" : "Падчас захавання {fields} адбылася памылка",
    "Team name" : "Назва каманды",
    "Team owner" : "Уладальнік каманды",
    "Edit" : "Рэдагаваць",
    "Request to join" : "Запыт на далучэнне",
    "Create" : "Стварыць",
    "Show in Calendar" : "Паказаць у Календары",
    "Your request to join this team is pending approval" : "Ваш запыт на далучэнне да гэтай каманды чакае ўхвалення",
    "Members" : "Удзельнікі",
    "Confirm" : "Пацвердзіць",
    "Add more info" : "Дадаць больш інфармацыі",
    "More fields" : "Больш палёў",
    "Please select a valid format" : "Выберыце правільны фармат",
    "Invalid image" : "Памылковы відарыс",
    "Error cropping picture" : "Памылка абрэзкі відарыса",
    "Pick an avatar" : "Выберыце аватар",
    "Pick" : "Выбраць",
    "Error while processing the picture." : "Памылка падчас апрацоўкі відарыса.",
    "Avatar downloaded from social network" : "Аватар спампаваны з сацыяльнай сеткі",
    "Avatar already up to date" : "Аватар ужо абноўлены",
    "Avatar download failed" : "Памылка спампоўвання аватара",
    "Crop contact photo" : "Абрэзаць аватар кантакту",
    "Upload a new picture" : "Запампаваць новы відарыс",
    "Choose from Files" : "Выбраць у Файлах",
    "Download picture" : "Спампаваць відарыс",
    "Delete picture" : "Выдаліць відарыс",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Гэты кантакт толькі для чытання. У вас няма дазволу на яго рэдагаванне.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Кантакт, які вы спрабавалі рэдагаваць, змяніўся. Абнавіце кантакт уручную. Усе далейшыя змены будуць адхілены.",
    "Address book" : "Адрасная кніга",
    "Add contact to Birthday Calendar" : "Дадаць кантакт у каляндар дзён нараджэння",
    "Exclude contact from Birthday Calendar" : "Выключыць кантакт з календара дзён нараджэння",
    "{title} at {organization}" : "{title} у {organization}",
    "Name" : "Імя",
    "Syntax error. Cannot open the contact." : "Сінтаксічная памылка. Немагчыма адкрыць кантакт.",
    "The contact does not exist on the server anymore." : "Кантакт больш не існуе на серверы.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Не ўдалося атрымаць кантакт з сервера. Праверце злучэнне з сеткай.",
    "An error occurred while trying to move the contact" : "Падчас спробы перамясціць кантакт адбылася памылка",
    "An error occurred while trying to copy the contact" : "Падчас спробы скапіяваць кантакт адбылася памылка",
    "Unable to update contact" : "Немагчыма абнавіць кантакт",
    "No contact selected" : "Не выбрана кантактаў",
    "Select a contact on the list to begin" : "Выберыце кантакт са спісу, каб пачаць",
    "Title" : "Загаловак",
    "Company" : "Кампанія",
    "Go to talk conversation" : "Перайсці да размовы ў Talk",
    "View profile" : "Праглядзець профіль",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Гэты кантакт быў пашкоджаны, а пасля выпраўлены. Праглядзіце змесціва і націсніце тут, каб захаваць яго.",
    "Edit profile" : "Рэдагаваць профіль",
    "Clone contact" : "Кланіраваць кантакт",
    "Generate QR Code" : "Згенерыраваць QR-код",
    "Contact vCard as QR code" : "vCard кантакту ў выглядзе QR-кода",
    "Pick an address book" : "Выберыце адрасную кнігу",
    "Select address book" : "Выбраць адрасную кнігу",
    "Media shares with you" : "Абагуленыя з вамі медыя",
    "Talk conversations with you" : "Размовы ў Talk з вамі",
    "Calendar events with you" : "Падзеі календара з вамі",
    "Deck cards with you" : "Карткі Deck з вамі",
    "No shared items with this contact" : "Няма абагуленых элементаў з гэтым кантактам",
    "Move" : "Перамясціць",
    "Remove from favorites" : "Выдаліць з абранага",
    "Add to favorites" : "У абранае",
    "Confirm merging contacts" : "Пацвердзіць аб'яднанне кантактаў",
    "The selected contacts have conflicting information. Choose which information to keep" : "Выбраныя кантакты маюць супярэчлівую інфармацыю. Выберыце, якую інфармацыю пакінуць.",
    "Contacts can be merged" : "Кантакты можна аб'яднаць",
    "Groups" : "Групы",
    "Select groups to add the merged contact to" : "Выберыце групы, у якія трэба дадаць аб'яднаны кантакт",
    "Merge contacts" : "Аб'яднаць кантакты",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Выдаліць {number} кантакт","Выдаліць {number} кантакты","Выдаліць {number} кантактаў","Выдаліць {number} кантактаў"],
    "Please select at least one editable contact to delete" : "Выберыце хаця б адзін кантакт для выдалення, які можна рэдагаваць",
    "Please select two editable contacts to merge" : "Выберыце два кантакты для аб'яднання, якія можна рэдагаваць",
    "Are you sure you want to proceed?" : "Вы ўпэўнены, што хочаце працягнуць?",
    "Search contacts …" : "Пошук кантактаў …",
    "Unselect {number}" : "Скасаваць выбар {number}",
    "Add to {group}" : "Дадаць у {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Звярніце ўвагу, што вы можаце дадаваць кантакты ў групы кантактаў толькі з адрасных кніг, даступных для запісу. Кантакты з адрасных кніг толькі для чытання, такіх як сістэмная адрасная кніга, дадаваць нельга.",
    "Remove {type}" : "Выдаліць {type}",
    "Add to group" : "Дадаць у групу",
    "Search {types}" : "Пошук {types}",
    "Add guest" : "Дадаць госця",
    "Search for people to add" : "Пошук людзей для дадавання",
    "No results" : "Няма вынікаў",
    "Add {type}" : "Дадаць {type}",
    "New team name" : "Назва новай каманды",
    "Personal team" : "Асабістая каманда",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Гэта каманда будзе бачная толькі вам. Іншыя ўдзельнікі не змогуць бачыць яе або карыстацца ёю.",
    "Local team" : "Лакальная каманда",
    "Create team" : "Стварыць каманду",
    "Promote as sole owner" : "Прызначыць як адзінага ўладальніка",
    "Promote to {level}" : "Павысіць да {level}",
    "Demote to {level}" : "Панізіць да {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Вы ўпэўнены, што хочаце выйсці з гэтай каманды? Гэта дзеянне нельга адрабіць.",
    "Leave team failed." : "Не ўдалося выйсці з каманды.",
    "Manage level" : "Кіраваць узроўнем",
    "Remove member" : "Выдаліць удзельніка",
    "Unable to get the results" : "Не ўдалося атрымаць вынікі",
    "Add to {team}" : "Дадаць у {team}",
    "Pending" : "У чаканні",
    "Select chart …" : "Выберыце дыяграму …",
    "Chart" : "Дыяграма",
    "Select Date" : "Выберыце дату",
    "Select type" : "Выберыце тып",
    "Add contact in group" : "Дадаць кантакт у групу",
    "None" : "Няма",
    "Select option" : "Выберыце варыянт",
    "Notes" : "Нататкі",
    "Personal dates" : "Асабістыя даты",
    "Add property of this type" : "Дадаць уласцівасць гэтага тыпу",
    "Member" : "Удзельнік",
    "Unable to create the contact." : "Немагчыма стварыць кантакт.",
    "Contact not found" : "Кантакт не знойдзены",
    "Group {group} not found" : "Група {group} не знойдзена",
    "Add member" : "Дадаць удзельніка",
    "New contact" : "Новы кантакт",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} кантакт дададзены ў {name}","{success} кантакты дададзены ў {name}","{success} кантактаў дададзена ў {name}","{success} кантактаў дададзена ў {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Ідзе дадаванне {success} кантакта ў {name}","Ідзе дадаванне {success} кантактаў ў {name}","Ідзе дадаванне {success} кантактаў ў {name}","Ідзе дадаванне {success} кантактаў ў {name}"],
    "_{count} error_::_{count} errors_" : ["{count} памылка","{count} памылкі","{count} памылак","{count} памылак"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Ідзе імпарт %n кантакта ў {addressbook}","Ідзе імпарт %n кантактаў у {addressbook}","Ідзе імпарт %n кантактаў у {addressbook}","Ідзе імпарт %n кантактаў у {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n кантакт імпартаваны ў {addressbook}","%n кантакты імпартаваны ў {addressbook}","%n кантактаў імпартавана ў {addressbook}"," %n кантактаў імпартавана ў {addressbook}"],
    "No data for this contact" : "Няма даных для гэтага кантакту",
    "No data for this contact on their profile" : "У профілі гэтага кантакту няма даных",
    "Import" : "Імпарт",
    "Are you sure you want to import this contact file?" : "Вы ўпэўнены, што хочаце імпартаваць гэты файл кантактаў?",
    "Could not copy" : "Не ўдалося скапіяваць",
    "Join team" : "Далучыцца да каманды",
    "You are about to leave {circle}.\nAre you sure?" : "Вы збіраецеся выйсці з {circle}.\nВы ўпэўнены?",
    "Please confirm team leave" : "Пацвердзіце выхад з каманды",
    "Could not leave the team {displayName}" : "Не ўдалося выйсці з каманды {displayName}",
    "Unable to join the team" : "Немагчыма далучыцца да каманды",
    "You are about to delete {circle}.\nAre you sure?" : "Вы збіраецеся выдаліць {circle}.\nВы ўпэўнены?",
    "Please confirm team deletion" : "Пацвердзіце выдаленне каманды",
    "Unable to delete the team" : "Немагчыма выдаліць каманду",
    "Link copied to the clipboard" : "Спасылка скапіявана ў буфер абмену",
    "Could not copy link to the clipboard." : "Не ўдалося скапіяваць спасылку ў буфер абмену.",
    "Not grouped" : "Без групы",
    "Organization chart" : "Арганізацыйная схема",
    "Team" : "Каманда",
    "User" : "Карыстальнік",
    "Group" : "Група",
    "Email" : "Адрас электроннай пошты",
    "Contact" : "Кантакт",
    "Moderator" : "Мадэратар",
    "Admin" : "Адміністратар",
    "Owner" : "Уладальнік",
    "Invites" : "Запрашэнні",
    "Privacy" : "Прыватнасць",
    "Visible to everyone" : "Бачны ўсім",
    "users" : "карыстальнікі",
    "Users" : "Карыстальнікі",
    "groups" : "групы",
    "teams" : "каманды",
    "email addresses" : "адрасы электроннай пошты",
    "Email addresses" : "Адрасы электроннай пошты",
    "contacts" : "кантакты",
    "Detailed name" : "Падрабязнае імя",
    "Additional names" : "Дадатковыя імёны",
    "Prefix" : "Прэфікс",
    "Suffix" : "Суфікс",
    "Nickname" : "Псеўданім",
    "Website" : "Вэб-сайт",
    "Location" : "Месцазнаходжанне",
    "Federated Cloud ID" : "Ідэнтыфікатар у федэратыўным воблаку",
    "Home" : "Дамашні",
    "Work" : "Працоўны",
    "Other" : "Іншы",
    "Address" : "Адрас",
    "Post office box" : "Паштовая скрыня",
    "Extended address" : "Пашыраны адрас",
    "City" : "Горад",
    "State or province" : "Вобласць або раён",
    "Postal code" : "Паштовы індэкс",
    "Country" : "Краіна",
    "Birthday" : "Дзень нараджэння",
    "Place of birth" : "Месца нараджэння",
    "Anniversary" : "Юбілей",
    "Date of death" : "Дата смерці",
    "Place of death" : "Месца смерці",
    "Instant messaging" : "Імгненныя паведамленні",
    "Phone" : "Тэлефон",
    "Mobile" : "Мабільны",
    "Work mobile" : "Працоўны мабільны",
    "Home mobile" : "Дамашні мабільны",
    "Fax" : "Факс",
    "Fax home" : "Дамашні факс",
    "Fax work" : "Працоўны факс",
    "Pager" : "Пэйджар",
    "Voice" : "Галасавая пошта",
    "Car" : "Аўтамабіль",
    "Work pager" : "Працоўны пэйджар",
    "Line manager" : "Лінейны менеджар",
    "Social network" : "Сацыяльная сетка",
    "Relationship to you" : "Сувязь з вамі",
    "Spouse" : "Муж/жонка",
    "Child" : "Дзіця",
    "Mother" : "Маці",
    "Father" : "Бацька",
    "Parent" : "Бацька/Маці",
    "Brother" : "Брат",
    "Sister" : "Сястра",
    "Relative" : "Сваяк",
    "Friend" : "Сябар",
    "Colleague" : "Калега",
    "Assistant" : "Памочнік",
    "Related contacts" : "Звязаныя кантакты",
    "Agent" : "Агент",
    "Emergency" : "Экстраная служба",
    "Co-worker" : "Супрацоўнік",
    "Gender" : "Пол",
    "Female" : "Жаночы",
    "Male" : "Мужчынскі",
    "Unknown" : "Невядомы",
    "Time zone" : "Часавы пояс",
    "Spoken languages" : "Мовы, на якіх размаўляе",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Не ўдалося прачытаць {failed} кантакт","Не ўдалося прачытаць {failed} кантакты","Не ўдалося прачытаць {failed} кантактаў","Не ўдалося прачытаць {failed} кантактаў"],
    "An error has occurred in team(s). Check the console for more details." : "У камандзе(-ах) адбылася памылка. Падрабязней глядзіце ў кансолі.",
    "Unable to create team {circleName}" : "Немагчыма стварыць каманду {circleName}",
    "Unable to delete team {circleId}" : "Немагчыма выдаліць каманду {circleId}",
    "Unable to delete contact" : "Немагчыма выдаліць кантакт"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
