OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Névjegyek importálása",
    "Details" : "Részletek",
    "All contacts" : "Összes névjegy",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n névjegy importálva","%n névjegy importálva"],
    "Contacts" : "Névjegyek",
    "A contacts app for Nextcloud" : "Névjegyek alkalmazás a Nextcloudhoz",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "A Nextcloud Névjegyek alkalmazás egy felhasználói felület a Nextcloud CardDAV-kiszolgálójához. Az alkalmazás segítségével könnyedén szinkronizálható a többféle eszközön meglévő névjegylista, amely szinkronizálás után online szerkeszthető.\n\n* 🚀 **Integráció más nextcloudos alkalmazásokkal!** Jelenleg a Levelek és a Naptár alkalmazással – de továbbiak várhatóak.\n* 🎉 **Ne hagyjon ki egy születésnapot sem!** A névjegyekben található születésnapok és más események szinkronizálhatók a Naptár alkalmazással.\n* 👥 **Névjegyek megosztása!** Meg akarja osztani a névjegyeit a barátaival vagy kollégáival? Nem probléma!\n* 🙈 **Nem találtuk fel újra kereket!** A nagyszerű és nyílt forráskódú SabreDav programkönyvtárra építünk.",
    "Copy to full name" : "Másolás a teljes névbe",
    "Omit year" : "Év kihagyása",
    "Allow updating avatars from social media" : "A profilképek közösségi médiából történő frissítésének engedélyezése",
    "There was an error fetching the member list" : "Hiba történt a taglista lekérésekor",
    "Please select a team" : "Válasszon egy csapatot",
    "Loading team…" : "Csapat betöltése…",
    "Loading contacts …" : "Névjegyek betöltése…",
    "There are no contacts yet" : "Még nincsenek névjegyek",
    "Create contact" : "Névjegy létrehozása",
    "There are no contacts in this group" : "Ebben a csoportban nincsenek névjegyek",
    "Create contacts" : "Névjegyek létrehozása",
    "Add contacts" : "Névjegyek hozzáadása",
    "Loading …" : "Betöltés…",
    "Manage team" : "Csapat kezelése",
    "Leave team" : "Csapat elhagyása",
    "Delete team" : "Csapat törlése",
    "Contacts settings" : "Névjegyek beállításai",
    "General" : "Általános",
    "Update avatars from social media" : "Profilképek frissítése a közösségi médiából",
    "Address books" : "Címjegyzékek",
    "Rename" : "Átnevezés",
    "Export" : "Exportálás",
    "Send email" : "E-mail küldése",
    "Send email as BCC" : "E-mail küldése rejtett másolatként",
    "Delete" : "Törlés",
    "Show all groups" : "Összes csoport megjelenítése",
    "Collapse groups" : "Csoportok összecsukása",
    "Show all teams" : "Összes csapat megjelenítése",
    "Collapse teams" : "Csapatok összecsukása",
    "Group name cannot be empty" : "A csoportnév nem lehet üres",
    "This group already exists" : "Ez a csoport már létezik",
    "An error occurred while creating the group" : "Hiba történt a csoport létrehozása során",
    "This team already exists" : "Ez a csapat már létezik",
    "An error happened during the creation of the team" : "Hiba történt a csapat létrehozása során",
    "Recently contacted" : "Legutóbbi kapcsolatfelvételek",
    "Contact groups" : "Névjegycsoportok",
    "Create a new contact group" : "Új névjegycsoport létrehozása",
    "Contact group name" : "Névjegycsoport neve",
    "Teams" : "Csapatok",
    "Create a new team" : "Új csapat létrehozása",
    "Open the contacts app settings" : "Névjegyek alkalmazás beállításainak megnyitása",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Megosztva {num} entitással","Megosztva {num} entitással"],
    "Copied" : "Másolva",
    "Cannot copy" : "Nem lehet másolni",
    "Copy link" : "Hivatkozás másolása",
    "Toggling of address book was not successful" : "A címjegyzék átváltása sikertelen",
    "This will delete the address book and every contacts within it" : "Ez törli a címjegyzéket és a benne található összes névjegyet",
    "Delete {addressbook}?" : "Törli a(z) {addressbook} címjegyzéket?",
    "This will unshare the address book and every contacts within it" : "Ez visszavonja a címjegyzék és a benne található összes névjegy megosztását",
    "Unshare {addressbook}?" : "Visszavonja a(z) {addressbook} címjegyzék megosztását?",
    "Deletion of address book was not successful." : "A címjegyzék törlése sikertelen.",
    "Renaming of address book was not successful." : "A címjegyzék átnevezése sikertelen.",
    "{addressbookname} (Hidden)" : "{addressbookname} (rejtett)",
    "Download" : "Letöltés",
    "Show" : "Megjelenítés",
    "Unshare from me" : "Megosztás visszavonása",
    "_%n contact_::_%n contacts_" : ["%n névjegy","%n névjegy"],
    "_%n group_::_%n groups_" : ["%n csoport","%n csoport"],
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "Share with users" : "Megosztás felhasználókkal",
    "No users or groups" : "Nincsenek felhasználók vagy csoportok",
    "Unable to delete the share" : "Nem lehet törölni a megosztást",
    "Unable to change permissions" : "Nem lehet megváltoztatni a jogosultságokat",
    "Choose a vCard file to import" : "Válasszon egy importálandó vCard fájlt",
    "Import into the {addressbookName} address book" : "Importálás a(z) {addressbookName} címjegyzékbe",
    "Select local file" : "Helyi fájl kiválasztása",
    "Import from files" : "Importálás fájlokból",
    "Importing is disabled because there are no address books available" : "Az importálás nincs engedélyezve mert nem található címjegyzék",
    "An error occurred, unable to create the address book" : "Hiba történt, nem sikerült létrehozni a címjegyzéket",
    "Add new address book" : "Új címjegyzék hozzáadása",
    "Cancel" : "Mégse",
    "Add" : "Hozzáadás",
    "First name" : "Utónév",
    "Last name" : "Vezetéknév",
    "Phonetic first name" : "Fonetikus utónév",
    "Phonetic last name" : "Fonetikus vezetéknév",
    "Display name" : "Név megjelenítés",
    "Last modified" : "Utoljára módosítva",
    "Manages" : "Kezeli",
    "Oversees" : "Felügyeli",
    "An error happened during the config change" : "Hiba történt a konfiguráció módosításakor",
    "Enforce password protection on files shared to this team" : "Jelszavas védelem kikényszerítése a csapattal megosztott fájlok esetén",
    "Use a unique password for all shares to this team" : "Egyéni jelszavak használata a csapat összes megosztása esetén",
    "Unique password …" : "Egyedi jelszó…",
    "Save" : "Mentés",
    "Change unique password" : "Egyedi jelszó módosítása",
    "Failed to save password. Please try again later." : "A jelszó mentése sikertelen. Próbálja újra később.",
    "Close" : "Bezárás",
    "There is no description for this team" : "Ennek a csapatnak nincs leírása",
    "Enter a description for the team" : "Adja meg a csapat leírását",
    "Folder name" : "Mappa név",
    "Conversation name" : "Beszélgetés neve",
    "An error happened while saving {fields}" : "Hiba történt a mentése során: {fields}",
    "Team name" : "Csapatnév",
    "Team owner" : "Csapattulajdonos",
    "Edit" : "Szerkesztés",
    "Request to join" : "Csatlakozás kérése",
    "Create" : "Létrehozás",
    "Your request to join this team is pending approval" : "A csapathoz való csatlakozási kérése jóváhagyásra vár",
    "You are not a member of {circle}" : "Nem tagja a(z) {circle} körnek",
    "Members" : "Tagok",
    "Confirm" : "Megerősítés",
    "Add more info" : "További információk hozzáadása",
    "More fields" : "További mezők",
    "Please select a valid format" : "Válasszon egy érvényes formátumot",
    "Invalid image" : "Érvénytelen kép",
    "Error cropping picture" : "Hiba a kép levágása során",
    "Pick an avatar" : "Profilkép választása",
    "Pick" : "Választás",
    "Error while processing the picture." : "Hiba a kép feldolgozása során.",
    "Avatar downloaded from social network" : "Profilkép letöltve a közösségi hálózatról",
    "Avatar already up to date" : "A profilkép már naprakész",
    "Avatar download failed" : "Profilkép letöltése sikertelen",
    "Crop contact photo" : "Névjegy fényképének levágása",
    "Upload a new picture" : "Új kép feltöltése",
    "Choose from Files" : "Válasszon a Fájlokból",
    "Download picture" : "Kép letöltése",
    "Delete picture" : "Kép törlése",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ez a névjegy csak olvasható. Nincs jogosultsága szerkeszteni ezt a névjegyet.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "A szerkesztett névjegy megváltozott. Frissítse kézileg a névjegyet. Minden további módosítás figyelmen kívül lesz hagyva.",
    "Address book" : "Címjegyzék",
    "Add contact to Birthday Calendar" : "Névjegy hozzáadása a születésnapok naptárához",
    "Exclude contact from Birthday Calendar" : "Névjegy kihagyása a születésnapok naptárából",
    "{title} at {organization}" : "{title} a következőnél: {organization}",
    "Name" : "Név",
    "Syntax error. Cannot open the contact." : "Szintaktikai hiba. Nem lehet megnyitni a kapcsolatot.",
    "The contact does not exist on the server anymore." : "A névjegy már nem létezik a kiszolgálón.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nem sikerült lekérni a névjegyet a kiszolgálóról, ellenőrizze a hálózati kapcsolatot.",
    "An error occurred while trying to move the contact" : "Hiba történt a névjegy áthelyezése során",
    "An error occurred while trying to copy the contact" : "Hiba történt a névjegy másolása során",
    "Unable to update contact" : "A névjegy nem frissíthető",
    "No contact selected" : "Nincs névjegy kiválasztva",
    "Select a contact on the list to begin" : "Válasszon egy névjegyet a listából a kezdéshez",
    "Title" : "Cím",
    "Company" : "Vállalat",
    "Go to talk conversation" : "Ugrás a beszélgetéshez",
    "View profile" : "Profil megtekintése",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ez a névjegy hibás volt és javítást kapott. Tekintse át a tartalmat, és kattintson ide a mentéshez.",
    "Edit profile" : "Profil szerkesztése",
    "Clone contact" : "Névjegy klónozása",
    "Generate QR Code" : "QR-kód másolása",
    "Contact vCard as QR code" : "Névjegy vCard QR-kódként",
    "Pick an address book" : "Válasszon címjegyzéket",
    "Select address book" : "Válasszon címjegyzéket",
    "Media shares with you" : "Médiaállományok megosztva Önnel",
    "Talk conversations with you" : "Beszélgetések megosztva Önnel",
    "Calendar events with you" : "Naptáresemények megosztva Önnel",
    "Deck cards with you" : "Kártyák megosztva Önnel",
    "No shared items with this contact" : "Nincsenek megosztások ezzel a névjeggyel",
    "Move" : "Move",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "Confirm merging contacts" : "Névjegyek egyesítésének megerősítése",
    "The selected contacts have conflicting information. Choose which information to keep" : "A kiválasztott névjegyek ütköző információkat tartalmaznak. Válassza ki a megtartandó információkat.",
    "Contacts can be merged" : "A névjegyek egyesíthetőek",
    "Groups" : "Csoportok",
    "Select groups to add the merged contact to" : "Válassza ki a csoportokat, amelyekhez hozzáadja az egyesített névjegyeket",
    "Merge contacts" : "Névjegyek összevonása",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["{number} névjegy törlése","{number} névjegy törlése"],
    "Please select at least one editable contact to delete" : "Válasszon legalább egy szerkeszthető névjegyet a törléshez",
    "Please select two editable contacts to merge" : "Válasszon két szerkeszthető névjegyet az egyesítéshez",
    "Are you sure you want to proceed?" : "Biztos, hogy folytatja?",
    "Search contacts …" : "Névjegyek keresése…",
    "Unselect {number}" : "{number} kiválasztásának megszüntetése",
    "Add to {group}" : "Hozzáadás a(z) {group} csoporthoz",
    "Add members to {group}" : "Tagok hozzáadása ehhez: {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Vegye figyelembe, hogy csak az írható címjegyzékekből adhat hozzá névjegyeket a névjegycsoportokhoz. Az írásvédett címjegyzékek, mint a rendszer címjegyzéke, nem adhatóak hozzá.",
    "Remove {type}" : "{type} eltávolítása",
    "Add to group" : "Hozzáadás a csoporthoz",
    "Add members to group" : "Tagok hozzáadása a csoporthoz",
    "Search {types}" : "{types} keresése",
    "Add guest" : "Vendég hozzáadása",
    "Search for people to add" : "Hozzáadandó emberek keresése",
    "No results" : "Nincs találat",
    "Add {type}" : "{type} hozzáadása",
    "New team name" : "Új csapat neve",
    "Personal team" : "Személyes csapat",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Ez a csapat csak az Ön számára látható. Más tagok nem fogják látni, és nem fogják tudni használni.",
    "Local team" : "Helyi csapat",
    "This team will not be shared with the other instances of the global scale" : "Ez a csapat nem lesz megosztva más globális léptékű példányokkal",
    "Create team" : "Csapat létrehozása",
    "Promote as sole owner" : "Előléptetés egyedüli tulajdonossá",
    "Promote to {level}" : "Előléptetés {level} szintre",
    "Demote to {level}" : "Lefokozás {level} szintre",
    "Are you sure you want to leave this team? This action cannot be undone." : "Biztos, hogy elhagyja ezt a csapatot? Ez a művelet nem vonható vissza.",
    "Leave team failed." : "A csapat elhagyása sikertelen.",
    "Could not delete the member {displayName}" : "{displayName} tagot nem sikerült törölni",
    "Could not change the member level to {level}" : "Nem sikerült a tag szintjét erre állítani: {level}",
    "Could not accept membership request" : "A tagsági kérést nem sikerült elfogadni",
    "Accept membership request" : "Csatlakozási kérés elfogadása",
    "Reject membership request" : "Csatlakozási kérés visszautasítása",
    "Manage level" : "Szint kezelése",
    "Remove member" : "Tag eltávolítása",
    "Unable to get the results" : "A találatok nem kérhetők le",
    "Some members could not be added" : "Egyes tagok nem adhatók hozzá",
    "There was an issue adding members to the team" : "Probléma lépett fel a tagok csaapthoz történő hozzáadásakor",
    "Loading members list …" : "Taglista betöltése…",
    "The list of members is only visible to members of this team" : "A taglista csak a csapattagok számára látható",
    "You currently have no access to the member list" : "Jelenleg nem fér hozzá a taglistához",
    "Add to {team}" : "Hozzáadás ehhez: {team}",
    "Invite members to {team}" : "Tagok hozzáadása ehhez: {team}",
    "Pending" : "Függőben",
    "Select chart …" : "Válasszon diagramot…",
    "Chart" : "Diagram",
    "Select Date" : "Válasszon dátumot",
    "Select type" : "Válasszon típust",
    "Add contact in group" : "Névjegy hozzáadása a csoporthoz",
    "None" : "Egyik sem",
    "Select option" : "Válasszon egy lehetőséget",
    "Notes" : "Jegyzetek",
    "Personal dates" : "Személyes dátumok",
    "Add property of this type" : "Ilyen tulajdonság hozzáadása",
    "Member" : "Tag",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Ez egy írásvédett csoport, melyet a rendszergazdák kezelnek. A csoporttagok csak megtekinthetik ezt a csoportot.",
    "Unable to create the contact." : "Nem lehet létrehozni a névjegyet.",
    "Contact not found" : "A névjegy nem található",
    "Group {group} not found" : "A(z) {group} csoport nem található",
    "Add member" : "Tag felvétele",
    "New contact" : "Új névjegy",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} névjegy hozzáadva a következőhöz: {name}","{success} névjegy hozzáadva a következőhöz: {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} névjegy hozzáadása a következőhöz: {name}","{success} névjegy hozzáadása a következőhöz: {name}"],
    "_{count} error_::_{count} errors_" : ["{count} hiba","{count} hiba"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n névjegy importálása a(z) {addressbook} címjegyzékbe","%n névjegy importálása a(z) {addressbook} címjegyzékbe"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n névjegy importálása a(z) {addressbook} címjegyzékbe befejeződött","%n névjegy importálása a(z) {addressbook} címjegyzékbe befejeződött"],
    "No data for this contact" : "Nincs adat ehhez a névjegyhez",
    "No data for this contact on their profile" : "Nincs adat ehhez a névjegyhez a profiljában",
    "Import" : "Importálás",
    "Are you sure you want to import this contact file?" : "Biztos, hogy importálja ezt a névjegyfájlt?",
    "Could not copy" : "A másolás nem sikerült",
    "Join team" : "Csatlakozás a csapathoz",
    "You are about to leave {circle}.\nAre you sure?" : "A(z) {circle} kör elhagyására készül.\nBiztos benne?",
    "Please confirm team leave" : "Erősítse meg a csapat elhagyását",
    "Could not leave the team {displayName}" : "A(z) {displayName} csapat elhagyása sikertelen",
    "Unable to join the team" : "Nem csatlakozhat ehhez a csapathoz",
    "You are about to delete {circle}.\nAre you sure?" : "A(z) {circle} kör törlésére készül.\nBiztos benne?",
    "Please confirm team deletion" : "Erősítse meg a csapat törlését",
    "Unable to delete the team" : "Nem lehet törölni a csapatot",
    "Link copied to the clipboard" : "Hivatkozás a vágólapra másolva",
    "Could not copy link to the clipboard." : "A hivatkozás másolása a vágólapra sikertelen.",
    "Not grouped" : "Nem csoportosított",
    "Organization chart" : "Szervezeti diagram",
    "Team" : "Csapat",
    "User" : "Felhasználó",
    "Group" : "Csoport",
    "Email" : "E-mail",
    "Contact" : "Névjegy",
    "Moderator" : "Moderátor",
    "Admin" : "Adminisztrátor",
    "Owner" : "Tulajdonos",
    "Invites" : "Meghívók",
    "Anyone can request membership" : "Bárki kérheti a csatlakozást",
    "Members need to accept invitation" : "A tagoknak el kell fogadniuk a meghívást",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "A tagságokat meg kell erősítenie/el kell fogadnia egy moderátornak („Bárki kérheti a csatlakozást” szükséges)",
    "Members can also invite" : "A tagok meghívhatnak másokat",
    "Membership" : "Tagság",
    "Prevent teams from being a member of another team" : "Annak megakadályozása, hogy a csapat egy másik csapat tagja legyen",
    "Privacy" : "Adatvédelem",
    "Visible to everyone" : "Mindenki számára látható",
    "users" : "felhasználó",
    "Users" : "Felhasználók",
    "groups" : "csoport",
    "teams" : "csapat",
    "email addresses" : "e-mail-cím",
    "Email addresses" : "E-mail-címek",
    "contacts" : "névjegyek",
    "Detailed name" : "Részletes név",
    "Additional names" : "További nevek",
    "Prefix" : "Előtag",
    "Suffix" : "Utótag",
    "Nickname" : "Becenév",
    "Website" : "Weboldal",
    "Location" : "Hely",
    "Federated Cloud ID" : "Föderált felhőazonosító",
    "Home" : "Otthoni",
    "Work" : "Munkahelyi",
    "Other" : "Egyéb",
    "Address" : "Cím",
    "Post office box" : "Postafiók",
    "Extended address" : "Bővített cím",
    "City" : "Város",
    "State or province" : "Állam vagy tartomány",
    "Postal code" : "Irányítószám",
    "Country" : "Ország",
    "Birthday" : "Születésnap",
    "Place of birth" : "Születési hely",
    "Anniversary" : "Évforduló",
    "Date of death" : "Halálozás dátuma",
    "Place of death" : "Elhalálozási hely",
    "Instant messaging" : "Azonnali üzenetküldés",
    "Phone" : "Telefonszám",
    "Mobile" : "Mobil",
    "Work mobile" : "Munkahelyi mobil",
    "Home mobile" : "Otthoni mobil",
    "Fax" : "Fax",
    "Fax home" : "Otthoni fax",
    "Fax work" : "Munkahelyi fax",
    "Pager" : "Személyhívó",
    "Voice" : "Hang",
    "Car" : "Autó",
    "Work pager" : "Munkahelyi csipogó",
    "Line manager" : "Felelős vezető",
    "Social network" : "Közösségi hálózat",
    "Relationship to you" : "Kapcsolat Önnel",
    "Spouse" : "Házastárs",
    "Child" : "Gyermek",
    "Mother" : "Anya",
    "Father" : "Apa",
    "Parent" : "Szülő",
    "Brother" : "Fiútestvér",
    "Sister" : "Lánytestvér",
    "Relative" : "Rokon",
    "Friend" : "Ismerős",
    "Colleague" : "Kolléga",
    "Assistant" : "Asszisztens",
    "Related contacts" : "Kapcsolódó névjegyek",
    "Agent" : "Ügynök",
    "Emergency" : "Vészhelyzet",
    "Co-worker" : "Munkatárs",
    "Gender" : "Nem",
    "Female" : "Nő",
    "Male" : "Férfi",
    "Unknown" : "Ismeretlen",
    "Time zone" : "Időzóna",
    "Spoken languages" : "Beszélt nyelvek",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} névjegyet nem sikerült olvasni","{failed} névjegyet nem sikerült olvasni"],
    "An error has occurred in team(s). Check the console for more details." : "Hiba történt a csapatokban. További részletekért nézze meg a konzolt.",
    "Unable to create team {circleName}" : "A(z) {circleName} csapat nem hozható létre",
    "Unable to delete team {circleId}" : "A(z) {circleId} csapat nem törölhető",
    "Unable to delete contact" : "A névjegy törlése sikertelen"
},
"nplurals=2; plural=(n != 1);");
