OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importuoti kontaktus",
    "Details" : "Išsamiau",
    "All contacts" : "Visi adresatai",
    "_Imported %n contact_::_Imported %n contacts_" : ["Importuotas %n kontaktas","Importuoti %n kontaktai","Importuota %n kontaktų","Importuota %n kontaktų"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(praleistas %n kontaktas)","(praleisti %n kontaktai)","(praleista %n kontaktų)","(praleista %n kontaktų)"],
    "Contacts" : "Adresatai",
    "A contacts app for Nextcloud" : "Kontaktų programėlė, skirta Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud kontaktų programėlė yra Nextcloud CardDAV serverio naudotojo sąsaja. Naudodami savo Nextcloud, lengvai sinchronizuokite kontaktus iš įvairių įrenginių ir taisykite juos internete.\n\n* 🚀 **Integracija su kitomis Nextcloud programėlėmis!** Šiuo metu su Paštu ir Kalendoriumi – greitu laiku ir su kitomis.\n* 🎉 **Niekada nepamirškite apie gimtadienį!** Galite sinchronizuoti gimtadienius ir kitus pasikartojančius įvykius naudodami savo Nextcloud Kalendorių.\n* 👥 **Adresų knygų bendrinimas!** Norite bendrinti kontaktus su savo draugais ar kolegomis? Jokių problemų!\n* 🙈 **Mes neišradinėjame dviračio!** Pagrįsta puikia ir atvira SabreDAV biblioteka.",
    "Copy to full name" : "Kopijuoti į vardą, pavardę",
    "Omit year" : "Neįtraukti metų",
    "Allow updating avatars from social media" : "Leisti atnaujinti avatarus iš socialinių tinklų",
    "There was an error fetching the member list" : "Gaunant narių sąrašą įvyko klaida",
    "Please select a team" : "Pasirinkite komandą",
    "Loading team…" : "Įkeliama komanda…",
    "Loading contacts …" : "Įkeliami kontaktai  …",
    "There are no contacts yet" : "Kol kas nėra adresatų",
    "Create contact" : "Sukurti kontaktą",
    "There are no contacts in this group" : "Šioje grupėje nėra adresatų",
    "Create contacts" : "Sukurti kontaktus",
    "Add contacts" : "Pridėti kontaktus",
    "Loading …" : "Įkeliama  …",
    "Manage team" : "Tvarkyti komandą",
    "Leave team" : "Išeiti iš komandos",
    "Delete team" : "Ištrinti komandą",
    "Setting saved" : "Nustatymas įrašytas",
    "Failed to save setting" : "Nepavyko įrašyti nustatymą",
    "Contacts settings" : "Kontaktų nustatymai",
    "General" : "Bendra",
    "Update avatars from social media" : "Atnaujinti avatarus iš socialinių tinklų",
    "Refreshed once per week" : "Atnaujinama kartą per savaitę",
    "Address books" : "Adresų knygos",
    "Tried to drop an invalid contact!" : "Bandyta pridėti neteisingą kontaktą!",
    "Rename" : "Pervadinti",
    "Export" : "Eksportuoti",
    "Send email" : "Siųsti elektroninį laišką",
    "Send email as BCC" : "Siųsti el. laišką kaip paslėptą kopiją",
    "Delete" : "Ištrinti",
    "Show all groups" : "Rodyti visas grupes",
    "Collapse groups" : "Suskleisti grupes",
    "Show all teams" : "Rodyti visas komandas",
    "Collapse teams" : "Suskleisti komandas",
    "Group name cannot be empty" : "Grupės pavadinimas negali būti tuščias",
    "This group already exists" : "Ši grupė jau yra",
    "An error occurred while creating the group" : "Kuriant grupę įvyko klaida",
    "This team already exists" : "Ši komanda jau yra",
    "An error happened during the creation of the team" : "Komandos kūrimo metu įvyko klaida",
    "Recently contacted" : "Paskiausiai susisiekta",
    "Contact groups" : "Kontaktų grupės",
    "Create a new contact group" : "Sukurti naują kontaktų grupę",
    "Contact group name" : "Kontaktų grupės pavadinimas",
    "Teams" : "Komandos",
    "Create a new team" : "Sukurti naują komandą",
    "Open the contacts app settings" : "Atverti kontaktų programėlės nustatymus",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Bendrinama su {num} subjektu","Bendrinama su {num} subjektais","Bendrinama su {num} subjektų","Bendrinama su {num} subjektų"],
    "Copied" : "Nukopijuota",
    "Cannot copy" : "Nepavyksta nukopijuoti",
    "Copy link" : "Kopijuoti nuorodą",
    "Toggling of address book was not successful" : "Adresų knygos perjungimas buvo nesėkmingas",
    "This will delete the address book and every contacts within it" : "Tai ištrins adresų knygą ir visus joje esančius kontaktus",
    "Delete {addressbook}?" : "Ištrinti {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Tai nutrauks adresų knygos ir visų joje esančių kontaktų bendrinimą",
    "Unshare {addressbook}?" : "Nustoti bendrinti {addressbook}?",
    "Deletion of address book was not successful." : "Adresų knygos ištrynimas buvo nesėkmingas.",
    "Renaming of address book was not successful." : "Adresų knygos pervadinimas buvo nesėkmingas.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Paslėptas)",
    "Download" : "Atsisiųsti",
    "Show" : "Rodyti",
    "Unshare from me" : "Nustoti bendrinti su manimi",
    "_%n contact_::_%n contacts_" : ["%n adresatas","%n adresatai","%n adresatų","%n adresatas"],
    "_%n group_::_%n groups_" : ["%n grupė","%n grupės","%n grupių","%n grupė"],
    "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
    "Share with users" : "Bendrinti su vartotojais",
    "No users or groups" : "Nėra jokių vartotojų ar grupių",
    "Unable to delete the share" : "Nepavyko ištrinti viešinio",
    "Unable to change permissions" : "Nepavyko pakeisti leidimų",
    "can create and edit" : "gali kurti ir redaguoti",
    "Choose a vCard file to import" : "Pasirinkite norimą importuoti vCard failą",
    "Import into the {addressbookName} address book" : "Importuoti į {addressbookName} adresų knygą",
    "Select local file" : "Pasirinkti vietinį failą",
    "Import from files" : "Importuoti iš failų",
    "Importing is disabled because there are no address books available" : "Importavimas yra išjungtas, nes nėra prieinamų adresų knygų",
    "An error occurred, unable to create the address book" : "Įvyko klaida, nepavyko sukurti adresų knygos",
    "New address book" : "Nauja adresų knyga",
    "Add new address book" : "Pridėti naują adresų knygą",
    "Cancel" : "Atsisakyti",
    "Add" : "Pridėti",
    "First name" : "Vardas",
    "Last name" : "Pavardė",
    "Phonetic first name" : "Fonetinis vardas",
    "Phonetic last name" : "Fonetinė pavardė",
    "Display name" : "Rodomas vardas",
    "Last modified" : "Paskutinis modifikavimas",
    "Sort contacts by" : "Rūšiuoti kontaktus pagal",
    "Manages" : "Tvarko",
    "Oversees" : "Prižiūri",
    "An error happened during the config change" : "Keičiant konfigūraciją įvyko klaida",
    "Enforce password protection on files shared to this team" : "Įjungti slaptažodžio apsaugą failams, bendrinamiems su šia komanda",
    "Use a unique password for all shares to this team" : "Visiems bendrinimams su šia komanda naudokite unikalų slaptažodį",
    "Unique password …" : "Unikalus slaptažodis  ...",
    "Save" : "Įrašyti",
    "Change unique password" : "Pakeisti unikalų slaptažodį",
    "Failed to save password. Please try again later." : "Nepavyko įrašyti slaptažodžio. Vėliau bandykite dar kartą.",
    "Close" : "Užverti",
    "There is no description for this team" : "Ši komanda neturi aprašo",
    "Enter a description for the team" : "Įveskite komandos aprašą",
    "Folder" : "Aplankas",
    "New folder" : "Naujas aplankas",
    "Folder name" : "Aplanko pavadinimas",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Tai sukurs įprastą aplanką, bendrinamą su komanda. Norėdami sukurti komandos aplanką, susisiekite su {productName} administratoriumi.",
    "Talk conversation" : "„Pokalbių\" pokalbis",
    "New Talk conversation" : "Naujas „Pokalbių\" pokalbis",
    "Conversation name" : "Pokalbio pavadinimas",
    "Collective" : "Kolektyvinis",
    "Calendar" : "Kalendorius",
    "New calendar" : "Naujas kalendorius",
    "Calendar name" : "Kalendoriaus pavadinimas",
    "Deck board" : "Darbų lenta",
    "New Deck board" : "Nauja Darbų lenta",
    "Board name" : "Lentos pavadinimas",
    "Deck app is not installed. Please install it to create team boards." : "Programėlė „Deck“ nėra įdiegta. Įdiekite ją, kad galėtumėte kurti komandos lentas.",
    "Unknown resource type" : "Nežinomas išteklių tipas",
    "Team calendar \"{resourceName}\" created and shared with team" : "Komandos kalendorius „{resourceName}“ sukurtas ir bendrinamas su komanda",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} „{resourceName}“ sukurtas ir bendrinamas su komanda",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalendorius pavadinimu „{name}“ jau yra. Pasirinkite kitą pavadinimą.",
    "Failed to create {resourceType}: {error}" : "Nepavyko sukurti {resourceType}: {error}",
    "An error happened while saving {fields}" : "Išsaugant įvyko klaida {fields}",
    "Team name" : "Komandos pavadinimas",
    "Team owner" : "Komandos savininkas",
    "Edit" : "Redaguoti",
    "Request to join" : "Prašyti prisijungti",
    "Create" : "Sukurti",
    "Show in Calendar" : "Rodyti kalendoriuje",
    "Your request to join this team is pending approval" : "Jūsų užklausa prisijungti prie šios komandos laukia patvirtinimo",
    "You are not a member of {circle}" : "Jūs nesate rato {circle} narys",
    "Members" : "Nariai",
    "Confirm" : "Patvirtinti",
    "Add more info" : "Pridėti daugiau informacijos",
    "More fields" : "Daugiau laukų",
    "Please select a valid format" : "Pasirinkite tinkamą formatą",
    "Invalid image" : "Netinkamas paveikslas",
    "Error cropping picture" : "Klaida apkerpant nuotrauką",
    "Pick an avatar" : "Pasirinkite avatarą",
    "Pick" : "Pasirinkti",
    "Error while processing the picture." : "Klaida apdorojant paveikslėlį.",
    "Avatar downloaded from social network" : "Avataras atsiųstas iš socialinio tinklo",
    "Avatar already up to date" : "Avataras jau yra naujausias",
    "Avatar download failed" : "Avataro atsiuntimas nepavyko",
    "Crop contact photo" : "Apkirpti adresato nuotrauką",
    "Upload a new picture" : "Įkelti naują paveikslą",
    "Choose from Files" : "Pasirinkti iš failų",
    "Download picture" : "Atsisiųsti paveikslėlį",
    "Delete picture" : "Ištrinti paveikslėlį",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šis adresatas yra tik skaitymo veiksenoje. Jūs neturite leidimo taisyti šį adresatą.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontaktas, kurį bandote redaguoti, pasikeitė. Įkelkite rankiniu būdu kontaktą iš naujo. Bet kokie tolimesni redagavimai bus atmesti.",
    "Address book" : "Adresų knyga",
    "Add contact to Birthday Calendar" : "Įtraukti kontaktą į gimtadienių kalendorių",
    "Exclude contact from Birthday Calendar" : "Išbraukti kontaktą iš gimtadienių kalendoriaus",
    "{title} at {organization}" : "{title} iš {organization}",
    "Name" : "Vardas",
    "Syntax error. Cannot open the contact." : "Sintaksės klaida. Nepavyko atverti adresato.",
    "The contact does not exist on the server anymore." : "Kontakto serveryje nebėra.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nepavyko gauti kontakto iš serverio, patikrinkite savo tinklo ryšį.",
    "An error occurred while trying to move the contact" : "Bandant perkelti kontaktą, įvyko klaida",
    "An error occurred while trying to copy the contact" : "Bandant nukopijuoti kontaktą, įvyko klaida",
    "Unable to update contact" : "Nepavyko atnaujinti adresato",
    "No contact selected" : "Nepasirinktas joks adresatas",
    "Select a contact on the list to begin" : "Norėdami pradėti, pasirinkite adresatą iš sąrašo",
    "Title" : "Pareigos",
    "Company" : "Kompanija",
    "Go to talk conversation" : "Naujas „Pokalbių“ pokalbis",
    "View profile" : "Rodyti profilį",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Šis kontaktas buvo sugadintas ir pataisytas. Peržiūrėkite turinį ir spustelėkite čia, norėdami kontaktą įrašyti.",
    "Edit profile" : "Redaguoti profilį",
    "Clone contact" : "Dubliuoti adresatą",
    "Generate QR Code" : "Generuoti QR kodą",
    "Contact vCard as QR code" : "Adresato vCard kaip QR kodas",
    "Pick an address book" : "Pasirinkti adresų knygą",
    "Select address book" : "Pasirinkti adresų knygą",
    "Media shares with you" : "\"Medijos failai bendrinimai su jumis",
    "Talk conversations with you" : "„Pokalbių“ pokalbiai bendrinami su jumis",
    "Calendar events with you" : "Kalendoriaus įvykiai bendrinami su jumis",
    "Deck cards with you" : "„Deck“ kortelės bendrinamos su jumis",
    "No shared items with this contact" : "Nėra bendrinamų elementų su šiuo kontaktu",
    "This contact cannot be moved" : "Šio kontakto negalima perkelti",
    "This contact cannot be grouped" : "Šio kontakto negalima priskirti grupei",
    "Add contacts to groups" : "Pridėti kontaktus prie grupių",
    "Move contacts to addressbook" : "Perkelti kontaktus į adresų knygą",
    "Select groups" : "Pasirinkti grupes",
    "Select addressbook" : "Pasirinkti adresų knygą",
    "Selected contacts" : "Pasirinkti kontaktai",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Atkreipkite dėmesį, kad į grupę galima pridėti tik {count} iš {total} kontaktų",
    "Please note that only {count} of the {total} contacts can be moved" : "Atkreipkite dėmesį, kad tik {count} iš {total} kontaktų gali būti perkelti",
    "Move" : "Perkelti",
    "Could not update favorite status" : "Nepavyko atnaujinti mėgstamiausio būsenos",
    "from {addressbook}" : "iš {addressbook}",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Confirm merging contacts" : "Patvirtinti kontaktų sujungimą",
    "The selected contacts have conflicting information. Choose which information to keep" : "Pasirinktuose kontaktuose yra prieštaringa informacija. Pasirinkite, kurią informaciją norite išsaugoti",
    "Contacts can be merged" : "Kontaktus galima sujungti",
    "Groups" : "Grupės",
    "Select groups to add the merged contact to" : "Pasirinkite grupes, į kurias norite įtraukti sujungtą kontaktą",
    "Merge contacts" : "Sujungti kontaktus",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Ištrinti {number} kontaktą","Ištrinti {number} kontaktus","Ištrinti {number} kontaktų","Ištrinti {number} kontaktų"],
    "Please select at least one editable contact to delete" : "Pasirinkite bent vieną redaguotiną kontaktą, kurį norite ištrinti",
    "Please select two editable contacts to merge" : "Pasirinkite du redaguotinus kontaktus, kuriuos norite sujungti",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Pridėkite prie grupės {number} kontaktą","Pridėkite prie grupės {number} kontaktus","Pridėkite prie grupės {number} kontaktų","Pridėkite prie grupės {number} kontaktų"],
    "Please select at least one editable contact to add to a group" : "Pasirinkite bent vieną redaguotiną kontaktą, kurį norite pridėti prie grupės",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Perkelti {number} kontaktą į adresų knygą","Perkelti {number} kontaktus į adresų knygą","Perkelti {number} kontaktų į adresų knygą","Perkelti {number} kontaktų į adresų knygą"],
    "Please select at least one editable contact to move to an addressbook" : "Pasirinkite bent vieną redaguotiną kontaktą, kurį norite perkelti į adresų knygą",
    "Are you sure you want to proceed?" : "Ar tikrai norite tęsti?",
    "Add contacts to group" : "Pridėkite kontaktus į grupę",
    "Search contacts …" : "Ieškoti kontaktų  …",
    "Unselect {number}" : "Atžymėti {number}",
    "Add to {group}" : "Pridėti į {group}",
    "Add members to {group}" : "Pridėti narius į {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Atkreipkite dėmesį, kad į kontaktų grupes galite pridėti kontaktus tik iš adresų knygų, į kurias galima rašyti. Kontaktų iš tik skaitomų adresų knygų, pvz., sistemos adresų knygos, pridėti negalima.",
    "Remove {type}" : "Šalinti {type}",
    "Add to group" : "Pridėti į grupę",
    "Add members to group" : "Pridėti narius į grupę",
    "Search {types}" : "Ieškoti {types}",
    "Add guest" : "Pridėti svečią",
    "Search for people to add" : "Ieškoti norimų pridėti žmonių",
    "No results" : "Rezultatų nėra",
    "Add {type}" : "Pridėti {type}",
    "New team name" : "Naujas komandos pavadinimas",
    "Personal team" : "Asmeninė komanda",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Ši komanda bus matoma tik jums. Kiti nariai negalės jos matyti ar ja naudotis.",
    "Local team" : "Vietinė komanda",
    "This team will not be shared with the other instances of the global scale" : "Ši komanda nebus bendrinama su kitais „Global Scale“ egzemplioriais",
    "Create team" : "Sukurti komandą",
    "Promote as sole owner" : "Skelbti kaip vienintelį savininką",
    "Promote to {level}" : "Paaukštinti į {level}",
    "Demote to {level}" : "Pažeminti iki {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Ar tikrai norite palikti šią komandą? Šio veiksmo atšaukti nebus galima.",
    "Leave team failed." : "Nepavyko išeiti iš komandos.",
    "Could not delete the member {displayName}" : "Nepavyko ištrinti nario {displayName}",
    "Could not change the member level to {level}" : "Nepavyko pakeisti nario lygį į {level}",
    "Could not accept membership request" : "Nepavyko patvirtinti prašymo tapti nariu",
    "Accept membership request" : "Priimti narystės užklausą",
    "Reject membership request" : "Atmesti narystės užklausą",
    "Manage level" : "Lygmens valdymas",
    "Remove member" : "Šalinti narį",
    "Unable to get the results" : "Nepavyko gauti rezultatų",
    "Some members could not be added" : "Kai kurių narių nepavyko pridėti",
    "There was an issue adding members to the team" : "Kilo problemų pridedant narius į komandą",
    "Loading members list …" : "Įkeliamas narių sąrašas  …",
    "The list of members is only visible to members of this team" : "Narių sąrašas yra matomas tik šios komandos nariams",
    "You currently have no access to the member list" : "Jūs šiuo metu neturite prieigos prie narių sąrašo",
    "Add to {team}" : "Pridėti į {team}",
    "Invite members to {team}" : "Pakviesti narius į {team}",
    "Pending" : "Laukiantis",
    "Select chart …" : "Pasirinkite diagramą  …",
    "Chart" : "Diagrama",
    "Select Date" : "Pasirinkti datą",
    "Select type" : "Pasirinkite tipą",
    "Add contact in group" : "Pridėti kontaktą į grupę",
    "None" : "Nėra",
    "copy" : "kopija",
    "Select option" : "Pasirinkite parinktį",
    "JavaScript URIs are not allowed" : "„JavaScript“ URI neleidžiami",
    "Notes" : "Pastabos",
    "send an email" : "siųsti el. laišką",
    "Personal dates" : "Asmeninės datos",
    "Add property of this type" : "Pridėti šio tipo savybę",
    "Member" : "Narys",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Tai yra tik skaitymo teises turinti grupė, kurią administruoja administratoriai. Grupės nariai gali tik peržiūrėti šią grupę.",
    "Unable to create the contact." : "Nepavyko sukurti adresato.",
    "Contact not found" : "Adresatas nerastas",
    "Group {group} not found" : "Grupė {group} nerasta",
    "Add member" : "Pridėti narį",
    "New contact" : "Naujas adresatas",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} adresatas sėkmingai pridėtas į {name}","{success} adresatai sėkmingai pridėti į {name}","{success} adresatų sėkmingai pridėta į {name}","{success} kontaktas sėkmingai pridėtas į {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Pridedamas {success} kontaktas į {name}","Pridedami {success} kontaktai į {name}","Pridedama {success} kontaktų į {name}","Pridedamas {success} kontaktas į {name}"],
    "_{count} error_::_{count} errors_" : ["{count} klaida","{count} klaidos","{count} klaidų","{count} klaida"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n kontaktas importuojamas į {addressbook}","%n kontaktai importuojami į {addressbook}","%n kontaktų importuojama į {addressbook}","%n kontaktas importuojamas į {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Atliktas %n adresato importavimas į {addressbook}","Atliktas %n kontaktų importavimas į {addressbook}","Atliktas %n kontaktų importavimas į {addressbook}","Atliktas %n kontakto importavimas į {addressbook}"],
    "No data for this contact" : "Nėra duomenų apie šį kontaktą",
    "No data for this contact on their profile" : "Šio kontakto profilyje nėra duomenų",
    "Import" : "Importuoti",
    "Are you sure you want to import this contact file?" : "Ar tikrai norite importuoti šį kontakto failą?",
    "Could not copy" : "Nepavyko nukopijuoti",
    "Join team" : "Prisijungti prie komandos",
    "You are about to leave {circle}.\nAre you sure?" : "Jūs ketinate išeiti iš {circle}.\nAr esate tikri?",
    "Please confirm team leave" : "Patvirtinkite išėjimą iš komandos",
    "Could not leave the team {displayName}" : "Nepavyko išeiti iš komandos {displayName}",
    "Unable to join the team" : "Nepavyko prisijungti prie komandos",
    "You are about to delete {circle}.\nAre you sure?" : "Jūs ketinate ištrinti {circle}.\nAr esate tikri?",
    "Please confirm team deletion" : "Patvirtinkite komandos ištrynimą",
    "Unable to delete the team" : "Nepavyko ištrinti komandos",
    "Confirm enabling federation" : "Patvirtinti federacijos įjungimą",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Įjungus šią funkciją, {circle} nebegalės būti kitų komandų nariu.\nAr tikrai norite tai padaryti?",
    "Enable federation" : "Įjungti federaciją",
    "Link copied to the clipboard" : "Nuoroda nukopijuota į iškarpinę",
    "Could not copy link to the clipboard." : "Nepavyko nukopijuoti nuorodos į iškarpinę.",
    "Not grouped" : "Nesugrupuoti",
    "Organization chart" : "Organizacijos diagrama",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Kurkite savo grupes bendrinimui. Pridėkite „Nextcloud“ naudotojus, kontaktus ar bet ką el. paštu.",
    "Team" : "Komanda",
    "User" : "Vartotojas",
    "Group" : "Grupė",
    "Email" : "El. paštas",
    "Contact" : "Kontaktas",
    "Moderator" : "Moderatorius",
    "Admin" : "Administratorius",
    "Owner" : "Savininkas",
    "Invites" : "Pakvietimai",
    "Anyone can request membership" : "Narystės gali prašyti bet kas",
    "Members need to accept invitation" : "Nariai turi priimti kvietimą",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Narystę turi patvirtinti/priimti moderatorius (reikalaujama, kad būtų nustatyta parinktis „Kiekvienas gali prašyti narystės“)",
    "Members can also invite" : "Nariai taip pat gali kviesti",
    "Membership" : "Narystė",
    "Prevent teams from being a member of another team" : "Neleisti komandoms būti kitos komandos nariu",
    "Federation" : "Federacija",
    "Allow federated members" : "Leisti „Federalizuotus“ narius",
    "Privacy" : "Privatumas",
    "Visible to everyone" : "Matomas visiems",
    "users" : "vartotojai",
    "Users" : "Vartotojai",
    "groups" : "grupės",
    "federated users" : "\"federuoti\" vartotojai",
    "Federated users" : "\"Federuoti\" vartotojai",
    "teams" : "komandos",
    "email addresses" : "el. pašto adresai",
    "Email addresses" : "El. pašto adresai",
    "contacts" : "kontaktai",
    "Detailed name" : "Išsamus vardas",
    "Additional names" : "Papildomi vardai",
    "Prefix" : "Priešvardis",
    "Suffix" : "Povardis",
    "Nickname" : "Slapyvardis",
    "Website" : "Svetainė",
    "Location" : "Vieta",
    "Federated Cloud ID" : "Federacinės debesijos ID",
    "Home" : "Namų",
    "Work" : "Darbo",
    "Other" : "Kita",
    "Address" : "Adresas",
    "Post office box" : "Pašto dėžutė",
    "Extended address" : "Išplėstinis adresas",
    "City" : "Miestas",
    "State or province" : "Regionas ar apskritis",
    "Postal code" : "Pašto kodas",
    "Country" : "Šalis",
    "Birthday" : "Gimtadienis",
    "Place of birth" : "Gimimo vieta",
    "Anniversary" : "Metinės",
    "Date of death" : "Mirties data",
    "Place of death" : "Mirties vieta",
    "Instant messaging" : "Momentiniai pranešimai",
    "Phone" : "Telefonas",
    "Mobile" : "Mobilusis",
    "Work mobile" : "Darbo mobilusis",
    "Home mobile" : "Namų mobilusis",
    "Fax" : "Faksas",
    "Fax home" : "Namų faksas",
    "Fax work" : "Darbo faksas",
    "Pager" : "Pranešimų gaviklis",
    "Voice" : "Balso pašto",
    "Car" : "Automobilis",
    "Work pager" : "Darbo pranešimų gaviklis",
    "Line manager" : "Tiesioginis vadovas",
    "Social network" : "Socialinis tinklas",
    "Relationship to you" : "Ryšys su jumis",
    "Spouse" : "Sutuoktinis",
    "Child" : "Vaikas",
    "Mother" : "Mama",
    "Father" : "Tėtis",
    "Parent" : "Tėvai",
    "Brother" : "Brolis",
    "Sister" : "Sesuo",
    "Relative" : "Giminaitis",
    "Friend" : "Draugas",
    "Colleague" : "Bendradarbis",
    "Assistant" : "Asistentas",
    "Related contacts" : "Susiję adresatai",
    "Agent" : "Agentas",
    "Emergency" : "Skubus atvejis",
    "Co-worker" : "Bendradarbis",
    "Gender" : "Lytis",
    "Female" : "Moteris",
    "Male" : "Vyras",
    "Unknown" : "Nežinoma",
    "Time zone" : "Laiko juosta",
    "Spoken languages" : "Šnekamosios kalbos",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Nepavyko perskaityti {failed} adresato","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresato"],
    "An error has occurred in team(s). Check the console for more details." : "Komandoje (-ose) įvyko klaida. Daugiau informacijos rasite konsolėje.",
    "Unable to create team {circleName}" : "Nepavyko sukurti komandos {circleName}",
    "Unable to delete team {circleId}" : "Nepavyko ištrinti komandos {circleId}",
    "Could not update favorite state" : "Nepavyko atnaujinti mėgstamiausio būsenos",
    "Unable to delete contact" : "Nepavyko ištrinti adresato",
    "Value copied to the clipboard" : "Vertė nukopijuota į iškarpinę",
    "Could not copy value to the clipboard." : "Nepavyko nukopijuoti vertės į iškarpinę.",
    "note" : "pastaba",
    "email" : "elektroninis paštas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
