import{_ as e,o as i,c as d,a as t,t as s,w as u,v as S,b as p,d as r,l as m,e as w,L as y}from"./modulepreload-polyfill-CCoRsF-h.chunk.mjs";const g={name:"AdminSettings",data(){return{allowSocialSync:m("contacts","allowSocialSync")==="yes"}},methods:{updateSetting(a){p.put(r("apps/contacts/api/v1/social/config/global/"+a),{allow:this[a]?"yes":"no"})}}},f={id:"contacts",class:"section"},h={for:"allow-social-sync"};function b(a,o,C,k,n,l){return i(),d("div",f,[t("h2",null,s(a.t("contacts","Contacts")),1),t("p",null,[u(t("input",{id:"allow-social-sync","onUpdate:modelValue":o[0]||(o[0]=c=>n.allowSocialSync=c),type:"checkbox",class:"checkbox",onChange:o[1]||(o[1]=c=>l.updateSetting("allowSocialSync"))},null,544),[[S,n.allowSocialSync]]),t("label",h,s(a.t("contacts","Allow updating avatars from social media")),1)])])}const v=e(g,[["render",b]]);document.addEventListener("DOMContentLoaded",x);function x(){const a=w(v);a.mixin(y),a.mount("#contacts-settings")}
//# sourceMappingURL=contacts-admin-settings.mjs.map
