OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Импорт контактов",
    "Details" : "Подробно",
    "All contacts" : "Все контакты",
    "Contacts" : "Контакты",
    "A contacts app for Nextcloud" : "Контакты для Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Приложение контакты для Nextcloud предоставляет интерфейс для сервера CardDAV, являющегося частью Nextcloud. Приложение позволяет просто настроить синхронизацию  контактов на различных устройствах с помощью Nextcloud, а также редактировать контакты, используя браузер.\n * 🚀 ** Интеграция с другими приложениями Nextcloud** Сейчас — почта и календарь, в будущем ещё больше.\n * 🎉 ** Не забывайте про дни рождения** Синхронизация дней рождения и других повторяющихся событий с календарем Nextcloud.\n * 👥 **Совместное использование адресных книг** Поделиться своими контактами с друзьями или коллегами? Нет проблем!\n* 🙈 **Мы не изобретаем колесо** Приложение основано на отличной открытой библиотеке SabreDAV.",
    "Copy to full name" : "Скопировать в полное имя",
    "Omit year" : "Пропустить год",
    "Allow updating avatars from social media" : "Разрешить обновление аватарок из соцсетей",
    "There was an error fetching the member list" : "Не удалось получить список участников",
    "Please select a team" : "Пожалуйста, выберите команду",
    "Loading team…" : "Загрузка команды…",
    "There are no contacts yet" : "Нет ни одного контакта",
    "Create contact" : "Создать контакт",
    "There are no contacts in this group" : "В этой группе нет ни одного контакта",
    "Create contacts" : "Создать контакты",
    "Add contacts" : "Добавить контакты",
    "Manage team" : "Управлять командой",
    "Leave team" : "Покинуть команду",
    "Delete team" : "Удалить команду",
    "Setting saved" : "Настройки сохранены",
    "Failed to save setting" : "Не удалось сохранить настройки",
    "Contacts settings" : "Параметры контактов",
    "General" : "Основные",
    "Update avatars from social media" : "Обновлять изображения из соц. сетей",
    "Refreshed once per week" : "Обновляется еженедельно",
    "Address books" : "Адресные книги",
    "Rename" : "Переименовать",
    "Export" : "Экспорт",
    "Send email" : "Отправить письмо",
    "Send email as BCC" : "Отправить электронное письмо как BCC",
    "Delete" : "Удалить",
    "Show all groups" : "Показать все группы",
    "Collapse groups" : "Свернуть группы",
    "Show all teams" : "Показать все команды",
    "Collapse teams" : "Сворачивать команды",
    "Group name cannot be empty" : "Название группы не может быть пустым",
    "This group already exists" : "Такая группа уже существует",
    "An error occurred while creating the group" : "При создании группы произошла ошибка",
    "This team already exists" : "Эта команда уже существует",
    "An error happened during the creation of the team" : "Произошла ошибка при создании команды",
    "Recently contacted" : "Недавние контакты",
    "Contact groups" : "Группы контакта",
    "Create a new contact group" : "Создать новую группу контактов",
    "Contact group name" : "Название группы",
    "Teams" : "Команды",
    "Create a new team" : "Создайте новую команду",
    "Open the contacts app settings" : "Откройте настройки приложения «Контакты».",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Общее для одной записи","Общее для {num} записей","Общее для {num} записей","Общее для {num} записей"],
    "Copied" : "Скопировано",
    "Cannot copy" : "Не удалось скопировать",
    "Copy link" : "Копировать ссылку",
    "Toggling of address book was not successful" : "Переключение адресной книги не удалось",
    "This will delete the address book and every contacts within it" : "Это удалит адресную книгу и все контакты в ней",
    "Delete {addressbook}?" : "Удалить {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Это приведет к отмене общего доступа к адресной книге и всем контактам в ней.",
    "Unshare {addressbook}?" : "Отменить публикацию {addressbook}?",
    "Deletion of address book was not successful." : "Удаление адресной книги не удалось.",
    "Renaming of address book was not successful." : "Переименование адресной книги не удалось.",
    "Download" : "Скачать",
    "Show" : "Показать",
    "Unshare from me" : "Отменить от меня доступ",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакта","%n контактов","%n контактов"],
    "_%n group_::_%n groups_" : ["%n группа","%n группы","%n групп","%n групп"],
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "Share with users" : "Поделиться с пользователями",
    "No users or groups" : "Пользователи или группы отсутствуют",
    "Unable to delete the share" : "Невозможно закрыть общий доступ",
    "Unable to change permissions" : "Невозможно изменить права доступа",
    "Choose a vCard file to import" : "Выберите файл в формате vCard для импорта",
    "Import into the {addressbookName} address book" : "Импортировать в адресную книгу «{addressbookName}»",
    "Select local file" : "Загрузить с ПК",
    "Import from files" : "Выбрать в Nextcloud",
    "Importing is disabled because there are no address books available" : "Возможность импорта отключена, т.к. отсутствуют адресные книги, в которые можно выполнить запись",
    "An error occurred, unable to create the address book" : "Произошла ошибка, невозможно создать адресную книгу",
    "New address book" : "Создать адресную книгу",
    "Add new address book" : "Создать адресную книгу",
    "Cancel" : "Отмена",
    "Add" : "Добавить",
    "First name" : "Имя",
    "Last name" : "Фамилия",
    "Phonetic first name" : "Имя (фонетическое написание)",
    "Phonetic last name" : "Фамилия (фонетическое написание)",
    "Display name" : "Отображаемое имя",
    "Last modified" : "Последнее изменение",
    "Manages" : "Управляет",
    "Oversees" : "Наблюдает",
    "An error happened during the config change" : "Не удалось изменить конфигурацию",
    "Enforce password protection on files shared to this team" : "Применить защиту паролем к файлам, предоставленным этой команде",
    "Use a unique password for all shares to this team" : "Используйте уникальный пароль для всех общих ресурсов этой команды",
    "Save" : "Сохранить",
    "Change unique password" : "Изменение уникального пароля",
    "Failed to save password. Please try again later." : "Не удалось сохранить пароль. Пожалуйста, повторите попытку позже.",
    "Close" : "Закрыть",
    "There is no description for this team" : "Для этой команды нет описания",
    "Enter a description for the team" : "Введите описание команды",
    "Folder name" : "Имя папки",
    "Conversation name" : "Название беседы",
    "Collective" : "Группа",
    "Calendar" : "Календарь",
    "New calendar" : "Новый календарь",
    "Calendar name" : "Название календаря",
    "Deck board" : "Доска",
    "New Deck board" : "Новая доска",
    "Board name" : "Название доски",
    "Team name" : "Название команды",
    "Team owner" : "Владелец команды",
    "Edit" : "Править",
    "Request to join" : "Присоединиться",
    "Create" : "Создавать",
    "Show in Calendar" : "Показать в календаре",
    "Your request to join this team is pending approval" : "Ваша заявка на вступление в эту команду ожидает одобрения",
    "You are not a member of {circle}" : "Вы не являетесь участником круга {circle}",
    "Members" : "Члены",
    "Confirm" : "Подтвердить",
    "Add more info" : "Добавить больше информации",
    "More fields" : "Дополнительные поля",
    "Please select a valid format" : "Пожалуйста, выберите верный формат",
    "Invalid image" : "Изображение повреждено",
    "Error cropping picture" : "Ошибка обрезки изображения",
    "Pick an avatar" : "Выбрать аватар",
    "Pick" : "Выберите",
    "Error while processing the picture." : "Ошибка при обработке изображения.",
    "Avatar downloaded from social network" : "Аватар загружен из соцсетей",
    "Avatar already up to date" : "Аватар уже обновлен",
    "Avatar download failed" : "Загрузка аватара не удалась",
    "Crop contact photo" : "Обрезать фотографию контакта",
    "Upload a new picture" : "Загрузить новое изображение",
    "Choose from Files" : "Выбрать в приложении Файлы",
    "Download picture" : "Скачать изображение",
    "Delete picture" : "Удалить изображение",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Контакт открыт в режиме «только чтение», для изменения недостаточно прав.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Контакт, который вы пытаетесь редактировать, был изменен. Выполните обновление контакта вручную. Все внесённые изменения не будут сохранены.",
    "Address book" : "Адресная книга",
    "Add contact to Birthday Calendar" : "Добавить контакт в календарь Дней Рождений",
    "Exclude contact from Birthday Calendar" : "Исключить контакт из календаря Дней Рождений",
    "{title} at {organization}" : "{title} в {organization}",
    "Name" : "Имя",
    "Syntax error. Cannot open the contact." : "Ошибка разбора синтаксиса, невозможно открыть контакт.",
    "The contact does not exist on the server anymore." : "Этого контакта больше нет на сервере.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Невозможно получить контакт с сервера, пожалуйста, проверьте ваше подключение к сети.",
    "An error occurred while trying to move the contact" : "Произошла ошибка при попытке переместить контакт",
    "An error occurred while trying to copy the contact" : "Произошла ошибка при попытке скопировать контакт",
    "Unable to update contact" : "Невозможно обновить контакт",
    "No contact selected" : "Не выбрано ни одного контакта",
    "Select a contact on the list to begin" : "Выберете контакт в списке чтобы начать",
    "Title" : "Должность",
    "Company" : "Компания",
    "Go to talk conversation" : "Перейти в обсуждение",
    "View profile" : "Показать профиль",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Поля записи контакта содержали некорректные данные, которые были исправлены. Проверьте данные и нажмите для сохранения.",
    "Edit profile" : "Изменить профиль",
    "Clone contact" : "Копировать контакт",
    "Generate QR Code" : "Создать QR-код",
    "Contact vCard as QR code" : "Визитная карточка в виде QR-кода",
    "Pick an address book" : "Выберите адресную книгу",
    "Select address book" : "Выберите адресную книгу",
    "Media shares with you" : "Для тебя поделились медиа",
    "Talk conversations with you" : "Беседовать с вами",
    "Calendar events with you" : "Календарь событий с вами",
    "Deck cards with you" : "Карточки с вами",
    "No shared items with this contact" : "Связанных с этим контактом элементов нет",
    "Remove from favorites" : "Удалить из избранного",
    "Add to favorites" : "Добавить в избранные",
    "The selected contacts have conflicting information. Choose which information to keep" : "Выбранные контакты содержат противоречивую информацию. Выберите, какую информацию сохранить.",
    "Groups" : "Группы",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Удалить {number} контакт","Удалить {number} контакта","Удалить {number} контактов","Удалить {number} контактов"],
    "Please select at least one editable contact to delete" : "Пожалуйста, выберите хотя бы один редактируемый контакт для удаления",
    "Are you sure you want to proceed?" : "Вы уверены, что хотите продолжить?",
    "Unselect {number}" : "Отменить выбор {number}",
    "Add to {group}" : "Добавить в {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Обратите внимание: вы можете добавлять в группы только контакты из доступных для записи адресных книг. Контакты из адресных книг только для чтения, таких как системная адресная книга, не могут быть добавлены.",
    "Remove {type}" : "Удалить {type}",
    "Add to group" : "Добавить в группу",
    "Search {types}" : "Поиск {types}",
    "Search for people to add" : "Поиск людей для добавления",
    "No results" : "Результаты отсутствуют",
    "Add {type}" : "Добавить {type}",
    "New team name" : "Новое название команды",
    "Personal team" : "Личная группа",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Эта команда будет видна только вам. Другие участники не смогут ее видеть или использовать.",
    "Local team" : "Местная команда",
    "This team will not be shared with the other instances of the global scale" : "Эта команда не будет использоваться совместно с другими экземплярами глобального масштаба.",
    "Create team" : "Создать команду",
    "Promote as sole owner" : "Повысить до единственного владельца",
    "Promote to {level}" : "Повысить до уровня «{level}»",
    "Demote to {level}" : "Понизить до уровня «{level}»",
    "Are you sure you want to leave this team? This action cannot be undone." : "Вы уверены, что хотите покинуть эту команду? Это действие нельзя отменить.",
    "Leave team failed." : "Не удалось покинуть команду.",
    "Could not delete the member {displayName}" : "Не удалось удалить участника {displayName}",
    "Could not change the member level to {level}" : "Не удалось изменить уровень участника на «{level}»",
    "Could not accept membership request" : "Не удалось принять запрос на участие",
    "Accept membership request" : "Принять запрос на присоединение к кругу",
    "Reject membership request" : "Отклонить запрос на присоединение к кругу",
    "Manage level" : "Управлять уровнем",
    "Remove member" : "Удалить участника",
    "Unable to get the results" : "Не удалось получить результаты запроса",
    "Some members could not be added" : "Не удалось добавить некоторых участников",
    "There was an issue adding members to the team" : "Возникла проблема с добавлением участников в команду.",
    "The list of members is only visible to members of this team" : "Список участников виден только членам этой команды.",
    "You currently have no access to the member list" : "В настоящее время у вас нет доступа к списку участников",
    "Pending" : "В очереди",
    "Chart" : "График",
    "Select Date" : "Выберите дату",
    "Select type" : "Выбор типа",
    "Add contact in group" : "Добавить контакт в группу",
    "None" : "Никто",
    "Select option" : "Выберете вариант",
    "Notes" : "Заметки",
    "Personal dates" : "Личные даты",
    "Add property of this type" : "Добавить свойство этого типа",
    "Member" : "Участник",
    "Unable to create the contact." : "Невозможно создать контакт.",
    "Contact not found" : "Контакт не найден",
    "Group {group} not found" : "Группа «{group}» не найдена",
    "Add member" : "Добавить участника",
    "New contact" : "Создать контакт",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} контакт добавлен в «{name}»","{success} контакта добавлено в «{name}»","{success} контактов добавлено в «{name}»","{success} контакта добавлено в «{name}»"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Добавление {success} контакта в «{name}»","Добавление {success} контактов в «{name}»","Добавление {success} контактов в «{name}»","Добавление {success} контактов в «{name}»"],
    "_{count} error_::_{count} errors_" : ["{count} ошибка","{count} ошибки","{count} ошибок","{count} ошибки"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Импорт %n контакта в {addressbook}","Импорт %n контактов в {addressbook}","Импорт %n контактов в {addressbook}","Импорт %n контактов в {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["В {addressbook} импортирован %n контакт","В {addressbook} импортировано %n контакта","В {addressbook} импортировано %n контактов","В {addressbook} импортировано %n контакта"],
    "No data for this contact" : "Нет данных по этому контакту",
    "No data for this contact on their profile" : "В профиле этого контакта нет данных",
    "Import" : "Импортировать",
    "Are you sure you want to import this contact file?" : "Вы уверены, что хотите импортировать этот файл контактов?",
    "Could not copy" : "Не удалось скопировать",
    "Join team" : "Присоединяйтесь к команде",
    "You are about to leave {circle}.\nAre you sure?" : "Подтвердите выход из круга «{circle}»",
    "Please confirm team leave" : "Пожалуйста, подтвердите выезд команды",
    "Could not leave the team {displayName}" : "Не смог покинуть команду {displayName}",
    "Unable to join the team" : "Невозможно присоединиться к команде",
    "You are about to delete {circle}.\nAre you sure?" : "Подтвердите удаление круга «{circle}»",
    "Please confirm team deletion" : "Пожалуйста, подтвердите удаление команды",
    "Unable to delete the team" : "Невозможно удалить команду",
    "Link copied to the clipboard" : "Ссылка скопирована в буфер обмена",
    "Could not copy link to the clipboard." : "Не удалось скопировать ссылку в буфер обмена",
    "Not grouped" : "Без группы",
    "Organization chart" : "Организационная структура",
    "Team" : "Команда",
    "User" : "Пользователь",
    "Group" : "Группа",
    "Email" : "Эл. почта",
    "Contact" : "Контакт",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Владелец",
    "Invites" : "Приглашения",
    "Anyone can request membership" : "Участие в круге доступно для всех",
    "Members need to accept invitation" : "Необходимо принятие приглашений пользователями",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Членство должно быть подтверждено/принято модератором (требуется \"Любой желающий может запросить членство\").",
    "Members can also invite" : "Разрешить приглашать участникам",
    "Membership" : "Членство",
    "Prevent teams from being a member of another team" : "Запретить командам быть членами другой команды",
    "Privacy" : "Конфиденциальность",
    "Visible to everyone" : "Видим для всех",
    "users" : "пользователи",
    "Users" : "Пользователи",
    "groups" : "группы",
    "teams" : "команды",
    "email addresses" : "адреса эл. почты",
    "Email addresses" : "Адреса электронной почты",
    "contacts" : "контакты",
    "Detailed name" : "Подробное имя",
    "Additional names" : "Отчество",
    "Prefix" : "Префикс",
    "Suffix" : "Суффикс",
    "Nickname" : "Псевдоним",
    "Website" : "Сайт",
    "Location" : "Местоположение",
    "Federated Cloud ID" : "ID в объединении облачных хранилищ",
    "Home" : "Домашний",
    "Work" : "Рабочий",
    "Other" : "Другой",
    "Address" : "Адрес",
    "Post office box" : "Абонентский ящик",
    "Extended address" : "Расширенный адрес",
    "City" : "Город",
    "State or province" : "Область или район",
    "Postal code" : "Почтовый индекс",
    "Country" : "Страна",
    "Birthday" : "День рождения",
    "Place of birth" : "Место рождения",
    "Anniversary" : "Годовщина",
    "Date of death" : "Дата смерти",
    "Place of death" : "Место смерти",
    "Instant messaging" : "Мгновенные сообщения",
    "Phone" : "Телефон",
    "Mobile" : "Мобильный",
    "Work mobile" : "Рабочий мобильный",
    "Home mobile" : "Домашний мобильный",
    "Fax" : "Факс",
    "Fax home" : "Факс домашний",
    "Fax work" : "Факс рабочий",
    "Pager" : "Пейджер",
    "Voice" : "Голосовая почта",
    "Car" : "Номер в авто",
    "Work pager" : "Рабочий пейджер",
    "Line manager" : "Линейный менеджер",
    "Social network" : "Социальная сеть",
    "Relationship to you" : "Отношение к вам",
    "Spouse" : "Супруг",
    "Child" : "Ребёнок",
    "Mother" : "Мать",
    "Father" : "Отец",
    "Parent" : "Родитель",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родственник",
    "Friend" : "Друг",
    "Colleague" : "Коллега",
    "Assistant" : "Помощник",
    "Related contacts" : "Связанные контакты",
    "Agent" : "Агент",
    "Emergency" : "Экстренный случай",
    "Co-worker" : "Коллега",
    "Gender" : "Пол",
    "Female" : "Женщина",
    "Male" : "Мужчина",
    "Unknown" : "Неизвестно",
    "Time zone" : "Часовой пояс",
    "Spoken languages" : "Разговорные языки",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} контакт не удалось прочесть","{failed} контакта не удалось прочесть","{failed} контактов не удалось прочесть","{failed} контактов не удалось прочесть"],
    "An error has occurred in team(s). Check the console for more details." : "Произошла ошибка в команде(ах). Проверьте консоль для получения более подробной информации.",
    "Unable to create team {circleName}" : "Невозможно создать команду {circleName}",
    "Unable to delete team {circleId}" : "Невозможно удалить команду {circleId}",
    "Unable to delete contact" : "Невозможно удалить контакт"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
