OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importar contactos",
    "Details" : "Detalles",
    "All contacts" : "Todos los contactos",
    "Contacts" : "Contactos",
    "A contacts app for Nextcloud" : "Una aplicción de Contactos para Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "La aplicación de Contactos de Nextcloud es una interface para el servidor CardDAV de Nextcloud. Sincroniza facilmente los contactos desde diferentes dispositivos con tu Nextcloud y editalos en línea.\n* 🚀 **¡Integración con otras aplicaciones Nextcloud!** Actualmente Correo y Calendario – mas por llegar.\n* 🎉 **¡Que nunca se te olvide un cumpleaños!** Puedes sincronizar cumpleaños y otros eventos recurrentes con tu Caldendario de Nextcloud.\n* 👥 **¡Comparte libros de direcciones!** ¿Quieres compartir tus contactos con tus amigos o colegas? ¡No hay problema!\n* 🙈 **¡No estamos reinventando la rueda!** Basado en la grandiosa librería abierta SabreDAV.",
    "Copy to full name" : "Copiar al nombre completo",
    "Omit year" : "Omitir año",
    "Allow updating avatars from social media" : "Permitir actualizar avatares desde redes sociales",
    "There was an error fetching the member list" : "Ocurrió un error al obtener la lista de miembros",
    "Please select a team" : "Por favor, seleccione un equipo",
    "Loading team…" : "Cargando equipo…",
    "There are no contacts yet" : "No hay contactos aún",
    "Create contact" : "Crear contacto",
    "There are no contacts in this group" : "No hay contactos en este grupo",
    "Create contacts" : "Crear contactos",
    "Add contacts" : "Añadir contactos",
    "Manage team" : "Administrar equipo",
    "Leave team" : "Abandonar equipo",
    "Delete team" : "Eliminar equipo",
    "Contacts settings" : "Configuración de contactos",
    "Update avatars from social media" : "Actualizar avatares desde redes sociales",
    "Address books" : "Libretas de direcciones",
    "Rename" : "Renombrar",
    "Export" : "Exportar",
    "Send email" : "Enviar correo electrónico",
    "Send email as BCC" : "Enviar correo electrónico como CCO",
    "Delete" : "Borrar",
    "Show all groups" : "Mostrar todos los grupos",
    "Collapse groups" : "Colapsar grupos",
    "Show all teams" : "Mostrar todos los equipos",
    "Collapse teams" : "Colapsar equipos",
    "This group already exists" : "Este grupo ya existe",
    "This team already exists" : "Este equipo ya existe",
    "An error happened during the creation of the team" : "Ocurrió un error durante la creación del equipo",
    "Recently contacted" : "Contactados recientemente",
    "Contact groups" : "Grupos de contactos",
    "Create a new contact group" : "Crear un nuevo grupo de contactos",
    "Contact group name" : "Nombre del grupo de contactos",
    "Teams" : "Equipos",
    "Create a new team" : "Crear un nuevo equipo",
    "Open the contacts app settings" : "Abrir la configuración de la aplicación de contactos",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidad","Compartido con {num} entidades","Compartido con {num} entidades"],
    "Copied" : "Copiado",
    "Cannot copy" : "No se puede copiar",
    "Copy link" : "Copiar liga",
    "Toggling of address book was not successful" : "No se pudo alternar la libreta de direcciones",
    "This will delete the address book and every contacts within it" : "Esto eliminará la libreta de direcciones y todos los contactos que hay en ella",
    "Delete {addressbook}?" : "¿Eliminar {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Esto dejará de compartir la libreta de direcciones y todos los contactos que hay en ella",
    "Unshare {addressbook}?" : "¿Dejar de compartir {addressbook}?",
    "Deletion of address book was not successful." : "No se pudo eliminar la libreta de direcciones.",
    "Renaming of address book was not successful." : "No se pudo renombrar de la libreta de direcciones.",
    "Download" : "Descargar",
    "Show" : "Mostrar",
    "Unshare from me" : "Dejar de compartir conmigo",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos","%n contactos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos","%n grupos"],
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Share with users" : "Compartir con usuarios",
    "No users or groups" : "No hay usuarios ni grupos",
    "Unable to delete the share" : "No se pudo eliminar el recurso compartido",
    "Unable to change permissions" : "No se pudieron cambiar los permisos",
    "Choose a vCard file to import" : "Elegir un archivo vCard para importar",
    "Import into the {addressbookName} address book" : "Importar a la libreta de direcciones {addressbookName}",
    "Select local file" : "Seleccionar archivo local",
    "Import from files" : "Importar desde archivos",
    "Importing is disabled because there are no address books available" : "La importación está deshabilitada porque no hay libretas de direcciones disponibles",
    "An error occurred, unable to create the address book" : "Ocurrió un error, no se pudo crear la libreta de direcciones",
    "Add new address book" : "Añadir una nueva libreta de direcciones",
    "Cancel" : "Cancelar",
    "Add" : "Agregar",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Phonetic first name" : "Nombre fonético",
    "Phonetic last name" : "Apellido fonético",
    "Display name" : "Nombre a desplegar",
    "Last modified" : "Última modificación",
    "Manages" : "Administra",
    "Oversees" : "Supervisa",
    "An error happened during the config change" : "Ocurrió un error durante el cambio de configuración",
    "Enforce password protection on files shared to this team" : "Imponer la protección con contraseña en los archivos compartidos a este equipo",
    "Use a unique password for all shares to this team" : "Utilizar una contraseña única para todos los recursos compartidos a este equipo",
    "Save" : "Guardar",
    "Change unique password" : "Cambiar la contraseña única",
    "Failed to save password. Please try again later." : "No se pudo guardar la contraseña. Por favor, intente de nuevo más tarde.",
    "Close" : "Cerrar",
    "There is no description for this team" : "No hay descripción para este equipo",
    "Enter a description for the team" : "Ingresar una descripción para el equipo",
    "Folder" : "Folder",
    "Team name" : "Nombre del equipo",
    "Edit" : "Editar",
    "Request to join" : "Solicitar unirse",
    "Your request to join this team is pending approval" : "Su solicitud para unirse a este equipo está pendiente de aprobación",
    "You are not a member of {circle}" : "No es miembro de {circle}",
    "Members" : "Miembros",
    "Confirm" : "Confirmar",
    "Add more info" : "Añadir más información",
    "More fields" : "Más campos",
    "Please select a valid format" : "Por favor, seleccione un formato válido",
    "Invalid image" : "Imagen inválida",
    "Error cropping picture" : "Error al recortar la imagen",
    "Pick an avatar" : "Seleccionar un avatar",
    "Error while processing the picture." : "Error al procesar la imagen.",
    "Avatar downloaded from social network" : "Avatar descargado desde red social",
    "Avatar already up to date" : "El avatar ya está actualizado",
    "Avatar download failed" : "La descarga del avatar falló",
    "Crop contact photo" : "Recortar foto de contacto",
    "Upload a new picture" : "Cargar una nueva imagen",
    "Choose from Files" : "Elegir desde Archivos",
    "Download picture" : "Descargar imagen",
    "Delete picture" : "Eliminar imagen",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "El contacto está en modo de sólo lectura. No tiene permiso para editar este contacto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que intentaba editar ha cambiado. Por favor, actualice el contacto manualmente. Cualquier otra edición será descartada.",
    "Address book" : "Libreta de direcciones",
    "Add contact to Birthday Calendar" : "Añadir contacto al calendario de cumpleaños",
    "Exclude contact from Birthday Calendar" : "Excluir contacto del calendario de cumpleaños",
    "{title} at {organization}" : "{title} en {organization}",
    "Name" : "Nombre",
    "Syntax error. Cannot open the contact." : "Error de sintaxis. No se puede abrir el contacto.",
    "The contact does not exist on the server anymore." : "El contacto ya no existe en el servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "No se pudo recuperar el contacto del servidor, por favor, compruebe su conexión de red.",
    "An error occurred while trying to move the contact" : "Ocurrió un error al intentar mover el contacto",
    "An error occurred while trying to copy the contact" : "Ocurrió un error al intentar copiar el contacto",
    "Unable to update contact" : "No se pudo actualizar el contacto",
    "No contact selected" : "Ningún contacto seleccionado",
    "Select a contact on the list to begin" : "Seleccionar un contacto de la lista para comenzar",
    "Title" : "Título",
    "Company" : "Compañía",
    "Go to talk conversation" : "Ir a la conversación de Talk",
    "View profile" : "Ver perfil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contacto estaba dañado y se ha reparado. Por favor, revise el contenido y haga clic aquí para guardarlo.",
    "Clone contact" : "Clonar contacto",
    "Generate QR Code" : "Generar código QR",
    "Contact vCard as QR code" : "vCard de contacto como código QR",
    "Pick an address book" : "Elegir una libreta de direcciones",
    "Select address book" : "Seleccionar una libreta de direcciones",
    "Media shares with you" : "Multimedia compartido con Ud.",
    "Talk conversations with you" : "Conversaciones Talk con Ud.",
    "Calendar events with you" : "Eventos de calendario con Ud.",
    "Deck cards with you" : "Tarjetas de Deck con Ud.",
    "No shared items with this contact" : "No hay elementos compartidos con este contacto",
    "Move" : "Move",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Add to {group}" : "Añadir a {group}",
    "Remove {type}" : "Eliminar {type}",
    "Add to group" : "Añadir al grupo",
    "Search {types}" : "Buscar {types}",
    "Search for people to add" : "Buscar personas para añadir",
    "No results" : "Sin resultados",
    "Add {type}" : "Añadir {type}",
    "New team name" : "Nuevo nombre del equipo",
    "Personal team" : "Equipo personal",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Este equipo sólo será visible para Ud. Otros miembros no podrán verlo ni utilizarlo.",
    "Local team" : "Equipo local",
    "This team will not be shared with the other instances of the global scale" : "Este equipo no será compartido con otras instancias de la escala global",
    "Create team" : "Crear equipo",
    "Promote as sole owner" : "Promover como único propietario",
    "Promote to {level}" : "Promover a {level}",
    "Demote to {level}" : "Descender a {level}",
    "Could not delete the member {displayName}" : "No se pudo eliminar el miembro {displayName}",
    "Could not change the member level to {level}" : "No se pudo cambiar el nivel del miembro a {level}",
    "Could not accept membership request" : "No se pudo aceptar la solicitud de membresía",
    "Accept membership request" : "Aceptar la solicitud de membresía",
    "Reject membership request" : "Rechazar la solicitud de membresía",
    "Manage level" : "Administrar el nivel",
    "Remove member" : "Eliminar miembro",
    "Unable to get the results" : "No se pudieron obtener los resultados",
    "Some members could not be added" : "No se pudieron añadir algunos miembros",
    "There was an issue adding members to the team" : "Hubo un problema al añadir miembros al equipo",
    "The list of members is only visible to members of this team" : "La lista de miembros sólo es visible para los miembros de este equipo",
    "You currently have no access to the member list" : "Actualmente no tiene acceso a la lista de miembros",
    "Pending" : "Pendiente",
    "Chart" : "Gráfico",
    "Select Date" : "Seleccionar fecha",
    "Select type" : "Seleccionar tipo",
    "Add contact in group" : "Añadir contacto en el grupo",
    "None" : "Ninguno",
    "Select option" : "Seleccionar opción",
    "Notes" : "Notas",
    "Add property of this type" : "Añadir propiedad de este tipo",
    "Member" : "Miembro",
    "Unable to create the contact." : "No se pudo crear el contacto.",
    "Contact not found" : "Contacto no encontrado",
    "Group {group} not found" : "Grupo {group} no encontrado",
    "Add member" : "Añadir miembro",
    "New contact" : "Nuevo contacto",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contacto añadido a {name}","{success} contactos añadidos a {name}","{success} contactos añadidos a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Añadiendo {success} contacto a {name}","Añadiendo {success} contactos a {name}","Añadiendo {success} contactos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errores","{count} errores"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contacto a {addressbook}","Importando %n contactos a {addressbook}","Importando %n contactos a {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importación de %n contacto a {addressbook} completada","Importación de %n contactos a {addressbook} completada","Importación de %n contactos a {addressbook} completada"],
    "Import" : "Importar",
    "Are you sure you want to import this contact file?" : "¿Está seguro de querer importar este archivo de contacto?",
    "Could not copy" : "No se pudo copiar",
    "Join team" : "Unirse al equipo",
    "You are about to leave {circle}.\nAre you sure?" : "Está a punto de abandonar {circle}.\n¿Está seguro?",
    "Please confirm team leave" : "Por favor, confirme abandonar del equipo",
    "Could not leave the team {displayName}" : "No se pudo abandonar el equipo {displayName}",
    "Unable to join the team" : "No se pudo unir al equipo",
    "You are about to delete {circle}.\nAre you sure?" : "Está a punto de eliminar {circle}.\n¿Estás seguro?",
    "Please confirm team deletion" : "Por favor, confirme la eliminación del equipo",
    "Unable to delete the team" : "No se pudo eliminar el equipo",
    "Link copied to the clipboard" : "Enlace copiado al portapapeles",
    "Could not copy link to the clipboard." : "No se pudo copiar el enlace al portapapeles.",
    "Not grouped" : "No agrupado",
    "Organization chart" : "Organigrama",
    "Team" : "Equipo",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Contact" : "Contacto",
    "Moderator" : "Moderador",
    "Admin" : "Admin",
    "Owner" : "Dueño",
    "Invites" : "Invitaciones",
    "Anyone can request membership" : "Cualquiera puede solicitar membresía",
    "Members need to accept invitation" : "Los miembros deben aceptar la invitación",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Las membresías deben ser confirmadas/aceptadas por un moderador (requiere \"Cualquiera puede solicitar membresía\")",
    "Members can also invite" : "Los miembros también pueden invitar",
    "Prevent teams from being a member of another team" : "Evitar que los equipos sean miembros de otros equipos",
    "Privacy" : "Privacidad",
    "Visible to everyone" : "Visible para todos",
    "users" : "usuarios",
    "groups" : "grupos",
    "teams" : "equipos",
    "email addresses" : "direcciones de correo electrónico",
    "Email addresses" : "Direcciones de correo electrónico",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Nickname" : "Apodo",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "Extended address" : "Dirección extendida",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Número celular de trabajo",
    "Home mobile" : "Número celular personal",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Auto",
    "Work pager" : "Localizador de trabajo",
    "Social network" : "Red social",
    "Relationship to you" : "Relación con Ud.",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Familiar",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Related contacts" : "Contactos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "Unknown" : "Desconocido",
    "Time zone" : "Zona horaria",
    "Spoken languages" : "Idiomas hablados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["No se pudo leer {failed} contacto","No se pudieron leer {failed} contactos","No se pudieron leer {failed} contactos"],
    "An error has occurred in team(s). Check the console for more details." : "Ocurrió un error en el(los) equipo(s). Compruebe la consola para más detalles.",
    "Unable to create team {circleName}" : "No se pudo crear el equipo {circleName}",
    "Unable to delete team {circleId}" : "No se pudo eliminar el equipo {circleId}",
    "Unable to delete contact" : "No se pudo eliminar el contacto"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
