.material-design-icon[data-v-f1279e47],.material-design-icon[data-v-b3e7fe94]{opacity:.8}.material-design-icon[data-v-b3e7fe94]:hover,.material-design-icon[data-v-b3e7fe94]:focus{opacity:1!important}h3[data-v-50d4633d]{font-size:22px;margin:0}.property[data-v-50d4633d]{margin-top:calc(var(--default-grid-baseline) * 3);margin-bottom:calc(var(--default-grid-baseline) * 1.5);display:flex;align-items:center}@media(max-width:1024px){.property__label[data-v-50d4633d]{width:unset}}.property__value[data-v-50d4633d]{font-weight:700}.property__value p[data-v-e8e0cada]{width:100%;overflow-wrap:break-word}.property__value--note[data-v-e359416b]{white-space:pre-line}.property__value p[data-v-e359416b]{width:100%;overflow-wrap:break-word}[data-v-e359416b] .textarea__main-wrapper{height:unset}[data-v-e359416b] .textarea__main-wrapper textarea{resize:none!important}/*!
* SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
* SPDX-License-Identifier: AGPL-3.0-or-later
*/.app-contacts #app-settings-content{padding-inline-start:0px!important}#app-settings-content .settings-section,.new-addressbook-entry{display:flex;align-items:center}#new-addressbook-form{display:flex;width:calc(100% - 44px)}#new-addressbook-form input{margin-top:0;margin-bottom:0}.settings-addressbook-list{display:flex}.settings-addressbook-list li{width:calc(100% - 44px)}.settings-addressbook-list__header{padding-inline-start:44px;color:var(--color-primary-element);padding-top:8px}.settings-line__icon{width:44px;height:44px}.sort-contacts{display:flex}.sort-contacts .multiselect{width:calc(100% - 44px);margin:0}.sort-contacts .multiselect .multiselect__single{padding-inline-end:24px!important;background-repeat:no-repeat;background-position:right 4px center}.sort-contacts .multiselect__content-wrapper{bottom:unset!important}.import-contact{display:flex;flex-direction:column}.import-contact__multiselect-label{z-index:2;width:100%;margin:0;padding:6px 12px;padding-inline-start:34px;border-radius:var(--border-radius) var(--border-radius) 0 0;background-position:left 9px center}.import-contact__multiselect-label--no-select{border-radius:var(--border-radius)}.import-contact__multiselect.multiselect{width:100%;margin:-1px 0 0}.import-contact__button-main{margin-inline-start:10px;width:calc(100% - 10px)!important}.new-addressbook .new-addressbook-input{border-color:var(--color-border-dark)}.addressbook-shares{width:100%}.addressbook-shares__list{margin-top:calc(var(--default-grid-baseline) * 2);margin-bottom:calc(var(--default-grid-baseline) * 3);display:flex;flex-direction:column}.addressbook-shares__shareematch--bold{font-weight:700}.addressbook-shares .icon-loading:after{top:70%;inset-inline-start:95%;height:14px;width:14px}.addressbook-shares .multiselect{width:inherit;margin:0}.addressbook-shares .multiselect .multiselect__tags:focus-within,.addressbook-shares .multiselect .multiselect__tags:hover{border-color:var(--color-primary-element)}.addressbook-shares .multiselect:not(.showContent) .multiselect__content-wrapper{display:none}.addressbook-sharee{padding:0 var(--default-grid-baseline);display:inline-flex;align-items:center;width:100%}.addressbook-sharee .icon{margin-inline-end:var(--default-grid-baseline);opacity:.2;width:16px;height:16px;display:inline-block;margin-bottom:calc(var(--default-grid-baseline) / 2)}.addressbook-sharee .icon.icon-loading-small{opacity:1}.addressbook-sharee__identifier{width:100%;white-space:nowrap;display:inline-block;vertical-align:top;opacity:.7}.addressbook-sharee__utils{padding:0!important;float:inline-end;position:relative!important;display:inline-flex;align-items:center;flex-shrink:0;height:20px}.addressbook-sharee__utils .icon-delete{display:inline-block;width:20px;height:20px;opacity:.4;margin-bottom:calc(var(--default-grid-baseline) / 2);margin-inline-start:var(--default-grid-baseline)}.addressbook-sharee__utils--disabled{opacity:.2!important}.addressbook-sharee__utils .checkbox{padding:0!important}.addressbook-sharee__utils label{opacity:.7}.app-content-list-item-icon{overflow:hidden}.app-content-list-item-icon__avatar{position:absolute;top:0;inset-inline-start:0;width:inherit;height:inherit;cursor:pointer;background-size:cover}/*!
 * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */.quick-action{margin-inline-end:var(--default-grid-baseline)}.property{width:100%}.property--title{display:flex;align-items:center;gap:15px}.property__row{margin-top:var(--default-grid-baseline);display:flex;align-items:center;gap:15px}.property__row input{margin-inline-end:0}.property__row:hover .property__ext{opacity:.7}.property__label{display:flex;flex:0 1 auto;justify-content:flex-end;width:200px;min-width:0}@media screen and (max-width:1024px){.property__label{width:fit-content}}.property__label>:not(.multiselect):not(.material-design-icon){overflow:hidden;white-space:nowrap;text-overflow:ellipsis;opacity:.7}.property__value{align-items:center;display:flex;flex:0 1 auto;width:300px;min-width:0}.property__value textarea{min-height:74px;max-height:394px}.property__value input,.property__value textarea{width:100%}.property__value input[readonly],.property__value textarea[readonly]{border:none;overflow:auto;outline:none;resize:none;padding:0;border-radius:0}.property__label>.multiselect,.property__value>.multiselect{width:100%;min-width:unset}.property__label>.mx-datepicker,.property__value>.mx-datepicker{width:100%}@media(max-width:1024px){.property__label{justify-content:flex-start}}.property__ext{opacity:0}.property__ext:hover,.property__ext:focus{opacity:.7}.property__actions{z-index:10;width:44px}.import-screen{width:auto;min-width:30vw;margin:50px}.import-screen__header{padding-top:20px}.import-screen__progress{width:80%;margin:auto}.import-screen__tracker{display:flex;justify-content:space-between;width:80%;margin:auto;padding-top:10px}/*!
 * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */@keyframes pulse{0%{box-shadow:0 0 #32323266}70%{box-shadow:0 0 0 15px #32323200}to{box-shadow:0 0 #32323200}}[class*="--pulse "],[class$=--pulse]{animation:pulse 1.5s infinite}.list-enter-active,.list-leave-active{transition:all .5s ease-in-out}.list-enter,.list-leave-to{opacity:0}.app-contacts .app-content-details{padding:calc(var(--default-grid-baseline) * 2);padding-top:0;height:100%;overflow:auto}@media(max-width:1024px){.app-contacts .app-content-details{height:calc(100% - 44px);padding:0 calc(var(--default-grid-baseline) * 5)}}.app-contacts .app-content-list{overflow:visible}/*!
* SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
* SPDX-License-Identifier: AGPL-3.0-or-later
*/.toastify.dialogs{min-width:200px;background:none;background-color:var(--color-main-background);color:var(--color-main-text);box-shadow:0 0 6px 0 var(--color-box-shadow);padding:0 12px;margin-top:45px;position:fixed;z-index:10100;border-radius:var(--border-radius);display:flex;align-items:center;min-height:50px}.toastify.dialogs .toast-loader-container,.toastify.dialogs .toast-undo-container{display:flex;align-items:center;width:100%}.toastify.dialogs .toast-undo-button,.toastify.dialogs .toast-close{position:static;overflow:hidden;box-sizing:border-box;min-width:44px;height:100%;padding:12px;white-space:nowrap;background-repeat:no-repeat;background-position:center;background-color:transparent;min-height:0}.toastify.dialogs .toast-undo-button.toast-close,.toastify.dialogs .toast-close.toast-close{text-indent:0;opacity:.4;border:none;min-height:44px;margin-left:10px;font-size:0}.toastify.dialogs .toast-undo-button.toast-close:before,.toastify.dialogs .toast-close.toast-close:before{background-image:url("data:image/svg+xml,%3csvg%20viewBox='0%200%2016%2016'%20height='16'%20width='16'%20xmlns='http://www.w3.org/2000/svg'%20xml:space='preserve'%20style='fill-rule:evenodd;clip-rule:evenodd;stroke-linejoin:round;stroke-miterlimit:2'%3e%3cpath%20d='M6.4%2019%205%2017.6l5.6-5.6L5%206.4%206.4%205l5.6%205.6L17.6%205%2019%206.4%2013.4%2012l5.6%205.6-1.4%201.4-5.6-5.6L6.4%2019Z'%20style='fill-rule:nonzero'%20transform='matrix(.85714%200%200%20.85714%20-2.286%20-2.286)'/%3e%3c/svg%3e");content:" ";filter:var(--background-invert-if-dark);display:inline-block;width:16px;height:16px}.toastify.dialogs .toast-undo-button.toast-undo-button,.toastify.dialogs .toast-close.toast-undo-button{height:calc(100% - 6px);margin:3px 3px 3px 12px}.toastify.dialogs .toast-undo-button:hover,.toastify.dialogs .toast-undo-button:focus,.toastify.dialogs .toast-undo-button:active,.toastify.dialogs .toast-close:hover,.toastify.dialogs .toast-close:focus,.toastify.dialogs .toast-close:active{cursor:pointer;opacity:1}.toastify.dialogs.toastify-top{right:10px}.toastify.dialogs.toast-with-click{cursor:pointer}.toastify.dialogs.toast-error{border-left:3px solid var(--color-element-error, var(--color-error))}.toastify.dialogs.toast-info{border-left:3px solid var(--color-element-info, var(--color-primary))}.toastify.dialogs.toast-warning{border-left:3px solid var(--color-element-warning, var(--color-warning))}.toastify.dialogs.toast-success,.toastify.dialogs.toast-undo{border-left:3px solid var(--color-element-success, var(--color-success))}.toastify.dialogs.toast-loading{border-left:3px solid var(--color-element-info, var(--color-primary))}.toastify.dialogs.toast-loading .toast-loader{display:inline-block;width:20px;height:20px;animation:rotate var(--animation-duration, .8s) linear infinite;margin-left:auto}.theme--dark .toastify.dialogs .toast-close.toast-close:before{background-image:url("data:image/svg+xml,%3csvg%20viewBox='0%200%2016%2016'%20height='16'%20width='16'%20xmlns='http://www.w3.org/2000/svg'%20xml:space='preserve'%20style='fill-rule:evenodd;clip-rule:evenodd;stroke-linejoin:round;stroke-miterlimit:2'%3e%3cpath%20d='M6.4%2019%205%2017.6l5.6-5.6L5%206.4%206.4%205l5.6%205.6L17.6%205%2019%206.4%2013.4%2012l5.6%205.6-1.4%201.4-5.6-5.6L6.4%2019Z'%20style='fill:%23fff;fill-rule:nonzero'%20transform='matrix(.85714%200%200%20.85714%20-2.286%20-2.286)'/%3e%3c/svg%3e")}.nc-generic-dialog .dialog__actions{justify-content:space-between;min-width:calc(100% - 12px)}._pickerEntry_xk2pl_1:not(:last-of-type){border-bottom:1px solid var(--color-border)}._pickerEntryItem_xk2pl_5{display:flex;align-items:center;height:64px}._pickerEntryIcon_xk2pl_11,._pickerEntryPreview_xk2pl_12{height:64px;width:64px;margin:0 var(--secondary-margin);display:block;flex:0 0 64px}._pickerEntryIcon_xk2pl_11{color:var(--color-text-maxcontrast)}._pickerEntryIcon_folder_xk2pl_24{color:var(--color-primary-element)}._pickerEntryPreview_xk2pl_12{overflow:hidden;border-radius:calc(var(--border-radius) * 2);object-fit:cover}._pickerEntryDescription_xk2pl_34{display:flex;flex-direction:column}._pickerEntryDescription_xk2pl_34 span{white-space:nowrap}._picker_6q4ek_1{--margin: 36px;--secondary-margin: 18px}._pickerHeader_6q4ek_6{position:sticky;z-index:10;top:0;padding:0 var(--margin);padding-bottom:var(--secondary-margin);background-color:var(--color-main-background)}._pickerForm_6q4ek_15{position:relative;overflow:auto;padding:0 var(--margin);margin-top:calc(-1 * var(--secondary-margin))}._pickerActionSubmit_disabled_6q4ek_22{opacity:.7;filter:saturate(50%)}._pickerSelectAll_6q4ek_27{display:grid;width:100%;margin-top:calc(var(--secondary-margin) * 1.5);padding-bottom:var(--secondary-margin);grid-template-columns:1fr 1fr}._pickerSelectAll_6q4ek_27 legend{display:flex;align-items:center;width:100%;margin-bottom:calc(var(--secondary-margin) / 2)}._pickerSelectAll_6q4ek_27._conflict-picker__all_6q4ek_40{position:sticky;top:0;margin:0;padding:var(--secondary-margin) 0;background-image:linear-gradient(to top,transparent,var(--color-main-background-blur) 10%,var(--color-main-background) 15%)}._pickerSelectAll_6q4ek_27._conflict-picker__all_6q4ek_40+fieldset{margin-top:0}._pickerSelectAll_6q4ek_27._conflict-picker__all_6q4ek_40 :deep(label){font-weight:700}._file-picker__file-icon_3v9zx_9{position:relative;width:32px;height:32px;min-width:32px;min-height:32px;background-repeat:no-repeat;background-size:contain;display:flex;justify-content:center}._file-picker__file-icon--primary_3v9zx_21{color:var(--color-primary-element)}._file-picker__file-icon-overlay_3v9zx_25{color:var(--color-primary-element-text);position:absolute;inset-block-start:10px}tr.file-picker__row[data-v-7857e8bd]{height:var(--row-height, 50px)}tr.file-picker__row td[data-v-7857e8bd]{cursor:pointer;overflow:hidden;text-overflow:ellipsis;border-bottom:none}tr.file-picker__row td.row-checkbox[data-v-7857e8bd]{padding:0 2px}tr.file-picker__row td[data-v-7857e8bd]:not(.row-checkbox){padding-inline:14px 0}tr.file-picker__row td.row-size[data-v-7857e8bd]{text-align:end;padding-inline:0 14px}tr.file-picker__row td.row-name[data-v-7857e8bd]{padding-inline:2px 0}.file-picker__row[data-v-7857e8bd] *{cursor:pointer}.file-picker__row--selected[data-v-7857e8bd]{background-color:var(--color-background-dark)}.file-picker__row--not-navigatable[data-v-7857e8bd]{filter:saturate(.7);opacity:.7}.file-picker__row--not-navigatable[data-v-7857e8bd] *,.file-picker__row--not-pickable[data-v-7857e8bd] *{cursor:default!important}.file-picker__row[data-v-7857e8bd]:hover{background-color:var(--color-background-hover)}.file-picker__name-container[data-v-7857e8bd]{display:flex;justify-content:start;align-items:center;height:100%}.file-picker__file-name[data-v-7857e8bd]{padding-inline-start:6px;min-width:0;overflow:hidden;text-overflow:ellipsis}.file-picker__file-extension[data-v-7857e8bd]{color:var(--color-text-maxcontrast);min-width:fit-content}/*!
* SPDX-FileCopyrightText: 2023-2024 Nextcloud GmbH and Nextcloud contributors
* SPDX-License-Identifier: AGPL-3.0-or-later
*/tr.file-picker__row[data-v-1f96131b]{height:var(--row-height, 50px)}tr.file-picker__row td[data-v-1f96131b]{cursor:pointer;overflow:hidden;text-overflow:ellipsis;border-bottom:none}tr.file-picker__row td.row-checkbox[data-v-1f96131b]{padding:0 2px}tr.file-picker__row td[data-v-1f96131b]:not(.row-checkbox){padding-inline:14px 0}tr.file-picker__row td.row-size[data-v-1f96131b]{text-align:end;padding-inline:0 14px}tr.file-picker__row td.row-name[data-v-1f96131b]{padding-inline:2px 0}@keyframes gradient-1f96131b{0%{background-position:0% 50%}50%{background-position:100% 50%}to{background-position:0% 50%}}.loading-row .row-checkbox[data-v-1f96131b]{text-align:center!important}.loading-row span[data-v-1f96131b]{display:inline-block;height:24px;background:linear-gradient(to right,var(--color-background-darker),var(--color-text-maxcontrast),var(--color-background-darker));background-size:600px 100%;border-radius:var(--border-radius);animation:gradient-1f96131b 12s ease infinite}.loading-row .row-wrapper[data-v-1f96131b]{display:inline-flex;align-items:center}.loading-row .row-checkbox span[data-v-1f96131b]{width:24px}.loading-row .row-name span[data-v-1f96131b]:last-of-type{margin-inline-start:6px;width:130px}.loading-row .row-size span[data-v-1f96131b]{width:80px}.loading-row .row-modified span[data-v-1f96131b]{width:90px}.file-picker__header-preview[data-v-412efd5c]{width:22px;height:32px;flex:0 0 auto}.file-picker__files[data-v-412efd5c]{margin:2px;margin-inline-start:12px;overflow:scroll auto}.file-picker__files table[data-v-412efd5c]{width:100%;max-height:100%;table-layout:fixed}.file-picker__files th[data-v-412efd5c]{position:sticky;z-index:1;top:0;background-color:var(--color-main-background);padding:2px}.file-picker__files th .header-wrapper[data-v-412efd5c]{display:flex}.file-picker__files th.row-checkbox[data-v-412efd5c]{width:44px}.file-picker__files th.row-name[data-v-412efd5c]{width:230px}.file-picker__files th.row-size[data-v-412efd5c]{width:100px}.file-picker__files th.row-modified[data-v-412efd5c]{width:120px}.file-picker__files th[data-v-412efd5c]:not(.row-size) .button-vue__wrapper{justify-content:start;flex-direction:row-reverse}.file-picker__files th[data-v-412efd5c]:not(.row-size) .button-vue{padding-inline:16px 4px}.file-picker__files th.row-size[data-v-412efd5c] .button-vue__wrapper{justify-content:end}.file-picker__files th[data-v-412efd5c] .button-vue__wrapper{color:var(--color-text-maxcontrast)}.file-picker__files th[data-v-412efd5c] .button-vue__wrapper .button-vue__text{font-weight:400}.file-picker__breadcrumbs[data-v-b448b141]{flex-grow:0!important}.file-picker__side[data-v-e1c54e23]{display:flex;flex-direction:column;align-items:stretch;gap:.5rem;min-width:200px;padding:2px;margin-block-start:7px;overflow:auto}.file-picker__side[data-v-e1c54e23] .button-vue__wrapper{justify-content:start}.file-picker__filter-input[data-v-e1c54e23]{margin-block:7px;max-width:260px}@media(max-width:736px){.file-picker__side[data-v-e1c54e23]{flex-direction:row;min-width:unset}}@media(max-width:512px){.file-picker__side[data-v-e1c54e23]{flex-direction:row;min-width:unset}.file-picker__filter-input[data-v-e1c54e23]{max-width:unset}}.file-picker__navigation{padding-inline:8px 2px}.file-picker__navigation,.file-picker__navigation *{box-sizing:border-box}.file-picker__navigation .v-select.select{min-width:220px}@media(min-width:513px)and (max-width:736px){.file-picker__navigation{gap:11px}}@media(max-width:512px){.file-picker__navigation{flex-direction:column-reverse!important}}.file-picker__view[data-v-9b6534b1]{height:50px;display:flex;justify-content:start;align-items:center}.file-picker__view h3[data-v-9b6534b1]{font-weight:700;height:fit-content;margin:0}.file-picker__main[data-v-9b6534b1]{box-sizing:border-box;width:100%;display:flex;flex-direction:column;min-height:0;flex:1;padding-inline:2px}.file-picker__main[data-v-9b6534b1] *{box-sizing:border-box}[data-v-9b6534b1] .file-picker{height:min(80vh,800px)!important}@media(max-width:512px){[data-v-9b6534b1] .file-picker{height:calc(100% - 16px - var(--default-clickable-area))!important}}[data-v-9b6534b1] .file-picker__content{display:flex;flex-direction:column;overflow:hidden}.public-auth-prompt__text[data-v-bd4b7f1b]{font-size:1.25em;margin-block:0 calc(3 * var(--default-grid-baseline))}.public-auth-prompt__header[data-v-bd4b7f1b]{margin-block:0 calc(3 * var(--default-grid-baseline))}.public-auth-prompt__header[data-v-bd4b7f1b]:first-child{margin-top:0}.public-auth-prompt__input[data-v-bd4b7f1b]{margin-block:calc(4 * var(--default-grid-baseline)) calc(2 * var(--default-grid-baseline))}
