OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importovať kontakty",
    "Details" : "Podrobnosti",
    "All contacts" : "Všetky kontakty",
    "_Imported %n contact_::_Imported %n contacts_" : ["Naimportovaný %n kontakt","Naimportovaných %n kontaktov","Naimportovaných %n kontaktov","Naimportované %n kontakty"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(vynechaný %n kontakt)","(vynechaných %n kontaktov)","(vynechaných %n kontaktov)","(vynechané %n kontakty)"],
    "Contacts" : "Kontakty",
    "A contacts app for Nextcloud" : "Apka kontaktov pre Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Aplikácia Nextcloud kontakty je používateľské rozhranie pre Nextcloud CardDAV server.  Jednoducho synchronizujte kontakty z rôznych zariadení s Vaším Nextcloud a upravujte ich online.\n\n* 🚀 **Integrácia s ostatnými Nextcloud aplikáciami!** V súčasnosti Mail a Calendar - ďalšie pribudnú neskôr.\n* 🎉 **Nikdy nezabudnite na narodeniny!** Môžete synchronizovať narodeniny a iné opakujúce sa udalosti s Vašim Nextcloud Calendar.\n* 👥 **Zdieľanie adresárov!** Chcete zdieľat Vaše kontakty priateľom alebo spolupracovníkom? Bez problémov!\n* 🙈 **Nevynachádzame koleso!** Založené na vynikajúcej a otvorenej knižnici SabreDAV.",
    "Copy to full name" : "Kopírovať na celé meno",
    "Omit year" : "Vynechať rok",
    "Allow updating avatars from social media" : "Povoliť aktualizáciu avatarov zo sociálnych médií",
    "There was an error fetching the member list" : "Pri načítavaní zoznamu členov sa vyskytla chyba",
    "Please select a team" : "Vyberte tím",
    "Loading team…" : "Načítavanie tímu...",
    "Loading contacts …" : "Načítavajú sa kontakty ...",
    "There are no contacts yet" : "Zatiaľ tu nie sú žiadne kontakty.",
    "Create contact" : "Vytvoriť kontakt",
    "There are no contacts in this group" : "V tejto skupine nie sú žiadne kontakty",
    "Create contacts" : "Vytvoriť kontakty",
    "Add contacts" : "Pridať kontakty",
    "Loading …" : "Načítava sa …",
    "Manage team" : "Spravovať tím",
    "Leave team" : "Opustiť tím",
    "Delete team" : "Zmazať tím",
    "Setting saved" : "Nastavenia uložené",
    "Failed to save setting" : "Nepodarilo sa uložiť nastavenie",
    "Contacts settings" : "Nastavenia kontaktov",
    "General" : "Všeobecné",
    "Update avatars from social media" : "Aktualizovať avatarov zo sociálneho média",
    "Refreshed once per week" : "Obnovované raz týždenne",
    "Address books" : "Adresáre",
    "Tried to drop an invalid contact!" : "Snažil sa pridať neplatný kontakt!",
    "Rename" : "Premenovať",
    "Export" : "Export",
    "Send email" : "Odoslať email",
    "Send email as BCC" : "Poslať e-mail ako BCC",
    "Delete" : "Zmazať",
    "Show all groups" : "Zobraziť všetky skupiny",
    "Collapse groups" : "Zbaliť skupiny",
    "Show all teams" : "Zobraziť všetky tímy",
    "Collapse teams" : "Schovať tímy",
    "Group name cannot be empty" : "Názov skupiny nemôže byť prázdny",
    "This group already exists" : "Táto skupina už existuje",
    "An error occurred while creating the group" : "Pri vytváraní skupiny sa vyskytla chyba",
    "This team already exists" : "Tento tím už existuje",
    "An error happened during the creation of the team" : "Pri vytváraní tímu sa stala chyba",
    "Recently contacted" : "Nedávno kontaktovaní",
    "Contact groups" : "Skupiny kontaktov",
    "Create a new contact group" : "Vytvoriť novú skupinu kontaktov",
    "Contact group name" : "Meno skupiny kontaktov",
    "Teams" : "Tímy",
    "Create a new team" : "Vytvoriť nový tím",
    "Open the contacts app settings" : "Otvoriť nastavenia aplikácie Kontakty",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Zdieľané s {num} entitou","Zdieľané s {num} entitami","Zdieľané s {num} entitami","Zdieľané s {num} entitami"],
    "Copied" : "Skopírované",
    "Cannot copy" : "Nemôžem kopírovať",
    "Copy link" : "Kopírovať odkaz",
    "Toggling of address book was not successful" : "Zapnutie/vypnutie adresára nebolo úspešné",
    "This will delete the address book and every contacts within it" : "Týmto sa odstráni adresár a všetky kontakty v ňom",
    "Delete {addressbook}?" : "Zmazať {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Týmto sa zruší zdieľanie adresára a všetkých kontaktov v ňom",
    "Unshare {addressbook}?" : "Zrušiť zdieľanie {addressbook}?",
    "Deletion of address book was not successful." : "Odstránenie adresára nebolo úspešné.",
    "Renaming of address book was not successful." : "Premenovanie adresára nebolo úspešné.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Skryté)",
    "Download" : "Stiahnuť",
    "Show" : "Zobraziť",
    "Unshare from me" : "Zrušiť zdieľanie so mnou",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontaktov","%n kontaktov","%n kontaktov"],
    "_%n group_::_%n groups_" : ["%n skupina","%n skupiny","%n skupín","%n skupín"],
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "Share with users" : "Zdieľať s používateľmi",
    "No users or groups" : "Žiadny používatelia alebo skupiny",
    "Unable to delete the share" : "Nepodarilo sa zmazať zdieľanie.",
    "Unable to change permissions" : "Nepodarilo sa zmeniť oprávnenia",
    "can create and edit" : "môže vytvárať a upravovať",
    "Choose a vCard file to import" : "Vyberte súbor vCard, ktorý chcete importovať",
    "Import into the {addressbookName} address book" : "Importovať do {addressbookName} adresára",
    "Select local file" : "Vybrať miestny súbor",
    "Import from files" : "Importovať zo súborov",
    "Importing is disabled because there are no address books available" : "Nie je možné importovať, pretože neexistuje ani jeden adresár kontaktov",
    "An error occurred, unable to create the address book" : "Vyskytla sa chyba, nepodarilo sa vytvoriť adresár",
    "New address book" : "Nový adresár",
    "Add new address book" : "Pridať nový adresár",
    "Cancel" : "Zrušiť",
    "Add" : "Add",
    "First name" : "Krstné meno",
    "Last name" : "Priezvisko",
    "Phonetic first name" : "Meno foneticky",
    "Phonetic last name" : "Priezvisko foneticky",
    "Display name" : "Zobrazované meno",
    "Last modified" : "Naposledy zmenené",
    "Sort contacts by" : "Zoradiť kontakty podľa",
    "Manages" : "Spravuje",
    "Oversees" : "Dohliada",
    "An error happened during the config change" : "Pri zmene konfigurácie sa stala chyba",
    "Enforce password protection on files shared to this team" : "Vyžadovať ochranu heslom pre súbory nazdieľané tomuto tímu",
    "Use a unique password for all shares to this team" : "Použiť unikátne heslo pre všetko zdieľané v tomto tíme.",
    "Unique password …" : "Unikátne heslo ...",
    "Save" : "Uložiť",
    "Change unique password" : "Zmeniť unikátne heslo",
    "Failed to save password. Please try again later." : "Uloženie hesla zlyhalo. Prosím skúste to znova neskôr.",
    "Close" : "Zavrieť",
    "There is no description for this team" : "Tím nemá žiadny popis",
    "Enter a description for the team" : "Vložte popis tímu",
    "Folder" : "Folder",
    "New folder" : "Nový priečinok",
    "Folder name" : "Názov priečinka",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Týmto sa vytvorí bežná zložka zdieľaná s tímom. Ak chcete vytvoriť tímovú zložku, kontaktujte prosím svojho {productName} administrátora.",
    "Talk conversation" : "Konverzácia v Talk /Rozhovore/",
    "New Talk conversation" : "Nová Konverzácia v Talk /Rozhovore/",
    "Conversation name" : "Názov rozhovoru",
    "Collective" : "Kolektív",
    "Calendar" : "Kalendár",
    "New calendar" : "Nový kalendár",
    "Calendar name" : "Názov kalendára",
    "Deck board" : "Nástenka aplikácie Deck",
    "New Deck board" : "Nová nástenka aplikácie Deck",
    "Board name" : "Názov nástenky",
    "Deck app is not installed. Please install it to create team boards." : "Aplikácia Deck nie je nainštalovaná. Nainštalujte ju, aby ste mohli vytvárať tímové nástenky.",
    "Unknown resource type" : "Neznámy typ zdroja",
    "Team calendar \"{resourceName}\" created and shared with team" : "Kalendár tímu \"{resourceName}\" bol vytvorený a zdieľaný s tímom.",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" bolo vytvorené a zdieľané s tímom",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalendár s názvom \"{name}\" už existuje. Vyberte prosím iný názov.",
    "Failed to create {resourceType}: {error}" : "Nepodarilo sa vytvoriť {resourceType}: {error}",
    "An error happened while saving {fields}" : "Došlo k chybe pri ukladaní {fields}.",
    "Team name" : "Názov tímu",
    "Team owner" : "Vlastník tímu",
    "Edit" : "Upraviť",
    "Request to join" : "Požiadať o pripojenie",
    "Create" : "Vytvoriť",
    "Show in Calendar" : "Zobraziť v Kalendári",
    "Your request to join this team is pending approval" : "Vaša požiadavka na pripojenie k tomuto tímu čaká na schválenie",
    "You are not a member of {circle}" : "Nie ste členom {circle}",
    "Members" : "Členovia",
    "Confirm" : "Potvrdiť",
    "Add more info" : "Pridať viac informácií",
    "More fields" : "Viac možnosťí",
    "Please select a valid format" : "Vyberte prosím platný formát",
    "Invalid image" : "Chybný obrázok",
    "Error cropping picture" : "Chyba počas orezávania obrázku",
    "Pick an avatar" : "Zvoľte si avatar",
    "Pick" : "Vybrať",
    "Error while processing the picture." : "Chyba pri spracovaní obrázka.",
    "Avatar downloaded from social network" : "Avatar stiahnutý zo sociálnej siete",
    "Avatar already up to date" : "Avatar už je aktuálny",
    "Avatar download failed" : "Stiahnutie avataru zlyhalo",
    "Crop contact photo" : "Orezať kontaktnú fotografiu",
    "Upload a new picture" : "Nahrať nový obrázok",
    "Choose from Files" : "Vybrať zo Súborov",
    "Download picture" : "Stiahnuť obrázok",
    "Delete picture" : "Zmazať obrázok",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tento kontakt je iba na čítanie. Nemáte oprávnenie na úpravu tohto kontaktu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt ktorý sa snažíte modifikovať sa zmenil.  Prosím manuálne obnovte kontakt.  Akékoľvek ďalšie zmeny nebudú brané do úvahy.",
    "Address book" : "Adresár",
    "Add contact to Birthday Calendar" : "Pridať kontakt do Kalendára narodenín",
    "Exclude contact from Birthday Calendar" : "Odobrať kontakt z Kalendára Narodenín",
    "{title} at {organization}" : "{title} v {organization}",
    "Name" : "Meno",
    "Syntax error. Cannot open the contact." : "Chyba zápisu. Nepodarilo sa otvoriť kontakt.",
    "The contact does not exist on the server anymore." : "Kontakt už na serveri neexistuje.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nepodarilo sa načítať kontakt zo servera, skontrolujte sieťové pripojenie.",
    "An error occurred while trying to move the contact" : "Pri pokuse o presun kontaktu sa vyskytla chyba",
    "An error occurred while trying to copy the contact" : "Pri pokuse o skopírovanie kontaktu sa vyskytla chyba",
    "Unable to update contact" : "Nepodarilo sa aktualizovať kontakt",
    "No contact selected" : "Vyberte aspoň jeden kontakt",
    "Select a contact on the list to begin" : "Pre začatie vyberte kontakt zo zoznamu",
    "Title" : "Funkcia",
    "Company" : "Spoločnosť",
    "Go to talk conversation" : "Prejsť na konverzáciu v Talk /Rozhovore/",
    "View profile" : "Zobraziť profil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Tento kontakt bol opravený. Overte prosím obsah a kliknite pre uloženie.",
    "Edit profile" : "Upraviť profil",
    "Clone contact" : "Duplikovať kontakt",
    "Generate QR Code" : "Vygenerovať QR kód",
    "Contact vCard as QR code" : "Zobraziť QR kód vCard kontaktu",
    "Pick an address book" : "Vybrať adresár",
    "Select address book" : "Označiť adresár",
    "Media shares with you" : "Mediá zdieľané s vami",
    "Talk conversations with you" : "Talk konverzácie s vami",
    "Calendar events with you" : "Kalendárne udalosti s vami",
    "Deck cards with you" : "Karty Desk s vami",
    "No shared items with this contact" : "Žiadne zdieľané položky s týmto kontaktom",
    "This contact cannot be moved" : "Tento kontakt nemožno presunúť",
    "This contact cannot be grouped" : "Tento kontakt nemožno zaradiť do skupiny",
    "Add contacts to groups" : "Pridať kontakty do skupín",
    "Move contacts to addressbook" : "Presunúť kontakty do adresára",
    "Select groups" : "Vybrať skupiny",
    "Select addressbook" : "Vybrať adresár",
    "Selected contacts" : "Vybrané kontakty",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Vezmite prosím na vedomie, že iba {count} z {total} kontaktov môže byť pridaných do skupiny.",
    "Please note that only {count} of the {total} contacts can be moved" : "Vezmite prosím na vedomie, že iba {count} z {total} kontaktov môže byť presunutých.",
    "Move" : "Move",
    "from {addressbook}" : "z {addressbook}",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Pridať k obľúbeným",
    "Confirm merging contacts" : "Potvrdiť zlúčenie kontaktov",
    "The selected contacts have conflicting information. Choose which information to keep" : "Vybrané kontakty obsahujú konfliktné informácie. Vyberte, ktoré informácie chcete zachovať.",
    "Contacts can be merged" : "Kontakty môžu byť zlúčené",
    "Groups" : "Skupiny",
    "Select groups to add the merged contact to" : "Vyberte skupiny, do ktorých chcete pridať zlúčený kontakt",
    "Merge contacts" : "Zlúčiť kontakty",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Vymazať {number} kontakt","Vymazať {number} kontaktov","Vymazať {number} kontaktov","Vymazať {number} kontakty"],
    "Please select at least one editable contact to delete" : "Vyberte aspoň jeden upraviteľný kontakt na vymazanie.",
    "Please select two editable contacts to merge" : "Vyberte dva upraviteľné kontakty na zlúčenie.",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Pridať {number} kontakt do skupiny","Pridať {number} kontaktov do skupiny","Pridať {number} kontaktov do skupiny","Pridať {number} kontakty do skupiny"],
    "Please select at least one editable contact to add to a group" : "Vyberte aspoň jeden editovateľný kontakt, ktorý chcete pridať do skupiny",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Presuňte {number} kontakt do adresára","Presuňte {number} kontaktov do adresára","Presuňte {number} kontaktov do adresára","Presuňte {number} kontakty do adresára"],
    "Please select at least one editable contact to move to an addressbook" : "Vyberte aspoň jeden upraviteľný kontakt na presun do adresára",
    "Are you sure you want to proceed?" : "Ste si istí, že chcete pokračovať?",
    "Add contacts to group" : "Pridať kontakty do skupiny",
    "Search contacts …" : "Prehľadať kontakty...",
    "Unselect {number}" : "Zrušiť výber {number}",
    "Add to {group}" : "Pridať do {group}",
    "Add members to {group}" : "Pridať členov do {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Upozorňujeme, že do kontaktných skupín môžete pridať iba kontakty z adresárov, ktoré sú zapisovateľné. Kontakty z adresárov iba na čítanie, ako je systémový adresár, pridať nemôžete.",
    "Remove {type}" : "Odstrániť {type}",
    "Add to group" : "Pridať do skupiny",
    "Add members to group" : "Pridať členov do skupiny",
    "Search {types}" : "Vyhľadať {types}",
    "Add guest" : "Pridať hosťa",
    "Search for people to add" : "Vyhľadať ľudí pre pridanie",
    "No results" : "Žiadne výsledky",
    "Add {type}" : "Pridať {type}",
    "New team name" : "Nové meno tímu",
    "Personal team" : "Osobný tím",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Tento tím bude viditeľný iba pre vás. Ostatní členovia ho nebudú vidieť ani ho používať.",
    "Local team" : "Lokálny tím",
    "This team will not be shared with the other instances of the global scale" : "Tento tím nebude zdieľaný z inými inštanciami globálneho rozsahu.",
    "Create team" : "Vytvoriť tím",
    "Promote as sole owner" : "Povýšiť ako jediný vlastník",
    "Promote to {level}" : "Povýšiť na {level}",
    "Demote to {level}" : "Degradovať na {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Ste si istí, že chcete opustiť tento tím? Túto akciu nie je možné vrátiť späť.",
    "Leave team failed." : "Opustenie tímu zlyhalo.",
    "Could not delete the member {displayName}" : "Nemôžem vymazať člena {displayName}",
    "Could not change the member level to {level}" : "Nemôžem zmeniť úroveň člena na {level}",
    "Could not accept membership request" : "Nie je možné prijať žiadosť o členstvo",
    "Accept membership request" : "Prijať žiadosť o členstvo",
    "Reject membership request" : "Odmietnuť žiadosť o členstvo",
    "Manage level" : "Spravovať úroveň",
    "Remove member" : "Odstrániť člena",
    "Unable to get the results" : "Nemôžem získať výsledky",
    "Some members could not be added" : "Niektorých členov nie je možné pridať",
    "There was an issue adding members to the team" : "Nastala chyba pri pridávaní členov do tímu",
    "Loading members list …" : "Načítavanie zoznamu členov …",
    "The list of members is only visible to members of this team" : "Zoznam členov je viditeľný iba pre členov tohto tímu",
    "You currently have no access to the member list" : "Momentálne nemáte prístup k zoznamu členov",
    "Add to {team}" : "Pridať do {team}",
    "Invite members to {team}" : "Pozvať členov do {team}",
    "Pending" : "Čakajúce",
    "Select chart …" : "Vybrať graf ...",
    "Chart" : "Graf",
    "Select Date" : "Vybrať dátum",
    "Select type" : "Vyberte typ",
    "Add contact in group" : "Pridať kontakt do skupiny",
    "None" : "Žiadne",
    "copy" : "kopírovať",
    "Select option" : "Vyberte možnosť",
    "JavaScript URIs are not allowed" : "JavaScript URI nie sú povolené",
    "Notes" : "Poznámky",
    "send an email" : "odoslať e-mail",
    "Personal dates" : "Osobné termíny",
    "Add property of this type" : "Pridať vlastnosť tohto typu",
    "Member" : "Člen",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Toto je skupina iba na čítanie spravovaná administrátormi. Členovia skupiny môžu túto skupinu iba zobraziť.",
    "Unable to create the contact." : "Nepodarilo sa vytvoriť kontakt.",
    "Contact not found" : "Kontakt sa nenašiel",
    "Group {group} not found" : "Skupina {group} nebola nájdená",
    "Add member" : "Pridať člena",
    "New contact" : "Nový kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt pridaný pre {name}","{success} kontakty pridané pre {name}","{success} kontakty pridané pre {name}","{success} kontakty pridané pre {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Pridanie kontaktu k {name} bolo {success}","Pridanie kontaktov k {name} bolo {success}","Pridanie kontaktov k {name} bolo {success}","Pridanie kontaktov k {name} bolo {success}"],
    "_{count} error_::_{count} errors_" : ["{count} chyba","{count} chýb","{count} chýb","{count} chýb"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importuje sa %n kontakt do {addressbook}","Importujú sa %n kontakty do {addressbook}","Importujú sa %n kontakty do {addressbook}","Importuje sa %n kontaktov do {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Do {addressbook} bol dokončený import %n kontaktu","Do {addressbook} bol dokončený import %n kontaktov","Do {addressbook} bol dokončený import %n kontaktov","Do {addressbook} bol dokončený import %n kontaktov"],
    "No data for this contact" : "Pre tento kontak neexistujú žiadne dáta",
    "No data for this contact on their profile" : "Pre tento kontak neexistujú v jeho profile žiadne dáta ",
    "Import" : "Import",
    "Are you sure you want to import this contact file?" : "Ste si istý, že chcete importovať tento súbor kontaktov?",
    "Could not copy" : "Nie je možné skopírovať",
    "Join team" : "Pripojiť sa k tímu",
    "You are about to leave {circle}.\nAre you sure?" : "Ste na odchode z {circle}.\nSte si istý?",
    "Please confirm team leave" : "Prosím, potvrďte opustenie tohto tímu.",
    "Could not leave the team {displayName}" : "Nie je možné opustiť tím {displayName}",
    "Unable to join the team" : "Nedá sa pripojiť k tímu.",
    "You are about to delete {circle}.\nAre you sure?" : "Odstraňujete {circle}.\nSte si istý?",
    "Please confirm team deletion" : "Prosím potvrďte zmazanie tímu",
    "Unable to delete the team" : "Nebolo možné zmazať tím.",
    "Confirm enabling federation" : "Potvrdiť povolenie federácie",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Povolenie tejto možnosti zabráni {circle} tomu, aby bol členom iných tímov. \nSte si istý?",
    "Enable federation" : "Povoliť federáciu",
    "Link copied to the clipboard" : "Odkaz bol skopírovaný do schránky",
    "Could not copy link to the clipboard." : "Nepodarilo sa skopírovať do schránky.",
    "Not grouped" : "Bez skupiny",
    "Organization chart" : "Organizačný diagram",
    "Team" : "Tím",
    "User" : "Užívateľ",
    "Group" : "Skupina",
    "Email" : "Email",
    "Contact" : "Kontakt",
    "Moderator" : "Moderátor",
    "Admin" : "Administrátor",
    "Owner" : "Vlastník",
    "Invites" : "Pozvánky",
    "Anyone can request membership" : "Ktokoľvek môže žiadať o členstvo",
    "Members need to accept invitation" : "Členovia musia potvrdiť pozvánku",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Členstvo musí potvrdiť/prijať moderátor (vyžadované od  „Ktokoľvek môže požiadať o členstvo“)",
    "Members can also invite" : "Členovia môžu tiež pozývať",
    "Membership" : "Členstvo",
    "Prevent teams from being a member of another team" : "Zabraňte tímom byť členmi iného tímu.",
    "Federation" : "Federácia",
    "Allow federated members" : "Povoliť federovaných členy",
    "Privacy" : "Ochrana osobných údajov",
    "Visible to everyone" : "Viditeľné pre všetkých",
    "users" : "používatelia",
    "Users" : "Používatelia",
    "groups" : "skupiny",
    "federated users" : "združení užívatelia",
    "Federated users" : "Združení užívatelia",
    "teams" : "tímy",
    "email addresses" : "emailové adresy",
    "Email addresses" : "E-mailové adresy",
    "contacts" : "kontakty",
    "Detailed name" : "Podrobné meno",
    "Additional names" : "Ďalšie mená",
    "Prefix" : "Titul pred menom",
    "Suffix" : "Titul po mene",
    "Nickname" : "Prezývka",
    "Website" : "Webstránka",
    "Location" : "Umiestnenie",
    "Federated Cloud ID" : "Identifikátor federovaného cloudu",
    "Home" : "Domov",
    "Work" : "Práca",
    "Other" : "Iné",
    "Address" : "Adresa",
    "Post office box" : "Poštová adresa",
    "Extended address" : "Rozšírené adresy",
    "City" : "Mesto",
    "State or province" : "Kraj alebo oblasť",
    "Postal code" : "PSČ",
    "Country" : "Krajina",
    "Birthday" : "Narodeniny",
    "Place of birth" : "Miesto narodenia",
    "Anniversary" : "Výročie",
    "Date of death" : "Dátum smrti",
    "Place of death" : "Miesto úmrtia",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefón",
    "Mobile" : "Mobil",
    "Work mobile" : "Pracovný mobil",
    "Home mobile" : "Domáci mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax doma",
    "Fax work" : "Fax v práci",
    "Pager" : "Pager",
    "Voice" : "Odkazová schránka",
    "Car" : "Auto",
    "Work pager" : "Pracovný pager",
    "Line manager" : "Líniový manažér",
    "Social network" : "Sociálna sieť",
    "Relationship to you" : "Vzťah s vami",
    "Spouse" : "Partner/ka",
    "Child" : "Dieťa",
    "Mother" : "Matka",
    "Father" : "Otec",
    "Parent" : "Rodič",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Príbuzný",
    "Friend" : "Kamarát/ka",
    "Colleague" : "Kolega",
    "Assistant" : "Asistent",
    "Related contacts" : "Súvisiace kontakty",
    "Agent" : "Agent",
    "Emergency" : "Núdzový kontakt",
    "Co-worker" : "Spolupracovník",
    "Gender" : "Pohlavie",
    "Female" : "Žena",
    "Male" : "Muž",
    "Unknown" : "Neznámy",
    "Time zone" : "Časová zóna",
    "Spoken languages" : "Hovorené jazyky",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt nebolo možné prečítať","{failed} kontakty nebolo možné prečítať","{failed} kontaktov nebolo možné prečítať","{failed} kontaktov nebolo možné prečítať"],
    "An error has occurred in team(s). Check the console for more details." : "V aplikácii Tím sa vyskytla chyba. Pre viac informácií skontrolujte konzolu.",
    "Unable to create team {circleName}" : "Nie je možné vytvoriť tím {circleName}",
    "Unable to delete team {circleId}" : "Nie je možné zmazať tím {circleId}",
    "Unable to delete contact" : "Nepodarilo sa zmazať kontakt.",
    "Value copied to the clipboard" : "Hodnota skopírovaná do schránky",
    "Could not copy value to the clipboard." : "Nepodarilo sa skopírovať hodnotu do schránky.",
    "note" : "poznámka",
    "email" : "email"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
